@@ -1,6 +1,7 @@
 #include "AstroImage.hpp"
 #include "Projector.hpp"
-#include "STexture.hpp"
+#include "StelTextureMgr.hpp"
+#include "StelCore.hpp"
 
 AstroImage::AstroImage()
 {
@@ -18,25 +19,31 @@ AstroImage::~AstroImage()
 {
 }
 
-void AstroImage::draw(Projector *prj, const Navigator *nav, ToneReproducer *eye)
+void AstroImage::draw(StelCore* core)
 {
 	if (!tex) return;
 	
+	if (!tex->bind())
+		return;
+	
+	Projector* prj = core->getProjection();
+	
 	glEnable(GL_TEXTURE_2D);
+	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+	glEnable(GL_BLEND);
 	glColor4f(1.0,1.0,1.0,1.0);
-	tex->bind();
 	
 	prj->setCurrentFrame(Projector::FRAME_J2000);
 	
 	Vec3d win;
     glBegin(GL_TRIANGLE_STRIP);
-        glTexCoord2dv(tex->texCoordinates[0]);
+        glTexCoord2dv(tex->getCoordinates()[0]);
 		prj->project(poly[2],win); glVertex3dv(win);
-		glTexCoord2dv(tex->texCoordinates[1]);
+		glTexCoord2dv(tex->getCoordinates()[1]);
 		prj->project(poly[3],win); glVertex3dv(win);
-        glTexCoord2dv(tex->texCoordinates[2]);
+		glTexCoord2dv(tex->getCoordinates()[2]);
 		prj->project(poly[1],win); glVertex3dv(win);
-        glTexCoord2dv(tex->texCoordinates[3]);
+		glTexCoord2dv(tex->getCoordinates()[3]);
 		prj->project(poly[0],win); glVertex3dv(win);
     glEnd();
 }
