@@ -22,6 +22,8 @@
 #include <iostream>
 #include <fstream>
 #include <vector>
+#include <QDebug>
+#include <QFile>
 
 #include "ConstellationMgr.hpp"
 #include "Constellation.hpp"
@@ -36,10 +38,12 @@
 #include "StelFontMgr.hpp"
 #include "StelLocaleMgr.hpp"
 #include "StelSkyCultureMgr.hpp"
+#include "StelModuleMgr.hpp"
 #include "StelFileMgr.hpp"
+#include "StelCore.hpp"
 
 // constructor which loads all data from appropriate files
-ConstellationMgr::ConstellationMgr(StarMgr *_hip_stars) : 
+ConstellationMgr::ConstellationMgr(StarMgr *_hip_stars) :
 	fontSize(15),
 	asterFont(NULL),
 	hipStarMgr(_hip_stars),
@@ -48,14 +52,14 @@ ConstellationMgr::ConstellationMgr(StarMgr *_hip_stars) :
 	flagArt(0),
 	flagBoundaries(0)
 {
+	setObjectName("ConstellationMgr");
 	assert(hipStarMgr);
 	isolateSelected = false;
-	dependenciesOrder["draw"]="nebulas";
 }
 
 ConstellationMgr::~ConstellationMgr()
 {
- 	vector<Constellation *>::iterator iter;
+	vector<Constellation *>::iterator iter;
 
 	for (iter = asterisms.begin(); iter != asterisms.end(); iter++)
 	{
@@ -70,26 +74,34 @@ ConstellationMgr::~ConstellationMgr()
 	allBoundarySegments.clear();
 }
 
-void ConstellationMgr::init(const InitParser& conf, LoadingBar& lb)
+void ConstellationMgr::init(const InitParser& conf)
 {
 	lastLoadedSkyCulture = "dummy";
-	updateSkyCulture(lb);
-	
+	updateSkyCulture();
 	fontSize = conf.get_double("viewing","constellation_font_size",16.);
 	setFlagLines(		conf.get_boolean("viewing:flag_constellation_drawing"));
 	setFlagNames(		conf.get_boolean("viewing:flag_constellation_name"));
 	setFlagBoundaries(	conf.get_boolean("viewing","flag_constellation_boundaries",false));
-	setFlagArt(			conf.get_boolean("viewing:flag_constellation_art"));
-	setFlagIsolateSelected(conf.get_boolean("viewing", "flag_constellation_isolate_selected",conf.get_boolean("viewing", "flag_constellation_pick", false)));
 	setArtIntensity(	conf.get_double("viewing","constellation_art_intensity", 0.5));
 	setArtFadeDuration(	conf.get_double("viewing","constellation_art_fade_duration",2.));
-	
+	setFlagArt(			conf.get_boolean("viewing:flag_constellation_art"));
+	setFlagIsolateSelected(conf.get_boolean("viewing", "flag_constellation_isolate_selected",conf.get_boolean("viewing", "flag_constellation_pick", false)));
 	StelApp::getInstance().getStelObjectMgr().registerStelObjectMgr(this);
 }
 
-void ConstellationMgr::updateSkyCulture(LoadingBar& lb)
+/*************************************************************************
+ Reimplementation of the getCallOrder method
+*************************************************************************/
+double ConstellationMgr::getCallOrder(StelModuleActionName actionName) const
 {
-	string newSkyCulture = StelApp::getInstance().getSkyCultureMgr().getSkyCultureDir();
+	if (actionName==StelModule::ACTION_DRAW)
+		return StelApp::getInstance().getModuleMgr().getModule("GridLinesMgr")->getCallOrder(actionName)+10;
+	return 0;
+}
+
+void ConstellationMgr::updateSkyCulture()
+{
+	QString newSkyCulture = StelApp::getInstance().getSkyCultureMgr().getSkyCultureDir();
 	StelFileMgr& fileMan = StelApp::getInstance().getFileMgr();
 	
 	// Check if the sky culture changed since last load, if not don't load anything
@@ -98,33 +110,32 @@ void ConstellationMgr::updateSkyCulture(LoadingBar& lb)
 	
 	// Find constellation art.  If this doesn't exist, warn, but continue using ""
 	// the loadLinesAndArt function knows how to handle this (just loads lines).
-	string conArtFile("");
+	QString conArtFile;
 	try
 	{
 		conArtFile = fileMan.findFile("skycultures/"+newSkyCulture+"/constellationsart.fab");
 	}
 	catch(exception& e)
 	{
-		cout << "WARNING: no constellationsart.fab file found for sky culture " << newSkyCulture << endl;
+		qWarning() << "WARNING: no constellationsart.fab file found for sky culture " << newSkyCulture;
 	}
-				
+
 	try
 	{
-		loadLinesAndArt(fileMan.findFile("skycultures/"+newSkyCulture+"/constellationship.fab"),
-				conArtFile, newSkyCulture, lb);
+		loadLinesAndArt(fileMan.findFile("skycultures/"+newSkyCulture+"/constellationship.fab"), conArtFile, newSkyCulture);
 			
 		// load constellation names
 		loadNames(fileMan.findFile("skycultures/" + newSkyCulture + "/constellation_names.eng.fab"));
-	
+
 		// Translate constellation names for the new sky culture
 		updateI18n();
 		
 		// as constellations have changed, clear out any selection and retest for match!
-		selectedObjectChangeCallBack(false);		
+		selectedObjectChangeCallBack(StelModule::REPLACE_SELECTION);		
 	}
 	catch(exception& e)
 	{
-		cout << "ERROR: while loading new constellation data for sky culture " 
+		qWarning() << "ERROR: while loading new constellation data for sky culture " 
 			<< newSkyCulture << ", reason: " << e.what() << endl;		
 	}
 		
@@ -135,20 +146,16 @@ void ConstellationMgr::updateSkyCulture(LoadingBar& lb)
 	lastLoadedSkyCulture = newSkyCulture;
 }
 
-void ConstellationMgr::setColorScheme(const InitParser& conf, const std::string& section)
+void ConstellationMgr::setColorScheme(const InitParser& conf, const QString& section)
 {
 	// Load colors from config file
-	string defaultColor = conf.get_str(section,"default_color");
-	setLinesColor(StelUtils::str_to_vec3f(conf.get_str(section,"const_lines_color", defaultColor)));
-	setBoundariesColor(StelUtils::str_to_vec3f(conf.get_str(section,"const_boundary_color", "0.8,0.3,0.3")));
-	setNamesColor(StelUtils::str_to_vec3f(conf.get_str(section,"const_names_color", defaultColor)));
+	string defaultColor = conf.get_str(section.toStdString(),"default_color");
+	setLinesColor(StelUtils::str_to_vec3f(conf.get_str(section.toStdString(),"const_lines_color", defaultColor)));
+	setBoundariesColor(StelUtils::str_to_vec3f(conf.get_str(section.toStdString(),"const_boundary_color", "0.8,0.3,0.3")));
+	setNamesColor(StelUtils::str_to_vec3f(conf.get_str(section.toStdString(),"const_names_color", defaultColor)));
 }
 
-/*************************************************************************
- The selected objects changed, check if some stars are selected and display the 
- matching constellations if isolate_selected mode is activated
-*************************************************************************/ 
-void ConstellationMgr::selectedObjectChangeCallBack(bool added)
+void ConstellationMgr::selectedObjectChangeCallBack(StelModuleSelectAction action)
 {
 	const std::vector<StelObjectP> newSelected = StelApp::getInstance().getStelObjectMgr().getSelectedObject();
 	if (newSelected.empty())
@@ -164,8 +171,14 @@ void ConstellationMgr::selectedObjectChangeCallBack(bool added)
 	{
 //		const boost::intrusive_ptr<Constellation> c = boost::dynamic_pointer_cast<Constellation>(newSelectedConst[0]);
 //		StelApp::getInstance().getStelObjectMgr().setSelectedObject(c->getBrightestStarInConstellation());
-		// Do not select a star, just the constellation
-		setSelectedConst((Constellation *)newSelectedConst[0].get());
+
+		// If removing this selection
+		if(action == StelModule::REMOVE_FROM_SELECTION) {
+			unsetSelectedConst((Constellation *)newSelectedConst[0].get());
+		} else {
+			// Add constellation to selected list (do not select a star, just the constellation)
+			setSelectedConst((Constellation *)newSelectedConst[0].get());
+		}
 	}
 	else
 	{
@@ -184,28 +197,54 @@ void ConstellationMgr::selectedObjectChangeCallBack(bool added)
 	}
 }
 
-void ConstellationMgr::setLinesColor(const Vec3f& c) {Constellation::lineColor = c;}
-Vec3f ConstellationMgr::getLinesColor() const {return Constellation::lineColor;}
+void ConstellationMgr::setLinesColor(const Vec3f& c)
+{
+	Constellation::lineColor = c;
+}
 
-void ConstellationMgr::setBoundariesColor(const Vec3f& c) {Constellation::boundaryColor = c;}
-Vec3f ConstellationMgr::getBoundariesColor() const {return Constellation::boundaryColor;}
+Vec3f ConstellationMgr::getLinesColor() const
+{
+	return Constellation::lineColor;
+}
 
-void ConstellationMgr::setNamesColor(const Vec3f& c) {Constellation::labelColor = c;}
-Vec3f ConstellationMgr::getNamesColor() const {return Constellation::labelColor;}
+void ConstellationMgr::setBoundariesColor(const Vec3f& c) 
+{
+	Constellation::boundaryColor = c;
+}
+
+Vec3f ConstellationMgr::getBoundariesColor() const 
+{
+	return Constellation::boundaryColor;
+}
+
+void ConstellationMgr::setNamesColor(const Vec3f& c) 
+{
+	Constellation::labelColor = c;
+}
+
+Vec3f ConstellationMgr::getNamesColor() const 
+{
+	return Constellation::labelColor;
+}
 
 void ConstellationMgr::setFontSize(double newFontSize)
 {
 	asterFont = &StelApp::getInstance().getFontManager().getStandardFont(StelApp::getInstance().getLocaleMgr().getSkyLanguage(), fontSize);
 }
 
-// Load line and art data from files
-void ConstellationMgr::loadLinesAndArt(const string &fileName, const string &artfileName, const string& cultureName, LoadingBar& lb)
+double ConstellationMgr::getFontSize() const
 {
-	std::ifstream inf(fileName.c_str());
+	return asterFont->getSize();
+}
+
+// Load line and art data from files
+void ConstellationMgr::loadLinesAndArt(const QString &fileName, const QString &artfileName, const QString& cultureName)
+{
+	std::ifstream inf(QFile::encodeName(fileName).constData());
 
 	if (!inf.is_open())
 	{
-		printf("Can't open constellation data file %s\n", fileName.c_str());
+		qWarning() << "Can't open constellation data file " << fileName;
 		assert(0);
 	}
 
@@ -232,9 +271,10 @@ void ConstellationMgr::loadLinesAndArt(const string &fileName, const string &art
 		if(cons->read(record, hipStarMgr))
 		{
 			asterisms.push_back(cons);
-		} else
-		{ 
-			cerr << "ERROR on line " << line << "of " << fileName.c_str() << endl;
+		}
+		else
+		{
+			qWarning() << "ERROR on line " << line << "of " << fileName;
 			delete cons;
 		}
 	}
@@ -246,10 +286,10 @@ void ConstellationMgr::loadLinesAndArt(const string &fileName, const string &art
 	setFlagNames(flagNames);	
 	setFlagBoundaries(flagBoundaries);	
 
-	FILE *fic = fopen(artfileName.c_str(), "r");
+	FILE *fic = fopen(QFile::encodeName(artfileName).constData(), "r");
 	if (!fic)
 	{
-		cerr << "Can't open " << artfileName.c_str() << endl;
+		qWarning() << "Can't open " << artfileName;
 		return; // no art, but still loaded constellation data
 	}
 
@@ -275,6 +315,7 @@ void ConstellationMgr::loadLinesAndArt(const string &fileName, const string &art
 	int current = 0;
 
 	StelApp::getInstance().getTextureManager().setDefaultParams();
+	LoadingBar& lb = *StelApp::getInstance().getLoadingBar();
 	while (!feof(fic))
 	{
 		if (fscanf(fic, "%s %s %u %u %u %u %u %u %u %u %u\n", shortname, texfile, &x1, &y1, &hp1, &x2, &y2, &hp2, &x3, &y3, &hp3) != 11)
@@ -302,32 +343,39 @@ void ConstellationMgr::loadLinesAndArt(const string &fileName, const string &art
 		else
 		{
 			StelApp::getInstance().getTextureManager().setDefaultParams();
-			string texturePath(texfile);
+			QString texturePath(texfile);
 			try
 			{
-				texturePath = StelApp::getInstance().getFileMgr().findFile(string("skycultures/")+cultureName+"/"+texfile);
+				texturePath = StelApp::getInstance().getFileMgr().findFile("skycultures/"+cultureName+"/"+texfile);
 			}
 			catch(exception& e)
 			{
 				// if the texture isn't found in the skycultures/[culture] directory,
 				// try the central textures diectory.
-				cerr << "WARNING, could not locate texture file " << texfile
+				qWarning() << "WARNING, could not locate texture file " << texfile
 				     << " in the skycultures/" << cultureName
-				     << " directory...  looking in general textures/ directory..." 
-				     << endl; 
+				     << " directory...  looking in general textures/ directory...";
 				try
 				{
-					texturePath = StelApp::getInstance().getFileMgr().findFile(string("textures/")+texfile);
+					texturePath = StelApp::getInstance().getFileMgr().findFile(QString("textures/")+texfile);
 				}
 				catch(exception& e2)
 				{
-					cerr << "ERROR: could not find texture, " << texfile << ": " << e2.what() << endl;
+					qWarning() << "ERROR: could not find texture, " << texfile << ": " << e2.what();
 				}
 			}
 			
-			cons->art_tex = StelApp::getInstance().getTextureManager().createTexture(texturePath);
+#ifndef USE_SDL
+			cons->artTexture = StelApp::getInstance().getTextureManager().createTextureThread(texturePath);
+#else
+			cons->artTexture = StelApp::getInstance().getTextureManager().createTexture(texturePath);
+#endif
+			
 			int texSizeX, texSizeY;
-			cons->art_tex->getDimensions(texSizeX, texSizeY);
+			if (cons->artTexture==NULL || !cons->artTexture->getDimensions(texSizeX, texSizeY))
+			{
+				qWarning() << "Texture dimention not available";
+			}
 
 			Vec3f s1 = hipStarMgr->searchHP(hp1)->getObsJ2000Pos(0);
 			Vec3f s2 = hipStarMgr->searchHP(hp2)->getObsJ2000Pos(0);
@@ -359,18 +407,21 @@ void ConstellationMgr::loadLinesAndArt(const string &fileName, const string &art
 	
 }
 
-double ConstellationMgr::draw(Projector * prj, const Navigator * nav, ToneReproducer *)
+double ConstellationMgr::draw(StelCore* core)
 {
+	Navigator* nav = core->getNavigation();
+	Projector* prj = core->getProjection();
+	
 	prj->setCurrentFrame(Projector::FRAME_J2000);
-	draw_lines(prj);
-	draw_names(prj);
-	draw_art(prj, nav);
+	drawLines(prj);
+	drawNames(prj);
+	drawArt(prj, nav);
 	drawBoundaries(prj);
 	return 0.;
 }
 
 // Draw constellations art textures
-void ConstellationMgr::draw_art(Projector * prj, const Navigator * nav) const
+void ConstellationMgr::drawArt(Projector * prj, const Navigator * nav) const
 {
 	glBlendFunc(GL_ONE, GL_ONE);
 	glEnable(GL_TEXTURE_2D);
@@ -380,27 +431,27 @@ void ConstellationMgr::draw_art(Projector * prj, const Navigator * nav) const
 	vector < Constellation * >::const_iterator iter;
 	for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
 	{
-		(*iter)->draw_art_optim(prj, nav);
+		(*iter)->drawArtOptim(prj, nav);
 	}
 
 	glDisable(GL_CULL_FACE);
 }
 
 // Draw constellations lines
-void ConstellationMgr::draw_lines(Projector * prj) const
+void ConstellationMgr::drawLines(Projector * prj) const
 {
 	glDisable(GL_TEXTURE_2D);
-    glDisable(GL_BLEND);
+	glDisable(GL_BLEND);
 
 	vector < Constellation * >::const_iterator iter;
 	for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
 	{
-		(*iter)->draw_optim(prj);
+		(*iter)->drawOptim(prj);
 	}
 }
 
 // Draw the names of all the constellations
-void ConstellationMgr::draw_names(Projector * prj) const
+void ConstellationMgr::drawNames(Projector * prj) const
 {
 	glEnable(GL_BLEND);
 	glEnable(GL_TEXTURE_2D);
@@ -414,17 +465,18 @@ void ConstellationMgr::draw_names(Projector * prj) const
 	{
 		// Check if in the field of view
 		if (prj->projectCheck((*iter)->XYZname, (*iter)->XYname))
-			(*iter)->draw_name(asterFont, prj);
+			(*iter)->drawName(asterFont, prj);
 	}
 }
 
-Constellation *ConstellationMgr::is_star_in(const StelObject* s) const
+Constellation *ConstellationMgr::isStarIn(const StelObject* s) const
 {
 	vector < Constellation * >::const_iterator iter;
 	for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
 	{
 		// Check if the star is in one of the constellation
-		if ((*iter)->is_star_in(s)) {
+		if ((*iter)->isStarIn(s)) 
+		{
 			return (*iter);
 		}
 	}
@@ -447,17 +499,12 @@ Constellation* ConstellationMgr::findFromAbbreviation(const string & abbreviatio
 }
 
 // Can't find constellation from a position because it's not well localized
-vector<StelObjectP> ConstellationMgr::searchAround(const Vec3d& v, double limitFov, const Navigator * nav, const Projector * prj) const
+vector<StelObjectP> ConstellationMgr::searchAround(const Vec3d& v, double limitFov, const StelCore* core) const
 {
 	return vector<StelObjectP>(0);
 }
 
-
-/** 
- * @brief Read constellation names from the given file
- * @param namesFile Name of the file containing the constellation names in english
- */
-void ConstellationMgr::loadNames(const string& namesFile)
+void ConstellationMgr::loadNames(const QString& namesFile)
 {
 	// Constellation not loaded yet
 	if (asterisms.empty()) return;
@@ -470,10 +517,10 @@ void ConstellationMgr::loadNames(const string& namesFile)
 	}
 
 	// read in translated common names from file
-	ifstream commonNameFile(namesFile.c_str());
+	ifstream commonNameFile(QFile::encodeName(namesFile).constData());
 	if (!commonNameFile.is_open())
 	{
-		cerr << "Can't open file" << namesFile << endl;
+		qWarning() << "Can't open file" << namesFile;
 		return;
 	}
 	
@@ -484,7 +531,8 @@ void ConstellationMgr::loadNames(const string& namesFile)
 	while (!std::getline(commonNameFile, record).eof())
 	{
 
-		if( record != "") {
+		if( record != "") 
+		{
 			istringstream in(record); 
 			in >> tmpShortName;
 
@@ -492,18 +540,15 @@ void ConstellationMgr::loadNames(const string& namesFile)
 
 			aster = findFromAbbreviation(tmpShortName);
 			if (aster != NULL)
-				{
-					// Read the names in english
-					aster->englishName = record.substr(tmpShortName.length()+1,record.length()).c_str();
-				}
+			{
+				// Read the names in english
+				aster->englishName = record.substr(tmpShortName.length()+1,record.length()).c_str();
+			}
 		}
 	}
 	commonNameFile.close();
-
 }
 
-//! @brief Update i18n names from english names according to current locale, and update font for locale
-//! The translation is done using gettext with translated strings defined in translations.h
 void ConstellationMgr::updateI18n()
 {
 	Translator& trans = StelApp::getInstance().getLocaleMgr().getSkyTranslator();
@@ -522,7 +567,7 @@ void ConstellationMgr::update(double delta_time)
 	for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
 	{
 		(*iter)->update((int)(delta_time*1000));
-    }
+	}
 }
 
 
@@ -584,7 +629,7 @@ void ConstellationMgr::setFlagArt(bool b)
 		vector < Constellation * >::const_iterator iter;
 		for (iter = selected.begin(); iter != selected.end(); ++iter)
 			(*iter)->setFlagArt(b);
-   }
+	}
 	else
 	{
 		vector < Constellation * >::const_iterator iter;
@@ -615,8 +660,6 @@ StelObject* ConstellationMgr::getSelected(void) const {
 	return *selected.begin();  // TODO return all or just remove this method
 }
 
-
-//! Define which constellation is selected from its abbreviation
 void ConstellationMgr::setSelected(const string& abbreviation) 
 {
 	Constellation * c = findFromAbbreviation(abbreviation);
@@ -625,7 +668,6 @@ void ConstellationMgr::setSelected(const string& abbreviation)
 
 }
 
-//! Define which constellation is selected and return brightest star 
 StelObjectP ConstellationMgr::setSelectedStar(const string& abbreviation) 
 {
 	Constellation * c = findFromAbbreviation(abbreviation);
@@ -637,8 +679,6 @@ StelObjectP ConstellationMgr::setSelectedStar(const string& abbreviation)
 	return NULL;
 }
 
-
-
 void ConstellationMgr::setSelectedConst(Constellation * c)
 {
 	// update states for other constellations to fade them out
@@ -651,35 +691,37 @@ void ConstellationMgr::setSelectedConst(Constellation * c)
 		c->setFlagName(getFlagNames());
 		c->setFlagArt(getFlagArt());
 		c->setFlagBoundaries(getFlagBoundaries());
-				
+	
 		if (isolateSelected)
 		{
-		    vector < Constellation * >::const_iterator iter;
-		    for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
-		    {
+			vector < Constellation * >::const_iterator iter;
+			for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
+			{
 
 				bool match = 0;
 				vector < Constellation * >::const_iterator s_iter;
 				for (s_iter = selected.begin(); s_iter != selected.end(); ++s_iter)
-					if( (*iter)==(*s_iter) ) {
+				{
+					if( (*iter)==(*s_iter) ) 
+					{
 						match=true; // this is a selected constellation
 						break;  
 					}
+				}
 
-				if(!match) {
+				if(!match)
+				{
 					// Not selected constellation
 					(*iter)->setFlagLines(false);
 					(*iter)->setFlagName(false);
 					(*iter)->setFlagArt(false);
 					(*iter)->setFlagBoundaries(false);
-		        }
-             }
+		        	}
+             		}
 			Constellation::singleSelected = true;  // For boundaries
-        }
+        	}
 		else
-		{
 			Constellation::singleSelected = false; // For boundaries
-		}
 	}
 	else
 	{
@@ -702,8 +744,55 @@ void ConstellationMgr::setSelectedConst(Constellation * c)
 	}
 }
 
-// Load from file 
-bool ConstellationMgr::loadBoundaries(const string& boundaryFile)
+
+//! Remove a constellation from the selected constellation list
+void ConstellationMgr::unsetSelectedConst(Constellation * c)
+{
+	if (c != NULL)
+	{
+
+		vector < Constellation * >::const_iterator iter;
+		int n=0;
+		for (iter = selected.begin(); iter != selected.end(); ++iter)
+		{
+			if( (*iter)->getEnglishName() == c->getEnglishName() ) 
+			{
+				selected.erase(selected.begin()+n, selected.begin()+n+1);
+				iter--;
+				n--;
+			}
+			n++;
+		}
+
+		// If no longer any selection, restore all flags on all constellations
+		if (selected.begin() == selected.end()) { 
+
+			// Otherwise apply standard flags to all constellations
+			for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
+			{
+				(*iter)->setFlagLines(getFlagLines());
+				(*iter)->setFlagName(getFlagNames());
+				(*iter)->setFlagArt(getFlagArt());
+				(*iter)->setFlagBoundaries(getFlagBoundaries());
+			}
+
+			Constellation::singleSelected = false; // For boundaries
+
+		} else if(isolateSelected) {
+
+			// No longer selected constellation
+			c->setFlagLines(false);
+			c->setFlagName(false);
+			c->setFlagArt(false);
+			c->setFlagBoundaries(false);
+
+			Constellation::singleSelected = true;  // For boundaries
+		}
+	}
+}
+
+
+bool ConstellationMgr::loadBoundaries(const QString& boundaryFile)
 {
 	Constellation *cons = NULL;
 	unsigned int i, j;
@@ -715,17 +804,17 @@ bool ConstellationMgr::loadBoundaries(const string& boundaryFile)
 	}
 	allBoundarySegments.clear();
 
-    cout << "Loading Constellation boundary data from " << boundaryFile << " ...\n";
+	cout << "Loading Constellation boundary data from " << qPrintable(boundaryFile) << "... ";
 	// Modified boundary file by Torsten Bronger with permission
 	// http://pp3.sourceforge.net
 	
-    ifstream dataFile;
-	dataFile.open(boundaryFile.c_str());
-    if (!dataFile.is_open())
-    {
-        cerr << "Boundary file " << boundaryFile << " not found" << endl;
-        return false;
-    }
+	ifstream dataFile;
+	dataFile.open(QFile::encodeName(boundaryFile).constData());
+	if (!dataFile.is_open())
+	{
+		qWarning() << "Boundary file " << boundaryFile << " not found";
+		return false;
+	}
 
 	float DE, RA;
 	float oDE, oRA;
@@ -778,18 +867,17 @@ bool ConstellationMgr::loadBoundaries(const string& boundaryFile)
 		i++;
 
 	}
-    dataFile.close();
+	dataFile.close();
 	cout << "(" << i << " segments loaded)" << endl;
-    delete points;
-    
-    return true;
+	delete points;
+
+	return true;
 }
 
-// Draw constellations lines
 void ConstellationMgr::drawBoundaries(Projector * prj) const
 {
 	glDisable(GL_TEXTURE_2D);
-    glDisable(GL_BLEND);
+	glDisable(GL_BLEND);
 
 	glLineStipple(2, 0x3333);
 	glEnable(GL_LINE_STIPPLE);
@@ -797,7 +885,7 @@ void ConstellationMgr::drawBoundaries(Projector * prj) const
 	vector < Constellation * >::const_iterator iter;
 	for (iter = asterisms.begin(); iter != asterisms.end(); ++iter)
 	{
-		(*iter)->draw_boundary_optim(prj);
+		(*iter)->drawBoundaryOptim(prj);
 	}
 	glDisable(GL_LINE_STIPPLE);
 }
@@ -807,8 +895,6 @@ void ConstellationMgr::drawBoundaries(Projector * prj) const
 ///  return 0;
 ///}
 
-//! Return the matching constellation object's pointer if exists or NULL
-//! @param nameI18n The case sensistive constellation name
 StelObjectP ConstellationMgr::searchByNameI18n(const wstring& nameI18n) const
 {
 	wstring objw = nameI18n;
@@ -824,9 +910,6 @@ StelObjectP ConstellationMgr::searchByNameI18n(const wstring& nameI18n) const
 	return NULL;
 }
 
-
-//! Return the matching constellation object's pointer if exists or NULL
-//! @param name The case sensistive standard program constellation code
 StelObjectP ConstellationMgr::searchByName(const string& name) const
 {
 	string objw = name;
@@ -844,7 +927,6 @@ StelObjectP ConstellationMgr::searchByName(const string& name) const
 	return NULL;
 }
 
-//! Find and return the list of at most maxNbItem objects auto-completing the passed object I18n name
 vector<wstring> ConstellationMgr::listMatchingObjectsI18n(const wstring& objPrefix, unsigned int maxNbItem) const
 {
 	vector<wstring> result;
