@@ -30,9 +30,12 @@
 #include "Planet.hpp"
 #include "StelFontMgr.hpp"
 #include "StelLocaleMgr.hpp"
+#include "StelModuleMgr.hpp"
 #include "InitParser.hpp"
+#include "StelCore.hpp"
 
-// Class which manages a grid to display in the sky
+//! @class SkyGrid 
+//! Class which manages a grid to display in the sky.
 class SkyGrid
 {
 public:
@@ -58,7 +61,8 @@ private:
 };
 
 
-// Class which manages a line to display around the sky like the ecliptic line
+//! @class SkyLine 
+//! Class which manages a line to display around the sky like the ecliptic line.
 class SkyLine
 {
 public:
@@ -89,7 +93,6 @@ private:
 	SFont& font;
 };
 
-
 // rms added color as parameter
 SkyGrid::SkyGrid(Projector::FRAME_TYPE frame) : color(0.2,0.2,0.2), frameType(frame), fontSize(12),
 	font(StelApp::getInstance().getFontManager().getStandardFont(StelApp::getInstance().getLocaleMgr().getAppLanguage(), fontSize))
@@ -340,6 +343,9 @@ void SkyGrid::draw(const Projector* prj) const
 	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA); // Normal transparency mode
 
 	glColor4f(color[0],color[1],color[2], fader.getInterstate());
+	Vec4f textColor(color[0], color[1], color[2], 0);
+	textColor*=2;
+	textColor[3]=fader.getInterstate();
 
 	prj->setCurrentFrame(frameType);	// set 2D coordinate
 
@@ -404,7 +410,7 @@ void SkyGrid::draw(const Projector* prj) const
 				else
 					size = *ii - lon;
 				if (size<0) size+=2.*M_PI;
-				prj->drawParallel(vv, size, true, &font);
+				prj->drawParallel(vv, size, true, &font, &textColor);
 				++ii;
 			}
 		}
@@ -486,7 +492,7 @@ void SkyGrid::draw(const Projector* prj) const
 				else
 					size = *k - lat180;
 				if (size<0.) size+=2.*M_PI;
-				prj->drawMeridian(vv, size, true, &font);
+				prj->drawMeridian(vv, size, true, &font, &textColor);
 				++k;
 			}
 		}
@@ -531,7 +537,7 @@ void SkyGrid::draw(const Projector* prj) const
 			{
 				Vec3d vvv;
 				spheToRectLat1802((double)latMas/RADIAN_MAS, 0, vvv);
-				prj->drawMeridian(vvv, 2.*M_PI, false, &font);
+				prj->drawMeridian(vvv, 2.*M_PI, false, &font, &textColor);
 			}
 		}
 	}
@@ -582,7 +588,7 @@ void SkyLine::draw(Projector *prj,const Navigator *nav) const
 
 GridLinesMgr::GridLinesMgr()
 {
-	dependenciesOrder["draw"]="nebulas";
+	setObjectName("GridLinesMgr");
 	equ_grid = new SkyGrid(Projector::FRAME_EARTH_EQU);
 	azi_grid = new SkyGrid(Projector::FRAME_LOCAL);
 	equator_line = new SkyLine(SkyLine::EQUATOR);
@@ -599,7 +605,17 @@ GridLinesMgr::~GridLinesMgr()
 	delete meridian_line;
 }
 
-void GridLinesMgr::init(const InitParser& conf, LoadingBar& lb)
+/*************************************************************************
+ Reimplementation of the getCallOrder method
+*************************************************************************/
+double GridLinesMgr::getCallOrder(StelModuleActionName actionName) const
+{
+	if (actionName==StelModule::ACTION_DRAW)
+		return StelApp::getInstance().getModuleMgr().getModule("NebulaMgr")->getCallOrder(actionName)+10;
+	return 0;
+}
+
+void GridLinesMgr::init(const InitParser& conf)
 {
 	setFlagAzimutalGrid(conf.get_boolean("viewing:flag_azimutal_grid"));
 	setFlagEquatorGrid(conf.get_boolean("viewing:flag_equatorial_grid"));
@@ -618,8 +634,11 @@ void GridLinesMgr::update(double deltaTime)
 	meridian_line->update(deltaTime);
 }
 
-double GridLinesMgr::draw(Projector *prj, const Navigator *nav, ToneReproducer *eye)
+double GridLinesMgr::draw(StelCore* core)
 {
+	Navigator* nav = core->getNavigation();
+	Projector* prj = core->getProjection();
+
 	// Draw the equatorial grid
 	equ_grid->draw(prj);
 	// Draw the altazimutal grid
@@ -633,15 +652,15 @@ double GridLinesMgr::draw(Projector *prj, const Navigator *nav, ToneReproducer *
 	return 0.;
 }
 
-void GridLinesMgr::setColorScheme(const InitParser& conf, const std::string& section)
+void GridLinesMgr::setColorScheme(const InitParser& conf, const QString& section)
 {
 	// Load colors from config file
-	string defaultColor = conf.get_str(section,"default_color");
-	setColorEquatorGrid(StelUtils::str_to_vec3f(conf.get_str(section,"equatorial_color", defaultColor)));
-	setColorAzimutalGrid(StelUtils::str_to_vec3f(conf.get_str(section,"azimuthal_color", defaultColor)));
-	setColorEquatorLine(StelUtils::str_to_vec3f(conf.get_str(section,"equator_color", defaultColor)));
-	setColorEclipticLine(StelUtils::str_to_vec3f(conf.get_str(section,"ecliptic_color", defaultColor)));
-	setColorMeridianLine(StelUtils::str_to_vec3f(conf.get_str(section,"meridian_color", defaultColor)));
+	string defaultColor = conf.get_str(section.toStdString(),"default_color");
+	setColorEquatorGrid(StelUtils::str_to_vec3f(conf.get_str(section.toStdString(),"equatorial_color", defaultColor)));
+	setColorAzimutalGrid(StelUtils::str_to_vec3f(conf.get_str(section.toStdString(),"azimuthal_color", defaultColor)));
+	setColorEquatorLine(StelUtils::str_to_vec3f(conf.get_str(section.toStdString(),"equator_color", defaultColor)));
+	setColorEclipticLine(StelUtils::str_to_vec3f(conf.get_str(section.toStdString(),"ecliptic_color", defaultColor)));
+	setColorMeridianLine(StelUtils::str_to_vec3f(conf.get_str(section.toStdString(),"meridian_color", defaultColor)));
 }
 
 //! Set flag for displaying Azimutal Grid
