@@ -19,7 +19,6 @@
 
 #include "Landscape.hpp"
 #include "InitParser.hpp"
-#include "STexture.hpp"
 #include "StelApp.hpp"
 #include "StelTextureMgr.hpp"
 #include "StelFileMgr.hpp"
@@ -27,6 +26,8 @@
 #include <cassert>
 #include <vector>
 
+#include <QDebug>
+
 Landscape::Landscape(float _radius) : radius(_radius), sky_brightness(1.),
 		     planet(""), latitude(-1000), longitude(-1000), altitude(1)
 {
@@ -38,17 +39,17 @@ Landscape::~Landscape()
 
 
 // Load attributes common to all landscapes
-void Landscape::loadCommon(const string& landscape_file, const string& landscapeId)
+void Landscape::loadCommon(const QString& landscape_file, const QString& landscapeId)
 {
 	InitParser pd;	// The landscape data ini file parser
 	pd.load(landscape_file);
 	// cout << "DEBUG Landscape::loadCommon section name is: " << landscapeId << "file name is " << landscape_file << endl;
-	name = StelUtils::stringToWstring(pd.get_str("landscape", "name"));
-	author = StelUtils::stringToWstring(pd.get_str("landscape", "author"));
-	description = StelUtils::stringToWstring(pd.get_str("landscape", "description"));
-	if(name == L"" )
+	name = QString::fromUtf8(pd.get_str("landscape", "name").c_str());
+	author = QString::fromUtf8(pd.get_str("landscape", "author").c_str());
+	description = QString::fromUtf8(pd.get_str("landscape", "description").c_str());
+	if (name.isEmpty())
 	{
-		cerr << "No valid landscape definition found for section "<< landscapeId << " in file " << landscape_file << ". No landscape in use." << endl;
+		qWarning() << "No valid landscape definition found for section "<< landscapeId << " in file " << landscape_file << ". No landscape in use." << endl;
 		valid_landscape = 0;
 		return;
 	}
@@ -58,16 +59,16 @@ void Landscape::loadCommon(const string& landscape_file, const string& landscape
 	}
 	
 	// Optional data
-	if (pd.find_entry("location:planet")) planet = pd.get_str("location", "planet");
+	if (pd.find_entry("location:planet")) planet = QString::fromStdString(pd.get_str("location", "planet"));
 	if (pd.find_entry("location:latitude")) latitude = StelUtils::get_dec_angle(pd.get_str("location", "latitude"));
 	if (pd.find_entry("location:longitude")) longitude = StelUtils::get_dec_angle(pd.get_str("location", "longitude"));
 	if (pd.find_entry("location:altitude")) altitude = pd.get_int("location", "altitude");
 }
 
-const string Landscape::getTexturePath(const string& basename, const string& landscapeId)
+const QString Landscape::getTexturePath(const QString& basename, const QString& landscapeId)
 {
 	// look in the landscape directory first, and if not found default to global textures directory
-	string path;
+	QString path;
 	try {
 		path = StelApp::getInstance().getFileMgr().findFile("landscapes/" + landscapeId + "/" + basename);
 		return path;
@@ -93,7 +94,7 @@ LandscapeOldStyle::~LandscapeOldStyle()
 	if (sides) delete [] sides;
 }
 
-void LandscapeOldStyle::load(const string& landscape_file, const string& landscapeId)
+void LandscapeOldStyle::load(const QString& landscape_file, const QString& landscapeId)
 {
 	loadCommon(landscape_file, landscapeId);
 	
@@ -105,7 +106,7 @@ void LandscapeOldStyle::load(const string& landscape_file, const string& landsca
 	string type = pd.get_str("landscape", "type");
 	if(type != "old_style")
 	{
-		cerr << "Landscape type mismatch for landscape "<< landscapeId << ", expected old_style, found " << type << ".  No landscape in use.\n";
+		qWarning() << "Landscape type mismatch for landscape "<< landscapeId << ", expected old_style, found " << type.c_str() << ".  No landscape in use.\n";
 		valid_landscape = 0;
 		return;
 	}
@@ -119,7 +120,7 @@ void LandscapeOldStyle::load(const string& landscape_file, const string& landsca
 	for (int i=0;i<nb_side_texs;++i)
 	{
 		sprintf(tmp,"tex%d",i);
-		side_texs[i] = StelApp::getInstance().getTextureManager().createTexture(getTexturePath(pd.get_str("landscape", tmp), landscapeId));
+		side_texs[i] = StelApp::getInstance().getTextureManager().createTexture(getTexturePath(pd.get_str("landscape", tmp).c_str(), landscapeId));
 	}
 
 	// Init sides parameters
@@ -144,7 +145,7 @@ void LandscapeOldStyle::load(const string& landscape_file, const string& landsca
 	nb_decor_repeat = pd.get_int("landscape", "nb_decor_repeat", 1);
 
 	StelApp::getInstance().getTextureManager().setDefaultParams();
-	ground_tex = StelApp::getInstance().getTextureManager().createTexture(getTexturePath(pd.get_str("landscape", "groundtex"), landscapeId));
+	ground_tex = StelApp::getInstance().getTextureManager().createTexture(getTexturePath(pd.get_str("landscape", "groundtex").c_str(), landscapeId));
 	s = pd.get_str("landscape", "ground");
 	sscanf(s.c_str(),"groundtex:%f:%f:%f:%f",&a,&b,&c,&d);
 	ground_tex_coord.tex = ground_tex;
@@ -154,7 +155,7 @@ void LandscapeOldStyle::load(const string& landscape_file, const string& landsca
 	ground_tex_coord.tex_coords[3] = d;
 
 	StelApp::getInstance().getTextureManager().setWrapMode(GL_REPEAT);
-	fog_tex = StelApp::getInstance().getTextureManager().createTexture(getTexturePath(pd.get_str("landscape", "fogtex"), landscapeId));
+	fog_tex = StelApp::getInstance().getTextureManager().createTexture(getTexturePath(pd.get_str("landscape", "fogtex").c_str(), landscapeId));
 	s = pd.get_str("landscape", "fog");
 	sscanf(s.c_str(),"fogtex:%f:%f:%f:%f",&a,&b,&c,&d);
 	fog_tex_coord.tex = fog_tex;
@@ -176,13 +177,13 @@ void LandscapeOldStyle::load(const string& landscape_file, const string& landsca
 
 
 // create from a hash of parameters (no ini file needed)
-void LandscapeOldStyle::create(bool _fullpath, stringHash_t param)
+void LandscapeOldStyle::create(bool _fullpath, QMap<QString, QString> param)
 {
-	name = StelUtils::stringToWstring(param["name"]);
+	name = param["name"];
 	valid_landscape = 1;  // assume valid if got here
 
 	// Load sides textures
-	nb_side_texs = StelUtils::stringToInt(param["nbsidetex"]);
+	nb_side_texs = param["nbsidetex"].toInt();
 	side_texs = new STextureSP[nb_side_texs];
 	
 	char tmp[255];
@@ -195,16 +196,16 @@ void LandscapeOldStyle::create(bool _fullpath, stringHash_t param)
 	}
 
 	// Init sides parameters
-	nb_side = StelUtils::stringToInt(param["nbside"]);
+	nb_side = param["nbside"].toInt();
 	sides = new landscape_tex_coord[nb_side];
-	string s;
+	QString s;
 	int texnum;
 	float a,b,c,d;
 	for (int i=0;i<nb_side;++i)
 	{
 		sprintf(tmp,"side%d",i);
 		s = param[tmp];
-		sscanf(s.c_str(),"tex%d:%f:%f:%f:%f",&texnum,&a,&b,&c,&d);
+		sscanf(s.toUtf8().constData(),"tex%d:%f:%f:%f:%f",&texnum,&a,&b,&c,&d);
 		sides[i].tex = side_texs[texnum];
 		sides[i].tex_coords[0] = a;
 		sides[i].tex_coords[1] = b;
@@ -213,11 +214,14 @@ void LandscapeOldStyle::create(bool _fullpath, stringHash_t param)
 		//printf("%f %f %f %f\n",a,b,c,d);
 	}
 
-	nb_decor_repeat = StelUtils::stringToInt(param["nb_decor_repeat"], 1);
+	bool ok;
+	nb_decor_repeat = param["nb_decor_repeat"].toInt(&ok);
+	if (!ok)
+		nb_decor_repeat = 1;
 
 	ground_tex = StelApp::getInstance().getTextureManager().createTexture(param["path"] + param["groundtex"]);
 	s = param["ground"];
-	sscanf(s.c_str(),"groundtex:%f:%f:%f:%f",&a,&b,&c,&d);
+	sscanf(s.toUtf8().constData(),"groundtex:%f:%f:%f:%f",&a,&b,&c,&d);
 	ground_tex_coord.tex = ground_tex;
 	ground_tex_coord.tex_coords[0] = a;
 	ground_tex_coord.tex_coords[1] = b;
@@ -227,21 +231,21 @@ void LandscapeOldStyle::create(bool _fullpath, stringHash_t param)
 	StelApp::getInstance().getTextureManager().setWrapMode(GL_REPEAT);
 	fog_tex = StelApp::getInstance().getTextureManager().createTexture(param["path"] + param["fogtex"]);
 	s = param["fog"];
-	sscanf(s.c_str(),"fogtex:%f:%f:%f:%f",&a,&b,&c,&d);
+	sscanf(s.toUtf8().constData(),"fogtex:%f:%f:%f:%f",&a,&b,&c,&d);
 	fog_tex_coord.tex = fog_tex;
 	fog_tex_coord.tex_coords[0] = a;
 	fog_tex_coord.tex_coords[1] = b;
 	fog_tex_coord.tex_coords[2] = c;
 	fog_tex_coord.tex_coords[3] = d;
 
-	fog_alt_angle = StelUtils::stringToDouble(param["fog_alt_angle"]);
-	fog_angle_shift = StelUtils::stringToDouble(param["fog_angle_shift"]);
-	decor_alt_angle = StelUtils::stringToDouble(param["decor_alt_angle"]);
-	decor_angle_shift = StelUtils::stringToDouble(param["decor_angle_shift"]);
-	decor_angle_rotatez = StelUtils::stringToDouble(param["decor_angle_rotatez"]);
-	ground_angle_shift = StelUtils::stringToDouble(param["ground_angle_shift"]);
-	ground_angle_rotatez = StelUtils::stringToDouble(param["ground_angle_rotatez"]);
-	draw_ground_first = StelUtils::stringToInt(param["draw_ground_first"]);
+	fog_alt_angle = param["fog_alt_angle"].toDouble();
+	fog_angle_shift = param["fog_angle_shift"].toDouble();
+	decor_alt_angle = param["decor_alt_angle"].toDouble();
+	decor_angle_shift = param["decor_angle_shift"].toDouble();
+	decor_angle_rotatez = param["decor_angle_rotatez"].toDouble();
+	ground_angle_shift = param["ground_angle_shift"].toDouble();
+	ground_angle_rotatez = param["ground_angle_rotatez"].toDouble();
+	draw_ground_first = param["draw_ground_first"].toInt();
 }
 
 void LandscapeOldStyle::draw(ToneReproducer * eye, const Projector* prj, const Navigator* nav)
@@ -375,7 +379,7 @@ LandscapeFisheye::~LandscapeFisheye()
 {
 }
 
-void LandscapeFisheye::load(const string& landscape_file, const string& landscapeId)
+void LandscapeFisheye::load(const QString& landscape_file, const QString& landscapeId)
 {
 	loadCommon(landscape_file, landscapeId);
 	
@@ -385,16 +389,19 @@ void LandscapeFisheye::load(const string& landscape_file, const string& landscap
 	string type = pd.get_str("landscape", "type");
 	if(type != "fisheye")
 	{
-		cerr << "Landscape type mismatch for landscape "<< landscapeId << ", expected fisheye, found " << type << ".  No landscape in use.\n";
+		qWarning() << "Landscape type mismatch for landscape "<< landscapeId << ", expected fisheye, found " << type.c_str() << ".  No landscape in use.\n";
 		valid_landscape = 0;
 		return;
 	}
-	create(name, 0, getTexturePath(pd.get_str("landscape", "maptex"), landscapeId), pd.get_double("landscape", "texturefov", 360));
+	create(name, 0, getTexturePath(pd.get_str("landscape", "maptex").c_str(), landscapeId),
+	       pd.get_double("landscape", "texturefov", 360),
+           pd.get_double("landscape", "angle_rotatez", 0.));
 }
 
 
 // create a fisheye landscape from basic parameters (no ini file needed)
-void LandscapeFisheye::create(const wstring _name, bool _fullpath, const string _maptex, double _texturefov)
+void LandscapeFisheye::create(const QString _name, bool _fullpath, const QString& _maptex,
+	                          double _texturefov, double _angle_rotatez)
 {
 	//	cout << _name << " " << _fullpath << " " << _maptex << " " << _texturefov << "\n";
 	valid_landscape = 1;  // assume ok...
@@ -402,6 +409,7 @@ void LandscapeFisheye::create(const wstring _name, bool _fullpath, const string
 	StelApp::getInstance().getTextureManager().setDefaultParams();
 	map_tex = StelApp::getInstance().getTextureManager().createTexture(_maptex);
 	tex_fov = _texturefov*M_PI/180.;
+    angle_rotatez = _angle_rotatez*M_PI/180.;
 }
 
 
@@ -419,8 +427,9 @@ void LandscapeFisheye::draw(ToneReproducer * eye, const Projector* prj, const Na
 	glEnable(GL_TEXTURE_2D);
 	glEnable(GL_BLEND);
 	map_tex->bind();
-	prj->setCurrentFrame(Projector::FRAME_LOCAL);
-	prj->sSphere_map(radius,40,20, tex_fov, 1);
+	prj->setCustomFrame(nav->get_local_to_eye_mat()
+	                    * Mat4d::zrotation(-angle_rotatez));
+	prj->sSphere_map(radius,40,20,tex_fov,1);
 
 	glDisable(GL_CULL_FACE);
 }
@@ -435,7 +444,7 @@ LandscapeSpherical::~LandscapeSpherical()
 {
 }
 
-void LandscapeSpherical::load(const string& landscape_file, const string& landscapeId)
+void LandscapeSpherical::load(const QString& landscape_file, const QString& landscapeId)
 {
 	loadCommon(landscape_file, landscapeId);
 	
@@ -445,24 +454,27 @@ void LandscapeSpherical::load(const string& landscape_file, const string& landsc
 	string type = pd.get_str("landscape", "type");
 	if(type != "spherical" )
 	{
-		cerr << "Landscape type mismatch for landscape "<< landscapeId << ", expected spherical, found " << type << ".  No landscape in use.\n";
+		qWarning() << "Landscape type mismatch for landscape "<< landscapeId << ", expected spherical, found " << type.c_str() << ".  No landscape in use.\n";
 		valid_landscape = 0;
 		return;
 	}
 
-	create(name, 0, getTexturePath(pd.get_str("landscape", "maptex"),landscapeId));
+	create(name, 0, getTexturePath(pd.get_str("landscape","maptex").c_str(),landscapeId),
+	       pd.get_double("landscape", "angle_rotatez", 0.));
 
 }
 
 
 // create a spherical landscape from basic parameters (no ini file needed)
-void LandscapeSpherical::create(const wstring _name, bool _fullpath, const string _maptex)
+void LandscapeSpherical::create(const QString _name, bool _fullpath, const QString& _maptex,
+	                            double _angle_rotatez)
 {
 	//	cout << _name << " " << _fullpath << " " << _maptex << " " << _texturefov << "\n";
 	valid_landscape = 1;  // assume ok...
 	name = _name;
 	StelApp::getInstance().getTextureManager().setDefaultParams();
 	map_tex = StelApp::getInstance().getTextureManager().createTexture(_maptex);
+    angle_rotatez = _angle_rotatez*M_PI/180.;
 }
 
 
@@ -492,8 +504,9 @@ void LandscapeSpherical::draw(ToneReproducer * eye, const Projector* prj, const
 
 	// TODO: verify that this works correctly for custom projections
 	// seam is at East
-	prj->setCurrentFrame(Projector::FRAME_LOCAL);
-	prj->sSphere(radius,1.0,40,20, 1);
+	prj->setCustomFrame(nav->get_local_to_eye_mat()
+	                    * Mat4d::zrotation(-angle_rotatez));
+	prj->sSphere(radius,1.0,40,20,1);
 
 	glDisable(GL_CULL_FACE);
 
