@@ -16,10 +16,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
- 
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <dirent.h>
+
+#include <QDebug>
+
 #include "LandscapeMgr.hpp"
 #include "Landscape.hpp"
 #include "Atmosphere.hpp"
@@ -136,8 +135,7 @@ void Cardinals::updateI18n()
 
 LandscapeMgr::LandscapeMgr() : atmosphere(NULL), cardinals_points(NULL), landscape(NULL), flagLandscapeSetsLocation(false)
 {
-	dependenciesOrder["draw"]="telescopes";
-	dependenciesOrder["update"]="ssystem";
+	setObjectName("LandscapeMgr");
 }
 
 LandscapeMgr::~LandscapeMgr()
@@ -148,6 +146,18 @@ LandscapeMgr::~LandscapeMgr()
 	landscape = NULL;
 }
 
+/*************************************************************************
+ Reimplementation of the getCallOrder method
+*************************************************************************/
+double LandscapeMgr::getCallOrder(StelModuleActionName actionName) const
+{
+	if (actionName==StelModule::ACTION_DRAW)
+		return StelApp::getInstance().getModuleMgr().getModule("TelescopeMgr")->getCallOrder(actionName)+10;
+	if (actionName==StelModule::ACTION_UPDATE)
+		return StelApp::getInstance().getModuleMgr().getModule("SolarSystem")->getCallOrder(actionName)+10;
+	return 0;
+}
+
 void LandscapeMgr::update(double deltaTime)
 {
 	atmosphere->update(deltaTime);
@@ -156,7 +166,7 @@ void LandscapeMgr::update(double deltaTime)
 	
 	// Compute the atmosphere color and intensity
 	// Compute the sun position in local coordinate
-	SolarSystem* ssystem = (SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("ssystem");
+	SolarSystem* ssystem = (SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("SolarSystem");
 	Navigator* nav = StelApp::getInstance().getCore()->getNavigation();
 	Projector* prj = StelApp::getInstance().getCore()->getProjection();
 	const Observer* obs = StelApp::getInstance().getCore()->getObservatory();
@@ -170,7 +180,7 @@ void LandscapeMgr::update(double deltaTime)
 	                          eye, prj, obs->get_latitude(), obs->get_altitude(),
 	                          15.f, 40.f);	// Temperature = 15c, relative humidity = 40%
 	
-	eye->set_world_adaptation_luminance(3.75+atmosphere->getAverageLuminance()*3.5);
+	eye->setWorldAdaptationLuminance(3.75+atmosphere->getAverageLuminance()*3.5);
 	
 	// Compute the ground luminance based on every planets around
 //	float groundLuminance = 0;
@@ -196,7 +206,7 @@ void LandscapeMgr::update(double deltaTime)
 //	groundLuminance*=atmosphere->getFadeIntensity();
 //	groundLuminance=atmosphere->getAverageLuminance()/50;
 //	cout << "Atmosphere lum=" << atmosphere->getAverageLuminance() << " ground lum=" <<  groundLuminance << endl;
-	//cout << "Adapted Atmosphere lum=" << eye->adapt_luminance(atmosphere->getAverageLuminance()) << " Adapted ground lum=" << eye->adapt_luminance(groundLuminance) << endl;
+	//cout << "Adapted Atmosphere lum=" << eye->adaptLuminance(atmosphere->getAverageLuminance()) << " Adapted ground lum=" << eye->adaptLuminance(groundLuminance) << endl;
 	
 	// compute global ground brightness in a simplistic way, directly in RGB
 	float landscapeBrightness = 0;
@@ -221,8 +231,12 @@ void LandscapeMgr::update(double deltaTime)
 	landscape->setBrightness(landscapeBrightness+0.05);
 }
 
-double LandscapeMgr::draw(Projector *prj, const Navigator *nav, ToneReproducer *eye)
+double LandscapeMgr::draw(StelCore* core)
 {
+	Navigator* nav = core->getNavigation();
+	Projector* prj = core->getProjection();
+	ToneReproducer* eye = core->getToneReproducer();
+	
 	// Draw the atmosphere
 	atmosphere->draw(prj);
 
@@ -235,11 +249,11 @@ double LandscapeMgr::draw(Projector *prj, const Navigator *nav, ToneReproducer *
 	return 0;
 }
 
-void LandscapeMgr::init(const InitParser& conf, LoadingBar& lb)
+void LandscapeMgr::init(const InitParser& conf)
 {
 	atmosphere = new Atmosphere();
 	landscape = new LandscapeOldStyle();
-	setLandscape(conf.get_str("init_location:landscape_name"));
+	setLandscapeByID(conf.get_str("init_location:landscape_name").c_str());
 	setFlagLandscape(conf.get_boolean("landscape", "flag_landscape", conf.get_boolean("landscape", "flag_ground", 1)));  // name change
 	setFlagFog(conf.get_boolean("landscape:flag_fog"));
 	setFlagAtmosphere(conf.get_boolean("landscape:flag_atmosphere"));
@@ -250,48 +264,48 @@ void LandscapeMgr::init(const InitParser& conf, LoadingBar& lb)
 	setFlagLandscapeSetsLocation(conf.get_boolean("landscape:flag_landscape_sets_location"));
 }
 
-void LandscapeMgr::setColorScheme(const InitParser& conf, const std::string& section)
+void LandscapeMgr::setColorScheme(const InitParser& conf, const QString& section)
 {
 	// Load colors from config file
-	string defaultColor = conf.get_str(section,"default_color");
-	setColorCardinalPoints(StelUtils::str_to_vec3f(conf.get_str(section,"cardinal_color", defaultColor)));
+	string defaultColor = conf.get_str(section.toStdString(),"default_color");
+	setColorCardinalPoints(StelUtils::str_to_vec3f(conf.get_str(section.toStdString(),"cardinal_color", defaultColor)));
 }
 
-bool LandscapeMgr::setLandscape(const string& new_landscape_name)
+
+bool LandscapeMgr::setLandscapeByName(const QString& newLandscapeName)
 {
-	if (new_landscape_name.empty())
+	if (newLandscapeName.isEmpty())
 		return 0;
 	
-	// we want to lookup the landscape ID (dir) from the name.
-	map<string,string> nameToDirMap = getNameToDirMap();
-	StelFileMgr& fileMan = StelApp::getInstance().getFileMgr();
-	Landscape* newLandscape = NULL;
-	
-	if (nameToDirMap[new_landscape_name] != "")
+	QMap<QString,QString> nameToDirMap = getNameToDirMap();
+	if (nameToDirMap.find(newLandscapeName)!=nameToDirMap.end())
 	{
-		try
-		{
-			newLandscape = create_from_file(fileMan.findFile("landscapes/" + nameToDirMap[new_landscape_name] + "/landscape.ini"), nameToDirMap[new_landscape_name]);
-		}
-		catch(exception& e)
-		{
-			cerr << "ERROR while loading landscape ";
-			cerr << "landscapes/" + nameToDirMap[new_landscape_name] + "/landscape.ini";
-			cerr << ", (" << e.what() << ")" << endl;
-		}
+		return setLandscapeByID(nameToDirMap[newLandscapeName]);
 	}
 	else
 	{
-		try
-		{
-			newLandscape = create_from_file(fileMan.findFile("landscapes/" + new_landscape_name + "/landscape.ini"), new_landscape_name);
-		}
-		catch(exception& e)
-		{
-			cerr << "ERROR while loading landscape ";
-			cerr << "landscapes/" + new_landscape_name + "/landscape.ini";
-			cerr << ", (" << e.what() << ")" << endl;
-		}
+		qWarning() << "Can't find a landscape with name=" << newLandscapeName << endl;
+		return false;
+	}
+}
+
+
+bool LandscapeMgr::setLandscapeByID(const QString& newLandscapeID)
+{
+	if (newLandscapeID.isEmpty())
+		return 0;
+	
+	// we want to lookup the landscape ID (dir) from the name.
+	StelFileMgr& fileMan = StelApp::getInstance().getFileMgr();
+	Landscape* newLandscape = NULL;
+	
+	try
+	{
+		newLandscape = createFromFile(fileMan.findFile("landscapes/" + newLandscapeID + "/landscape.ini"), newLandscapeID);
+	}
+	catch(exception& e)
+	{
+		qWarning() << "ERROR while loading landscape " << "landscapes/" + newLandscapeID + "/landscape.ini" << ", (" << e.what() << ")" << endl;
 	}
 
 	if(!newLandscape)
@@ -305,13 +319,13 @@ bool LandscapeMgr::setLandscape(const string& new_landscape_name)
 		delete landscape;
 		landscape = newLandscape;
 	}
-	landscapeSectionName = new_landscape_name;
+	currentLandscapeID = newLandscapeID;
 	
 	if (getFlagLandscapeSetsLocation())
 	{
 		// Set the planet and moveto the right location
 		if (landscape->getPlanet()!="") 
-			StelApp::getInstance().getCore()->setHomePlanet(landscape->getPlanet());
+			StelApp::getInstance().getCore()->getObservatory()->setHomePlanet(landscape->getPlanet());
 	
 		if (landscape->getLongitude() > -500 && landscape->getLatitude() > -500) 
 		{
@@ -320,7 +334,7 @@ bool LandscapeMgr::setLandscape(const string& new_landscape_name)
 				landscape->getLongitude(),
 				landscape->getAltitude(),
 				0,
-    				landscape->getName());
+    			landscape->getName().toStdWString());
 		}
 	
 	}
@@ -330,9 +344,9 @@ bool LandscapeMgr::setLandscape(const string& new_landscape_name)
 
 //! Load a landscape based on a hash of parameters mirroring the landscape.ini file
 //! and make it the current landscape
-bool LandscapeMgr::loadLandscape(stringHash_t& param)
+bool LandscapeMgr::loadLandscape(QMap<QString, QString>& param)
 {
-	Landscape* newLandscape = create_from_hash(param);
+	Landscape* newLandscape = createFromHash(param);
 	if(!newLandscape)
 		return 0;
 
@@ -344,7 +358,7 @@ bool LandscapeMgr::loadLandscape(stringHash_t& param)
 		delete landscape;
 		landscape = newLandscape;
 	}
-	landscapeSectionName = param["name"];
+	currentLandscapeID = param["name"];
 	// probably not particularly useful, as not in landscape.ini file
 
 	return 1;
@@ -376,76 +390,115 @@ bool LandscapeMgr::getFlagFog(void) const
 	return landscape->getFlagShowFog();
 }
 
-wstring LandscapeMgr::getLandscapeName(void)
+QString LandscapeMgr::getLandscapeName(void)
 {
 	return landscape->getName();
 }
 
-wstring LandscapeMgr::getLandscapeAuthorName(void)
+QString LandscapeMgr::getLandscapeAuthorName(void)
 {
 	return landscape->getAuthorName();
 }
 
-wstring LandscapeMgr::getLandscapeDescription(void)
+QString LandscapeMgr::getLandscapeDescription(void)
 {
 	return landscape->getDescription();
 }
 
-wstring LandscapeMgr::getLandscapePlanetName(void) {
-	string desc("");
+QString LandscapeMgr::getLandscapePlanetName(void) 
+{
+	QString desc;
 	if (landscape->getPlanet() != "")
 	{
 		desc = landscape->getPlanet();
 	}
-	return StelUtils::stringToWstring(desc);
+	return desc;
 }
     
-wstring LandscapeMgr::getLandscapeLocationDescription(void) {
-	string desc;
+QString LandscapeMgr::getLandscapeLocationDescription(void) 
+{
+	QString desc;
 //cerr << landscape->getLongitude() << " " << landscape->getLatitude() << endl;
 	if (landscape->getLongitude()>-500.0 && landscape->getLatitude()>-500.0)
 	{
 		desc = "lon " + StelUtils::radToDmsStrAdapt(landscape->getLongitude() * M_PI/180.);
 		desc += ", lat " + StelUtils::radToDmsStrAdapt(landscape->getLatitude() *M_PI/180.);
-		desc += ", " + StelUtils::doubleToString(landscape->getAltitude()) + " m";
+		desc += QString(", ") + StelUtils::doubleToString(landscape->getAltitude()).c_str() + " m";
 	}
-	return StelUtils::stringToWstring(desc);
+	return desc;
 }
-    
-	//! Set flag for displaying Cardinals Points
-	void LandscapeMgr::setFlagCardinalsPoints(bool b) {cardinals_points->setFlagShow(b);}
-	//! Get flag for displaying Cardinals Points
-	bool LandscapeMgr::getFlagCardinalsPoints(void) const {return cardinals_points->getFlagShow();}
 
-	//! Set Cardinals Points color
-	void LandscapeMgr::setColorCardinalPoints(const Vec3f& v) {cardinals_points->setColor(v); }
-	//! Get Cardinals Points color
-	Vec3f LandscapeMgr::getColorCardinalPoints(void) const {return cardinals_points->get_color();}
+//! Set flag for displaying Cardinals Points
+void LandscapeMgr::setFlagCardinalsPoints(bool b) 
+{
+	cardinals_points->setFlagShow(b);
+}
+
+//! Get flag for displaying Cardinals Points
+bool LandscapeMgr::getFlagCardinalsPoints(void) const 
+{
+	return cardinals_points->getFlagShow();
+}
+
+//! Set Cardinals Points color
+void LandscapeMgr::setColorCardinalPoints(const Vec3f& v) 
+{
+	cardinals_points->setColor(v); 
+}
+
+//! Get Cardinals Points color
+Vec3f LandscapeMgr::getColorCardinalPoints(void) const 
+{
+	return cardinals_points->get_color();
+}
 	
-	///////////////////////////////////////////////////////////////////////////////////////
-	// Atmosphere
-	//! Set flag for displaying Atmosphere
-	void LandscapeMgr::setFlagAtmosphere(bool b) {atmosphere->setFlagShow(b);}
-	//! Get flag for displaying Atmosphere
-	bool LandscapeMgr::getFlagAtmosphere(void) const {return atmosphere->getFlagShow();}
+///////////////////////////////////////////////////////////////////////////////////////
+// Atmosphere
+//! Set flag for displaying Atmosphere
+void LandscapeMgr::setFlagAtmosphere(bool b) 
+{
+	atmosphere->setFlagShow(b);
+}
 
-	//! Set atmosphere fade duration in s
-	void LandscapeMgr::setAtmosphereFadeDuration(float f) {atmosphere->setFadeDuration(f);}
-	//! Get atmosphere fade duration in s
-	float LandscapeMgr::getAtmosphereFadeDuration(void) const {return atmosphere->getFadeDuration();}
+//! Get flag for displaying Atmosphere
+bool LandscapeMgr::getFlagAtmosphere(void) const 
+{
+	return atmosphere->getFlagShow();
+}
 
-	//! Set light pollution luminance level
-    void LandscapeMgr::setAtmosphereLightPollutionLuminance(float f) {atmosphere->setLightPollutionLuminance(f);}
-	//! Get light pollution luminance level
-    float LandscapeMgr::getAtmosphereLightPollutionLuminance(void) const {return atmosphere->getLightPollutionLuminance();}
+//! Set atmosphere fade duration in s
+void LandscapeMgr::setAtmosphereFadeDuration(float f) 
+{
+	atmosphere->setFadeDuration(f);
+}
 
-	
-	float LandscapeMgr::getLuminance(void) {return atmosphere->getRealDisplayIntensityFactor();}
+//! Get atmosphere fade duration in s
+float LandscapeMgr::getAtmosphereFadeDuration(void) const 
+{
+	return atmosphere->getFadeDuration();
+}
 
-Landscape* LandscapeMgr::create_from_file(const string& landscape_file, const string& landscapeId)
+//! Set light pollution luminance level
+void LandscapeMgr::setAtmosphereLightPollutionLuminance(float f) 
+{
+	atmosphere->setLightPollutionLuminance(f);
+}
+
+//! Get light pollution luminance level
+float LandscapeMgr::getAtmosphereLightPollutionLuminance(void) const 
+{
+	return atmosphere->getLightPollutionLuminance();
+}
+
+float LandscapeMgr::getLuminance(void) 
+{
+	return atmosphere->getRealDisplayIntensityFactor();
+}
+
+Landscape* LandscapeMgr::createFromFile(const QString& landscapeFile, const QString& landscapeId)
 {
 	InitParser pd;	// The landscape data ini file parser
-	pd.load(landscape_file);
+	pd.load(landscapeFile);
 	string s;
 	s = pd.get_str("landscape", "type");
 	Landscape* ldscp = NULL;
@@ -470,13 +523,11 @@ Landscape* LandscapeMgr::create_from_file(const string& landscape_file, const st
 		ldscp = new LandscapeFisheye();
 	}
 	
-	ldscp->load(landscape_file, landscapeId);
+	ldscp->load(landscapeFile, landscapeId);
 	return ldscp;
 }
 
-// create landscape from parameters passed in a hash (same keys as with ini file)
-// NOTE: maptex must be full path and filename
-Landscape* LandscapeMgr::create_from_hash(stringHash_t & param)
+Landscape* LandscapeMgr::createFromHash(QMap<QString, QString>& param)
 {
 	// NOTE: textures should be full filename (and path)
 	if (param["type"]=="old_style")
@@ -488,13 +539,15 @@ Landscape* LandscapeMgr::create_from_hash(stringHash_t & param)
 	else if (param["type"]=="spherical")
 	{
 		LandscapeSpherical* ldscp = new LandscapeSpherical();
-		ldscp->create(StelUtils::stringToWstring(param["name"]), 1, param["path"] + param["maptex"]);
+		ldscp->create(param["name"], 1, param["path"] + param["maptex"],param["angle_rotatez"].toDouble());
 		return ldscp;
 	}
 	else
 	{   //	if (s=="fisheye")
 		LandscapeFisheye* ldscp = new LandscapeFisheye();
-		ldscp->create(StelUtils::stringToWstring(param["name"]), 1, param["path"] + param["maptex"], StelUtils::stringToDouble(param["texturefov"]));
+		ldscp->create(param["name"], 1, param["path"] + param["maptex"],
+		              param["texturefov"].toDouble(),
+                      param["angle_rotatez"].toDouble());
 		return ldscp;
 	}
 }
@@ -504,31 +557,31 @@ Landscape* LandscapeMgr::create_from_hash(stringHash_t & param)
  landscape.ini file).  The result is a string with each name separated
  by a '\n' character.
  *********************************************************************/
-string LandscapeMgr::getLandscapeNames()
+QString LandscapeMgr::getAllLandscapeNames()
 {
-	map<string,string> nameToDirMap = getNameToDirMap();
- 	string result("");
+	QMap<QString,QString> nameToDirMap = getNameToDirMap();
+ 	QString result;
 	
 	// We just look over the map of names to IDs and extract the keys
-	for(map<string,string>::iterator i=nameToDirMap.begin();
-		   i!=nameToDirMap.end();
-		   i++)
+	foreach (QString i, nameToDirMap.keys())
 	{
-		result += i->first + '\n';
+		result += i + '\n';
 	}
 
 	return result;
 }
 
-string LandscapeMgr::nameToKey(const string& name)
+QString LandscapeMgr::nameToID(const QString& name)
 {
-	map<string,string> nameToDirMap = getNameToDirMap();
+	QMap<QString,QString> nameToDirMap = getNameToDirMap();
 	
-	if ( nameToDirMap[name] == "" ) {
+	if (nameToDirMap.find(name)!=nameToDirMap.end())
+	{
  		assert(0);
 		return "error";
 	}
-	else {
+	else
+	{
 		return nameToDirMap[name];
 	}
 }
@@ -536,12 +589,11 @@ string LandscapeMgr::nameToKey(const string& name)
 /****************************************************************************
  get a map of landscape name (from landscape.ini name field) to ID (dir name)
  ****************************************************************************/
-std::map<std::string,std::string> LandscapeMgr::getNameToDirMap(void)
+QMap<QString,QString> LandscapeMgr::getNameToDirMap(void)
 {
-	set<string> landscapeDirs;
-	map<string,string> result;
+	QSet<QString> landscapeDirs;
+	QMap<QString,QString> result;
 	StelFileMgr& fileMan(StelApp::getInstance().getFileMgr());
-	
 	try
 	{
 		landscapeDirs = fileMan.listContents("landscapes",StelFileMgr::DIRECTORY);
@@ -551,15 +603,14 @@ std::map<std::string,std::string> LandscapeMgr::getNameToDirMap(void)
 		cerr << "ERROR while trying list list landscapes:" << e.what() << endl;	
 	}
 	
-	for(set<string>::iterator dir=landscapeDirs.begin(); dir!=landscapeDirs.end(); dir++)
+	foreach (QString dir, landscapeDirs)
 	{
 		try
 		{
 			InitParser pd;
-			pd.load(fileMan.findFile("landscapes/" + *dir + "/landscape.ini"));
-			string k = pd.get_str("landscape", "name");
-			// cerr << "DEBUG LandscapeMgr::getNameToDirMap adding " << k << " -> " << *dir << endl;
-			result[k] = *dir;
+			pd.load(fileMan.findFile("landscapes/" + dir + "/landscape.ini"));
+			QString k = pd.get_str("landscape", "name").c_str();
+			result[k] = dir;
 		}
 		catch (exception& e)
 		{
