@@ -1,12 +1,33 @@
+/*
+ * Stellarium
+ * Copyright (C) 2007 Fabien Chereau
+ * 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ */
+
 #include "MovementMgr.hpp"
 #include "StelObjectMgr.hpp"
 #include "StelApp.hpp"
+#include "StelCore.hpp"
 #include "InitParser.hpp"
 #include "Navigator.hpp"
 
 MovementMgr::MovementMgr(StelCore* acore) : core(acore), flag_lock_equ_pos(false), flagTracking(false), is_mouse_moving_horiz(false), is_mouse_moving_vert(false), 
 	flag_auto_move(0), deltaFov(0.), deltaAlt(0.), deltaAz(0.), move_speed(0.00025), flag_auto_zoom(0)
 {
+	setObjectName("MovementMgr");
 	is_dragging = false;
 }
 
@@ -14,7 +35,7 @@ MovementMgr::~MovementMgr()
 {
 }
 
-void MovementMgr::init(const InitParser& conf, LoadingBar& lb)
+void MovementMgr::init(const InitParser& conf)
 {
 	FlagEnableMoveMouse	= conf.get_boolean("navigation","flag_enable_move_mouse",1);
 	MouseZoom			= conf.get_int("navigation","mouse_zoom",30);
@@ -92,12 +113,12 @@ bool MovementMgr::handleKeys(StelKey key, StelMod mod, Uint16 unicode, Uint8 sta
 		if (key==StelKey_RIGHT) turn_right(1);
 		if (key==StelKey_UP)
 		{
-			if (mod & StelMod_CTRL) zoom_in(1);
+			if (mod & COMPATIBLE_StelMod_CTRL) zoom_in(1);
 			else turn_up(1);
 		}
 		if (key==StelKey_DOWN)
 		{
-			if (mod & StelMod_CTRL) zoom_out(1);
+			if (mod & COMPATIBLE_StelMod_CTRL) zoom_out(1);
 			else turn_down(1);
 		}
 		if (key==StelKey_PAGEUP) zoom_in(1);
@@ -108,7 +129,7 @@ bool MovementMgr::handleKeys(StelKey key, StelMod mod, Uint16 unicode, Uint8 sta
 		// When a deplacement key is released stop mooving
 		if (key==StelKey_LEFT) turn_left(0);
 		if (key==StelKey_RIGHT) turn_right(0);
-		if (mod & StelMod_CTRL)
+		if (mod & COMPATIBLE_StelMod_CTRL)
 		{
 			if (key==StelKey_UP) zoom_in(0);
 			if (key==StelKey_DOWN) zoom_out(0);
@@ -182,7 +203,7 @@ bool MovementMgr::handleMouseClicks(Uint16 x, Uint16 y, Uint8 button, Uint8 stat
 /*************************************************************************
  The selected objects changed, follow it it we were already following another one
 *************************************************************************/ 
-void MovementMgr::selectedObjectChangeCallBack()
+void MovementMgr::selectedObjectChangeCallBack(StelModuleSelectAction action)
 {
 	// If an object was selected keep the earth following
 	if (StelApp::getInstance().getStelObjectMgr().getWasSelected())
@@ -426,7 +447,7 @@ void MovementMgr::setFlagTracking(bool b)
 	}
 	else
 	{
-		moveTo(StelApp::getInstance().getStelObjectMgr().getSelectedObject()[0]->getEarthEquatorialPos(core->getNavigation()), getAutomoveDuration());
+		moveTo(StelApp::getInstance().getStelObjectMgr().getSelectedObject()[0]->getEarthEquatorialPos(core->getNavigation()), getAutoMoveDuration());
 		flagTracking=true;
 	}
 }
@@ -693,3 +714,8 @@ void MovementMgr::change_fov(double deltaFov)
 	// if we are zooming in or out
 	if (deltaFov) core->getProjection()->setFov(core->getProjection()->getFov()+deltaFov);
 }
+
+double MovementMgr::getAimFov(void) const
+{
+	return (flag_auto_zoom ? zoom_move.aim : core->getProjection()->getFov());
+}
