@@ -21,6 +21,8 @@
 
 #include <fstream>
 #include <algorithm>
+#include <QDebug>
+#include <QFile>
 
 #include "StelApp.hpp"
 #include "NebulaMgr.hpp"
@@ -36,6 +38,8 @@
 #include "StelSkyCultureMgr.hpp"
 #include "StelFileMgr.hpp"
 #include "InitParser.hpp"
+#include "StelModuleMgr.hpp"
+#include "StelCore.hpp"
 
 void NebulaMgr::setNamesColor(const Vec3f& c) {Nebula::label_color = c;}
 const Vec3f &NebulaMgr::getNamesColor(void) const {return Nebula::label_color;}
@@ -47,9 +51,9 @@ void NebulaMgr::setFlagBright(bool b) {Nebula::flagBright = b;}
 bool NebulaMgr::getFlagBright(void) const {return Nebula::flagBright;}
 
 
-NebulaMgr::NebulaMgr(void) : displayNoTexture(false) {
-	nebZones = new vector<Nebula*>[nebGrid.getNbPoints()];
-	dependenciesOrder["draw"]="milkyway";
+NebulaMgr::NebulaMgr(void) : nebGrid(10000), displayNoTexture(false)
+{
+	setObjectName("NebulaMgr");
 }
 
 NebulaMgr::~NebulaMgr()
@@ -60,11 +64,21 @@ NebulaMgr::~NebulaMgr()
 		delete (*iter);
 	}
 	
-	delete[] nebZones;
+	Nebula::tex_circle = STextureSP();
+}
+
+/*************************************************************************
+ Reimplementation of the getCallOrder method
+*************************************************************************/
+double NebulaMgr::getCallOrder(StelModuleActionName actionName) const
+{
+	if (actionName==StelModule::ACTION_DRAW)
+		return StelApp::getInstance().getModuleMgr().getModule("MilkyWay")->getCallOrder(actionName)+10;
+	return 0;
 }
 
 // read from stream
-void NebulaMgr::init(const InitParser& conf, LoadingBar& lb)
+void NebulaMgr::init(const InitParser& conf)
 {
 	// TODO: mechanism to specify which sets get loaded at start time.
 	// candidate methods:
@@ -73,7 +87,7 @@ void NebulaMgr::init(const InitParser& conf, LoadingBar& lb)
 	// 3. flag in nebula_textures.fab (yuk)
 	// 4. info.ini file in each set containing a "load at startup" item
 	// For now (0.9.0), just load the default set
-	loadNebulaSet("default", lb);
+	loadNebulaSet("default");
 
 	double fontSize = 12;
 	Nebula::nebula_font = &StelApp::getInstance().getFontManager().getStandardFont(StelApp::getInstance().getLocaleMgr().getSkyLanguage(), fontSize);
@@ -97,8 +111,12 @@ void NebulaMgr::init(const InitParser& conf, LoadingBar& lb)
 }
 
 // Draw all the Nebulae
-double NebulaMgr::draw(Projector* prj, const Navigator * nav, ToneReproducer* eye)
+double NebulaMgr::draw(StelCore* core)
 {
+	Navigator* nav = core->getNavigation();
+	Projector* prj = core->getProjection();
+	ToneReproducer* eye = core->getToneReproducer();
+	
 	Nebula::hints_brightness = hintsFader.getInterstate()*flagShow.getInterstate();
 	Nebula::flagShowTexture = flagShowTexture;
 	
@@ -107,56 +125,46 @@ double NebulaMgr::draw(Projector* prj, const Navigator * nav, ToneReproducer* ey
 	glBlendFunc(GL_ONE, GL_ONE);
 
 	Vec3f pXYZ;
-
-	// Find the star zones which are in the screen
-	int nbZones=0;
-	// FOV is currently measured vertically, so need to adjust for wide screens
-	// TODO: projector should probably use largest measurement itself
-	float max_fov = MY_MAX( prj->getFov(), prj->getFov()*prj->getViewportWidth()/prj->getViewportHeight());
-	nbZones = nebGrid.Intersect(nav->getPrecEquVision(), max_fov*M_PI/180.f*1.2f);
-	static int * zoneList = nebGrid.getResult();
 	
-    prj->setCurrentFrame(Projector::FRAME_J2000);
+	prj->setCurrentFrame(Projector::FRAME_J2000);
+	// Use a 1 degree margin
+	const double margin = 1.*M_PI/180.*prj->getPixelPerRadAtCenter();
+	const StelGeom::ConvexPolygon& p = prj->getViewportConvexPolygon(margin, margin);
+	nebGrid.filterIntersect(p);
 	
 	// Print all the stars of all the selected zones
-	static vector<Nebula *>::iterator end;
-	static vector<Nebula *>::iterator iter;
 	Nebula* n;
 
-	  // speed up the computation of n->getOnScreenSize(prj, nav)>5:
-	const float size_limit = 5.0 * (M_PI/180.0) * (prj->getFov()/prj->getViewportHeight());
+	// speed up the computation of n->getOnScreenSize(prj, nav)>5:
+	const float size_limit = 5./prj->getPixelPerRadAtCenter()*180./M_PI;
 
-	for(int i=0;i<nbZones;++i)
+	for (TreeGrid::const_iterator iter = nebGrid.begin(); iter != nebGrid.end(); ++iter)
 	{
-		end = nebZones[zoneList[i]].end();
-	    for(iter = nebZones[zoneList[i]].begin(); iter!=end; ++iter)
-		{
-			n = *iter;
-			if (!displayNoTexture && !n->hasTex()) continue;
+		n = static_cast<Nebula*>(*iter);
+		if (!displayNoTexture && !n->hasTex()) continue;
 
-			// improve performance by skipping if too small to see
-			// TODO: skip if too faint to see
-			if (n->angular_size>size_limit || (hintsFader.getInterstate()>0.0001 && n->mag <= getMaxMagHints()))
+		// improve performance by skipping if too small to see
+		// TODO: skip if too faint to see
+		if (n->angular_size>size_limit || (hintsFader.getInterstate()>0.0001 && n->mag <= getMaxMagHints()))
+		{
+			prj->project(n->XYZ,n->XY);
+
+			if (n->angular_size>size_limit)
 			{
-				prj->project(n->XYZ,n->XY);
-	
-				if (n->angular_size>size_limit)
-				{
-					if (n->hasTex())
-						n->draw_tex(prj, nav, eye);
-					else n->draw_no_tex(prj, nav, eye);
-				}
-	
-				if (hintsFader.getInterstate()>0.00001 && n->mag <= getMaxMagHints())
-				{
-					n->draw_name(prj);
-					n->draw_circle(prj, nav);
-				} 
+				if (n->hasTex())
+					n->draw_tex(prj, nav, eye);
+				else n->draw_no_tex(prj, nav, eye);
 			}
+
+			if (hintsFader.getInterstate()>0.00001 && n->mag <= getMaxMagHints())
+			{
+				n->draw_name(prj);
+				n->draw_circle(prj, nav);
+			} 
 		}
 	}
-	
 	drawPointer(prj, nav);
+	//nebGrid.draw(prj, p);
 
 	return 0;
 }
@@ -180,8 +188,8 @@ void NebulaMgr::drawPointer(const Projector* prj, const Navigator * nav)
         glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA); // Normal transparency mode
 
 		float size = obj->getOnScreenSize(prj, nav);
-		size+=20.f + 10.f*std::sin(2.f * StelApp::getInstance().getTotalRunTime());
 
+		size+=20.f + 10.f*std::sin(2.f * StelApp::getInstance().getTotalRunTime());
 		prj->drawSprite2dMode(screenpos[0]-size/2, screenpos[1]-size/2, 20, 90);
 		prj->drawSprite2dMode(screenpos[0]-size/2, screenpos[1]+size/2, 20, 0);
 		prj->drawSprite2dMode(screenpos[0]+size/2, screenpos[1]+size/2, 20, -90);
@@ -189,21 +197,20 @@ void NebulaMgr::drawPointer(const Projector* prj, const Navigator * nav)
 	}
 }
 
-void NebulaMgr::updateSkyCulture(LoadingBar& lb)
+void NebulaMgr::updateSkyCulture()
 {;}
 
-void NebulaMgr::setColorScheme(const InitParser& conf, const std::string& section)
+void NebulaMgr::setColorScheme(const InitParser& conf, const QString& section)
 {
 	// Load colors from config file
-	string defaultColor = conf.get_str(section,"default_color");
-	setNamesColor(StelUtils::str_to_vec3f(conf.get_str(section,"nebula_label_color", defaultColor)));
-	setCirclesColor(StelUtils::str_to_vec3f(conf.get_str(section,"nebula_circle_color", defaultColor)));
+	string defaultColor = conf.get_str(section.toStdString(),"default_color");
+	setNamesColor(StelUtils::str_to_vec3f(conf.get_str(section.toStdString(),"nebula_label_color", defaultColor)));
+	setCirclesColor(StelUtils::str_to_vec3f(conf.get_str(section.toStdString(),"nebula_circle_color", defaultColor)));
 }
 
 // search by name
 StelObject* NebulaMgr::search(const string& name)
 {
-
 	string uname = name;
 	transform(uname.begin(), uname.end(), uname.begin(), ::toupper);
 	vector <Nebula*>::const_iterator iter;
@@ -249,21 +256,19 @@ StelObject* NebulaMgr::search(const string& name)
 	if (cat == "IC") return searchIC(num);
 	// if (cat == "UGC") return searchUGC(num);
 	return NULL;
-
-
 }
 
-void NebulaMgr::loadNebulaSet(const string& setName, LoadingBar& lb)
+void NebulaMgr::loadNebulaSet(const QString& setName)
 {
 	try
 	{
-		loadNGC(StelApp::getInstance().getFileMgr().findFile("nebulae/" + setName + "/ngc2000.dat"), lb);
+		loadNGC(StelApp::getInstance().getFileMgr().findFile("nebulae/" + setName + "/ngc2000.dat"));
 		loadNGCNames(StelApp::getInstance().getFileMgr().findFile("nebulae/" + setName + "/ngc2000names.dat"));
-		loadTextures(setName, lb);
+		loadTextures(setName);
 	}
-	catch(exception& e)
+	catch (exception& e)
 	{
-		cerr << "ERROR while loading nebula data set " << setName << ": " << e.what() << endl;
+		qWarning() << "ERROR while loading nebula data set " << setName << ": " << e.what();
 	}
 }
 
@@ -290,7 +295,7 @@ StelObject* NebulaMgr::search(Vec3f Pos)
 }
 
 // Return a stl vector containing the nebulas located inside the lim_fov circle around position v
-vector<StelObjectP> NebulaMgr::searchAround(const Vec3d& av, double limitFov, const Navigator * nav, const Projector * prj) const
+vector<StelObjectP> NebulaMgr::searchAround(const Vec3d& av, double limitFov, const StelCore* core) const
 {
 	vector<StelObjectP> result;
 	if (!getFlagShow())
@@ -333,11 +338,11 @@ Nebula *NebulaMgr::searchM(unsigned int M)
 Nebula *NebulaMgr::searchNGC(unsigned int NGC)
 {
 	vector<Nebula *>::iterator iter;
-	for(iter=neb_array.begin();iter!=neb_array.end();iter++)
+	for(iter=neb_array.begin();iter!=neb_array.end();++iter)
 	{
-		if ((*iter)->NGC_nb == NGC) return (*iter);
+		if ((*iter)->NGC_nb == NGC)
+			return (*iter);
 	}
-
 	return NULL;
 }
 
@@ -364,17 +369,19 @@ Nebula *NebulaMgr::searchIC(unsigned int IC)
 }*/
 
 // read from stream
-bool NebulaMgr::loadNGC(const string& catNGC, LoadingBar& lb)
+bool NebulaMgr::loadNGC(const QString& catNGC)
 {
 	char recordstr[512];
 	unsigned int i;
 	unsigned int data_drop;
 
+	LoadingBar& lb = *StelApp::getInstance().getLoadingBar();
+	
 	cout << "Loading NGC data... ";
-	FILE * ngcFile = fopen(catNGC.c_str(),"rb");
+	FILE * ngcFile = fopen(QFile::encodeName(catNGC).constData(),"rb");
 	if (!ngcFile)
 	{
-		cerr << "NGC data file " << catNGC << " not found" << endl;
+		qWarning() << "NGC data file " << catNGC << " not found";
 		return false;
 	}
 
@@ -405,25 +412,25 @@ bool NebulaMgr::loadNGC(const string& catNGC, LoadingBar& lb)
 		else
 		{
 			neb_array.push_back(e);
-			nebZones[nebGrid.GetNearest(e->XYZ)].push_back(e);
+			nebGrid.insert(e);
 		}
 		i++;
 	}
 	fclose(ngcFile);
 	printf("(%d items loaded [%d dropped])\n", i, data_drop);
-
+    //printf("Grid depth = %d\n", nebGrid.depth());
 	return true;
 }
 
 
-bool NebulaMgr::loadNGCNames(const string& catNGCNames)
+bool NebulaMgr::loadNGCNames(const QString& catNGCNames)
 {
 	char recordstr[512];
 	cout << "Loading NGC name data...";
-	FILE * ngcNameFile = fopen(catNGCNames.c_str(),"rb");
+	FILE * ngcNameFile = fopen(QFile::encodeName(catNGCNames).constData(),"rb");
 	if (!ngcNameFile)
 	{
-		cerr << "NGC name data file " << catNGCNames << " not found." << endl;
+		qWarning() << "NGC name data file " << catNGCNames << " not found.";
 		return false;
 	}
 
@@ -446,16 +453,17 @@ bool NebulaMgr::loadNGCNames(const string& catNGCNames)
 			e = (Nebula*)searchNGC(nb);
 		}
 
+		strncpy(n, recordstr, 36);
+		// trim the white spaces at the back
+		n[36] = '\0';
+		k = 36;
+		while (n[--k] == ' ' && k >= 0)
+		{
+			n[k] = '\0';
+		}
+		
 		if (e)
 		{
-			strncpy(n, recordstr, 36);
-			// trim the white spaces at the back
-			n[36] = '\0';
-			k = 36;
-			while (n[--k] == ' ' && k >= 0)
-			{
-				n[k] = '\0';
-			}
 			// If the name is not a messier number perhaps one is already
 			// defined for this object
 			if (strncmp(n, "M ",2))
@@ -489,17 +497,18 @@ bool NebulaMgr::loadNGCNames(const string& catNGCNames)
 	return true;
 }
 
-bool NebulaMgr::loadTextures(const string& setName, LoadingBar& lb)
+bool NebulaMgr::loadTextures(const QString& setName)
 {
-	cout << "Loading Nebula Textures for set " << setName << "...";
-	string texFile;
+	LoadingBar& lb = *StelApp::getInstance().getLoadingBar();
+	cout << "Loading Nebula Textures for set " << qPrintable(setName) << "...";
+	QString texFile;
 	try
 	{
 		texFile = StelApp::getInstance().getFileMgr().findFile("nebulae/"+setName+"/nebula_textures.fab");
-		std::ifstream inf(texFile.c_str());
+		std::ifstream inf(QFile::encodeName(texFile).constData());
 		if (!inf.is_open())
 		{
-			throw(runtime_error("cannot open file for reading: " + texFile));
+			throw (runtime_error(string("cannot open file for reading: ") + qPrintable(texFile)));
 		}
 	
 		// determine total number to be loaded for percent complete display
@@ -518,7 +527,7 @@ bool NebulaMgr::loadTextures(const string& setName, LoadingBar& lb)
 		int NGC;
 		while(!getline(inf, record).eof())
 		{
-		// Draw loading bar
+			// Draw loading bar
 			if (record.empty() || record[0]=='#')
 				continue;
 
@@ -534,23 +543,26 @@ bool NebulaMgr::loadTextures(const string& setName, LoadingBar& lb)
 			{
 				if (!e->readTexture(setName, record)) // reading error
 				{
-					cerr << "Error while reading nebula texture " << setName << "/" << e->englishName << endl;
+					cerr << "Error while reading nebula texture " << qPrintable(setName) << "/" << e->englishName << endl;
 					cerr << "Record was " << record << endl;
 				}
 			} 
 			else
 			{
-			// Allow non NGC nebulas/textures!
-				if (NGC != -1) cout << "Nebula with unrecognized NGC number " << NGC << endl;
+				// Allow non NGC nebulas/textures!
+				if (NGC != -1)
+					cout << "Nebula with unrecognized NGC number " << NGC << endl;
 				e = new Nebula;
-				if (!e->readTexture(setName, record)) { // reading error
+				if (!e->readTexture(setName, record))
+				{
+					// reading error
 					cerr << "Error while reading texture " << e->englishName << endl;
 					delete e;
 				} 
 				else 
 				{
 					neb_array.push_back(e);
-					nebZones[nebGrid.GetNearest(e->XYZ)].push_back(e);
+					nebGrid.insert(e);
 				}
 			}
 	
@@ -558,15 +570,13 @@ bool NebulaMgr::loadTextures(const string& setName, LoadingBar& lb)
 		cout << "(" << total << " textures loaded)" << endl;
 		return true;	
 	}
-	catch(exception& e)
+	catch (exception& e)
 	{
-		cerr << "ERROR: unable to load nebula texture set \"" << setName << "\": " << e.what() << endl;
+		qWarning() << "ERROR: unable to load nebula texture set \"" << setName << "\": " << e.what();
 		return false;		
 	}
 }
 
-//! @brief Update i18 names from english names according to passed translator
-//! The translation is done using gettext with translated strings defined in translations.h
 void NebulaMgr::updateI18n()
 {
 	Translator trans = StelApp::getInstance().getLocaleMgr().getSkyTranslator();
