@@ -21,6 +21,9 @@
 #include <sstream>
 #include <iomanip>
 
+#include <QTextStream>
+#include <QDebug>
+
 #include "StelApp.hpp"
 #include "SolarSystem.hpp"
 #include "STexture.hpp"
@@ -31,6 +34,7 @@
 #include "sideral_time.h"
 #include "StelTextureMgr.hpp"
 #include "StelModuleMgr.hpp"
+#include "StarMgr.hpp"
 
 SFont* Planet::planet_name_font = NULL;
 float Planet::object_scale = 1.f;
@@ -47,8 +51,8 @@ Planet::Planet(Planet *parent,
                double oblateness,
                Vec3f color,
                float albedo,
-               const string& tex_map_name,
-               const string& tex_halo_name,
+               const QString& tex_map_name,
+               const QString& tex_halo_name,
                pos_func_type coord_func,
                OsulatingFunctType *osculating_func,
 			   bool close_orbit,bool hidden) :
@@ -95,31 +99,35 @@ Planet::~Planet()
 wstring Planet::getInfoString(const Navigator * nav) const
 {
 	double tempDE, tempRA;
-	wostringstream oss;
+	
+	QString str;
+	QTextStream oss(&str);
 
-	oss << _(englishName);  // UI translation can differ from sky translation
-	oss.setf(ios::fixed);
-	oss.precision(1);
-	if (sphere_scale != 1.f) oss << L" (x" << sphere_scale << L")";
+	oss << q_(englishName.c_str());  // UI translation can differ from sky translation
+	oss.setRealNumberNotation(QTextStream::FixedNotation);
+	oss.setRealNumberPrecision(1);
+	if (sphere_scale != 1.f)
+		oss << " (x" << sphere_scale << ")";
 	oss << endl;
 
-	oss.precision(2);
-	oss << _("Magnitude: ") << compute_magnitude(nav->getObserverHelioPos()) << endl;
+	oss.setRealNumberPrecision(2);
+	oss << q_("Magnitude: ") << compute_magnitude(nav->getObserverHelioPos()) << endl;
 
 	Vec3d equPos = getEarthEquatorialPos(nav);
 	StelUtils::rect_to_sphe(&tempRA,&tempDE,equPos);
-	oss << _("RA/DE: ") << StelUtils::radToHmsWstr(tempRA) << L"/" << StelUtils::radToDmsWstr(tempDE) << endl;
+	oss << q_("RA/DE: ") << StelUtils::radToHmsStr(tempRA) << "/" << StelUtils::radToDmsStr(tempDE) << endl;
 	// calculate alt az position
 	Vec3d localPos = nav->earth_equ_to_local(equPos);
 	StelUtils::rect_to_sphe(&tempRA,&tempDE,localPos);
 	tempRA = 3*M_PI - tempRA;  // N is zero, E is 90 degrees
-	if(tempRA > M_PI*2) tempRA -= M_PI*2;
-	oss << _("Az/Alt: ") << StelUtils::radToDmsWstr(tempRA) << L"/" << StelUtils::radToDmsWstr(tempDE) << endl;
+	if(tempRA > M_PI*2)
+		tempRA -= M_PI*2;
+	oss << q_("Az/Alt: ") << StelUtils::radToDmsStr(tempRA) << "/" << StelUtils::radToDmsStr(tempDE) << endl;
 
-	oss.precision(8);
-	oss << _("Distance: ") << equPos.length() << _("AU") << endl;
+	oss.setRealNumberPrecision(8);
+	oss << q_("Distance: ") << equPos.length() << q_("AU") << endl;
 	
-	return oss.str();
+	return str.toStdWString();
 }
 
 //! Get sky label (sky translation)
@@ -141,27 +149,29 @@ wstring Planet::getSkyLabel(const Navigator * nav) const
 // Return the information string "ready to print" :)
 wstring Planet::getShortInfoString(const Navigator * nav) const
 {
-	wostringstream oss;
+	QString str;
+	QTextStream oss(&str);
 
-	oss << _(englishName);  // UI translation can differ from sky translation
+	oss << q_(englishName.c_str());  // UI translation can differ from sky translation
 
-	oss.setf(ios::fixed);
-	oss.precision(1);
-	if (sphere_scale != 1.f) oss << L" (x" << sphere_scale << L")";
+	oss.setRealNumberNotation(QTextStream::FixedNotation);
+	oss.setRealNumberPrecision(1);
+	if (sphere_scale != 1.f)
+		oss << " (x" << sphere_scale << ")";
 
-	oss.precision(2);
-	oss << L"  " << _("Magnitude: ") << compute_magnitude(nav->getObserverHelioPos());
+	oss.setRealNumberPrecision(2);
+	oss << "  " << q_("Magnitude: ") << compute_magnitude(nav->getObserverHelioPos());
 
 	Vec3d equPos = getEarthEquatorialPos(nav);
-	oss.precision(5);
-	oss << L"  " <<  _("Distance: ") << equPos.length() << _("AU");
+	oss.setRealNumberPrecision(5);
+	oss << "  " << q_("Distance: ") << equPos.length() << q_("AU");
 
-	return oss.str();
+	return str.toStdWString();
 }
 
 float Planet::getSelectPriority(const Navigator *nav) const
 {
-	if( ((SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("ssystem"))->getFlagHints() )
+	if( ((SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("SolarSystem"))->getFlagHints() )
 	{
 	// easy to select, especially pluto
 		return getMagnitude(nav)-15.f;
@@ -174,7 +184,7 @@ float Planet::getSelectPriority(const Navigator *nav) const
 
 Vec3f Planet::getInfoColor(void) const
 {
-	return ((SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("ssystem"))->getNamesColor();
+	return ((SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("SolarSystem"))->getNamesColor();
 }
 
 
@@ -390,8 +400,11 @@ void Planet::setRotEquatorialToVsop87(const Mat4d &m) {
 // Compute the z rotation to use from equatorial to geographic coordinates
 double Planet::getSiderealTime(double jd) const
 {
-	if (englishName=="Earth") return get_apparent_sidereal_time(jd);
-
+	if (englishName=="Earth")
+	{
+		return get_apparent_sidereal_time(jd);
+	}
+ 
 	double t = jd - re.epoch;
 	double rotations = t / (double) re.period;
 	double wholeRotations = floor(rotations);
@@ -508,7 +521,7 @@ float Planet::compute_magnitude(const Navigator * nav) const
 	return compute_magnitude(nav->getObserverHelioPos());
 }
 
-void Planet::set_big_halo(const string& halotexfile)
+void Planet::set_big_halo(const QString& halotexfile)
 {
 	StelApp::getInstance().getTextureManager().setDefaultParams();
 	tex_big_halo = StelApp::getInstance().getTextureManager().createTexture(halotexfile);
@@ -525,7 +538,7 @@ float Planet::getOnScreenSize(const Projector *prj, const Navigator *nav) const
 }
 
 // Draw the Planet and all the related infos : name, circle etc..
-double Planet::draw(Projector* prj, const Navigator * nav, const ToneReproducer* eye, int flag_point, bool stencil)
+double Planet::draw(Projector* prj, const Navigator * nav, const ToneReproducer* eye, bool stencil)
 {
 	if (hidden) return 0;
 
@@ -605,8 +618,7 @@ double Planet::draw(Projector* prj, const Navigator * nav, const ToneReproducer*
 
 		if (tex_halo)
 		{
-			if (flag_point) draw_point_halo(nav, prj, eye);
-			else draw_halo(nav, prj, eye);
+			draw_halo(nav, prj, eye);
 		}
 		if (tex_big_halo) draw_big_halo(nav, prj, eye);
 	}
@@ -705,123 +717,48 @@ void Planet::draw_sphere(const Projector* prj, const Mat4d& mat, float screen_sz
 
 }
 
+
+
 void Planet::draw_halo(const Navigator* nav, const Projector* prj, const ToneReproducer* eye)
 {
-	float cmag;
-	float rmag;
+	float rc_mag[2];
+	const StarMgr *const smgr = (const StarMgr*)StelApp::getInstance()
+                                  .getModuleMgr().getModule("StarMgr");
 
-    float fov_q = prj->getFov();
-    if (fov_q > 60) fov_q = 60;
-    else if (fov_q < 0.1) fov_q = 0.1;
-    fov_q = 1.f/(fov_q*fov_q);
-    rmag = std::sqrt(eye->adapt_luminance(
-        std::exp(-0.92103f*(compute_magnitude(nav->getObserverHelioPos())
-                         + 12.12331f)) * 108064.73f * fov_q)) * 30.f;
+	if (smgr->computeRCMag(
+                compute_magnitude(nav->getObserverHelioPos()),smgr->getFlagPointStar(),
+                prj->getFov(),eye,rc_mag) < 0) return;
 
-//	rmag = eye->adapt_luminance(std::exp(-0.92103f*(compute_magnitude(nav->get_observer_helio_pos()) +
-//	                                            12.12331f)) * 108064.73f);
-//	rmag = rmag/std::pow(prj->getFov(),0.85f)*50.f;
-
-	cmag = 1.f;
-
-	// if size of star is too small (blink) we put its size to 1.2 --> no more blink
-	// And we compensate the difference of brighteness with cmag
-	if (rmag<1.2f)
-	{
-		if (rmag<0.3f) return;
-		cmag=rmag*rmag/1.44f;
-		rmag=1.2f;
-	}
-	else
-	{
-//  try this one if you want to see a bright moon:
-//if (rmag>4.f) {
-//  rmag=4.f+2.f*std::sqrt(1.f+rmag-4.f)-2.f;
-  if (rmag>8.f) {
-    rmag=8.f+2.f*std::sqrt(1.f+rmag-8.f)-2.f;
-  }
-//}
-
-//		if (rmag>5.f)
-//		{
-//			rmag=5.f+sqrt(rmag-5)/6;
-//			if (rmag>9.f)
-//			{
-//				rmag=9.f;
-//			}
-//		}
-	}
-
-
-	// Global scaling
-	rmag*=Planet::object_scale;
-
-	glBlendFunc(GL_ONE, GL_ONE);
-	float screen_r = getOnScreenSize(prj, nav);
-if (screen_r<1.f) screen_r=1.f;
-	cmag *= 0.5*rmag/(screen_r*screen_r*screen_r);
-	if (cmag>1.f) cmag = 1.f;
-
-	if (rmag<screen_r)
-	{
-		cmag*=rmag/screen_r;
-		rmag = screen_r;
-	}
-
-	if (tex_halo) tex_halo->bind();
 	glEnable(GL_BLEND);
 	glDisable(GL_LIGHTING);
-	glEnable(GL_TEXTURE_2D);
-	glColor3f(color[0]*cmag, color[1]*cmag, color[2]*cmag);
-	
-	prj->drawSprite2dMode(screenPos[0], screenPos[1], rmag*2);
-}
-
-void Planet::draw_point_halo(const Navigator* nav, const Projector* prj, const ToneReproducer* eye)
-{
-	float cmag;
-	float rmag;
-
-    float fov_q = prj->getFov();
-    if (fov_q > 60) fov_q = 60;
-    fov_q = 1.f/(fov_q*fov_q);
-    rmag =
-      std::sqrt(eye->adapt_luminance(
-        std::exp(-0.92103f*(compute_magnitude(nav->getObserverHelioPos())
-                         + 12.12331f)) * 108064.73f * fov_q)) * 6.f;
-
-//	rmag = eye->adapt_luminance(std::exp(-0.92103f*(compute_magnitude(nav->get_observer_helio_pos()) +
-//	                                            12.12331f)) * 108064.73f);
-//	rmag = rmag/std::pow(prj->getFov(),0.85f)*10.f;
-
-	cmag = 1.f;
-
-	// if size of star is too small (blink) we put its size to 1.2 --> no more blink
-	// And we compensate the difference of brighteness with cmag
-	if (rmag<0.3f) return;
-	cmag=rmag*rmag/(1.4f*1.4f);
-	rmag=1.4f;
-
-	// Global scaling
-	//rmag*=Planet::star_scale;
-
 	glBlendFunc(GL_ONE, GL_ONE);
 	float screen_r = getOnScreenSize(prj, nav);
-	cmag *= rmag/screen_r;
-	if (cmag>1.f) cmag = 1.f;
+	if (smgr->getFlagPointStar()) {
+		if (screen_r<=1.f)
+		{
+			glDisable(GL_TEXTURE_2D);
+			glPointSize(0.1);
+			glColor3fv(color*rc_mag[1]);
+			prj->drawPoint2d(screenPos[0], screenPos[1]);
+		}
+	} else {
+		// Global scaling with star_scale already done
+		//	rc_mag[0]*=Planet::object_scale;
 
-	if (rmag<screen_r)
-	{
-		cmag*=rmag/screen_r;
-		rmag = screen_r;
+		if (screen_r<1.f) screen_r=1.f;
+		rc_mag[1] *= 0.5*rc_mag[0]/(screen_r*screen_r*screen_r);
+		if (rc_mag[1]>1.f) rc_mag[1] = 1.f;
+
+		if (rc_mag[0]<screen_r)
+		{
+			rc_mag[1]*= (rc_mag[0]/screen_r);
+			rc_mag[0] = screen_r;
+		}
+		if (tex_halo) tex_halo->bind();
+		glEnable(GL_TEXTURE_2D);
+		glColor3fv(color*rc_mag[1]);
+		prj->drawSprite2dMode(screenPos[0], screenPos[1], rc_mag[0]*2);
 	}
-
-	if (tex_halo) tex_halo->bind();
-	glEnable(GL_BLEND);
-	glDisable(GL_LIGHTING);
-	glEnable(GL_TEXTURE_2D);
-	glColor3f(color[0]*cmag, color[1]*cmag, color[2]*cmag);
-	prj->drawSprite2dMode(screenPos[0], screenPos[1], rmag*2);
 }
 
 void Planet::draw_big_halo(const Navigator* nav, const Projector* prj, const ToneReproducer* eye)
@@ -831,7 +768,7 @@ void Planet::draw_big_halo(const Navigator* nav, const Projector* prj, const Ton
 		float cmag;
 		float rmag;
 	
-	    cmag = std::sqrt(eye->adapt_luminance(std::exp(-0.92103f*(compute_magnitude(nav->getObserverHelioPos()) + 12.12331f)) * 108064.73f*0.0001))*0.1;
+	    cmag = std::sqrt(eye->adaptLuminance(std::exp(-0.92103f*(compute_magnitude(nav->getObserverHelioPos()) + 12.12331f)) * 108064.73f*0.0001))*0.1;
 		rmag = big_halo_size/2;
 		float screen_r = getOnScreenSize(prj, nav)*8;	// Size in pixel at which the halo should start to disapear
 		if (cmag>1.f) cmag = 1.f;
@@ -863,48 +800,31 @@ void Planet::draw_big_halo(const Navigator* nav, const Projector* prj, const Ton
 	}
 	else
 	{
-		float cmag;
-		float rmag;
-	    float fov_q = prj->getFov();
-	    if (fov_q > 60) fov_q = 60;
-	    else if (fov_q < 0.1) fov_q = 0.1;
-	    fov_q = 1.f/(fov_q*fov_q);
-	    rmag = std::sqrt(eye->adapt_luminance(
-	        std::exp(-0.92103f*(compute_magnitude(nav->getObserverHelioPos())
-	                         + 12.12331f)) * 108064.73f * fov_q)) * 30.f;
-		cmag = 1.f;
-		if (rmag<1.2f)
-		{
-			if (rmag<0.3f) return;
-			cmag=rmag*rmag/1.44f;
-			rmag=1.2f;
-		}
-		else
-		{
-	      if (rmag>8.f) {
-	        rmag=8.f+2.f*std::sqrt(1.f+rmag-8.f)-2.f;
-	      }
-		}
-		rmag*=Planet::object_scale;
+		float rc_mag[2];
+		const StarMgr *const smgr = (const StarMgr*)StelApp::getInstance()
+	                                  .getModuleMgr().getModule("StarMgr");
+		if (smgr->computeRCMag(
+    	            compute_magnitude(nav->getObserverHelioPos()),false,
+        	        prj->getFov(),eye,rc_mag) < 0) return;
 		glBlendFunc(GL_ONE, GL_ONE);
 		float screen_r = 0.25*getOnScreenSize(prj, nav);
 		if (screen_r<1.f) screen_r=1.f;
-		cmag *= 0.5*rmag/(screen_r*screen_r*screen_r);
-		if (cmag>1.f) cmag = 1.f;
+		rc_mag[1] *= 0.5*rc_mag[0]/(screen_r*screen_r*screen_r);
+		if (rc_mag[1]>1.f) rc_mag[1] = 1.f;
 	
-		if (rmag<screen_r)
+		if (rc_mag[0]<screen_r)
 		{
-			cmag*=rmag/screen_r;
-			rmag = screen_r;
+			rc_mag[1]*=rc_mag[0]/screen_r;
+			rc_mag[0] = screen_r;
 		}
 	
 		if (tex_big_halo) tex_big_halo->bind();
 		glEnable(GL_BLEND);
 		glDisable(GL_LIGHTING);
 		glEnable(GL_TEXTURE_2D);
-		glColor3f(color[0]*cmag, color[1]*cmag, color[2]*cmag);
+		glColor3f(color[0]*rc_mag[1], color[1]*rc_mag[1], color[2]*rc_mag[1]);
 	
-		screen_r = 0.3*rmag; // just an arbitrary scaling
+		screen_r = 0.3*rc_mag[0]; // just an arbitrary scaling
 	      // drawSprite2dMode does not work for the big halo,
 	      // perhaps it is too big?
 		glBegin(GL_QUADS);
@@ -920,7 +840,7 @@ void Planet::draw_big_halo(const Navigator* nav, const Projector* prj, const Ton
 	}
 }
 
-Ring::Ring(double radius_min,double radius_max,const string &texname)
+Ring::Ring(double radius_min,double radius_max,const QString &texname)
      :radius_min(radius_min),radius_max(radius_max) {
 	tex = StelApp::getInstance().getTextureManager().createTexture(texname);
 }
@@ -946,8 +866,6 @@ void Ring::draw(const Projector* prj,const Mat4d& mat,double screen_sz)
 
 	if (tex) tex->bind();
 
-	// TODO: radial texture would look much better
-
 	  // solve the ring wraparound by culling:
 	  // decide if we are above or below the ring plane
 	const double h = mat.r[ 8]*mat.r[12]
