@@ -21,6 +21,7 @@
 #include <sstream>
 #include <cstdio>
 #include <cassert>
+#include <map>
 #include "GLee.h"
 
 #if defined(__APPLE__) && defined(__MACH__)
@@ -32,7 +33,8 @@
 #include "Projector.hpp"
 #include "InitParser.hpp"
 #include "MappingClasses.hpp"
-
+#include "StelApp.hpp"
+#include <QDebug>
 
 const char *Projector::maskTypeToString(PROJECTOR_MASK_TYPE type)
 {
@@ -62,8 +64,8 @@ void Projector::init(const InitParser& conf)
 	  projMaskType = Projector::stringToMaskType(tmpstr);
 	setMaskType(projMaskType);
 	const bool maximized = (tmpstr=="maximized");
-	const int screen_w = conf.get_int("video:screen_w");
-	const int screen_h = conf.get_int("video:screen_h");
+	const int screen_w = StelApp::getInstance().getScreenW();
+	const int screen_h = StelApp::getInstance().getScreenH();
 	const int screen_min_wh = MY_MIN(screen_w,screen_h);
 	const int viewport_width
 	  = conf.get_int("projection","viewport_width",
@@ -136,7 +138,7 @@ void Projector::init(const InitParser& conf)
 	initFov	= conf.get_double ("navigation","init_fov",60.);
 	setFov(initFov);
 
-	glFrontFace(needGlFrontFaceCW()?GL_CW:GL_CCW);
+	//glFrontFace(needGlFrontFaceCW()?GL_CW:GL_CCW);
 
 	flagGlPointSprite = conf.get_boolean("projection","flag_use_gl_point_sprite",false);
 	flagGlPointSprite = flagGlPointSprite && GLEE_ARB_point_sprite;
@@ -145,7 +147,7 @@ void Projector::init(const InitParser& conf)
 		glTexEnvf( GL_POINT_SPRITE_ARB, GL_COORD_REPLACE_ARB, GL_TRUE );
 		glEnable(GL_POINT_SPRITE_ARB);
 		glEnable(GL_POINT_SMOOTH);
-		cerr << "INFO: using GL_ARB_point_sprite" << endl;
+		cout << "INFO: using GL_ARB_point_sprite" << endl;
 	} else {
 		//cerr << "WARNING: GL_ARB_point_sprite not available" << endl;
 	}
@@ -192,7 +194,7 @@ void Projector::setViewport(int x, int y, int w, int h,
 	viewport_center[0] = x+cx;
 	viewport_center[1] = y+cy;
 	viewport_fov_diameter = fov_diam;
-	view_scaling_factor = 0.5 * viewport_fov_diameter
+	pixel_per_rad = 0.5 * viewport_fov_diameter
 	  / (mapping ? mapping->fovToViewScalingFactor(fov*(M_PI/360.0)) : 1.0);
 	glViewport(x, y, w, h);
 	initGlMatrixOrtho2d();
@@ -216,13 +218,17 @@ std::vector<Vec2d> Projector::getViewportVertices2d() const
  Return a convex polygon on the sphere which includes the viewport in the 
  current frame
 *************************************************************************/
-StelGeom::ConvexPolygon Projector::getViewportConvexPolygon(double margin) const
+StelGeom::ConvexPolygon Projector::getViewportConvexPolygon(double marginX, double marginY) const
 {
 	Vec3d e0, e1, e2, e3;
-	unProject(0-margin,0-margin,e0);
-	unProject(getViewportWidth()+margin,0-margin,e1);
-	unProject(getViewportWidth()+margin,getViewportHeight()+margin,e2);
-	unProject(0-margin,getViewportHeight()+margin,e3);
+	unProject(0-marginX,0-marginY,e0);
+	unProject(getViewportWidth()+marginX,0-marginY,e1);
+	unProject(getViewportWidth()+marginX,getViewportHeight()+marginY,e2);
+	unProject(0-marginX,getViewportHeight()+marginY,e3);
+	e0.normalize();
+	e1.normalize();
+	e2.normalize();
+	e3.normalize();
 	return StelGeom::ConvexPolygon(e0, e3, e2, e1);
 }
 
@@ -321,7 +327,7 @@ void Projector::setFov(double f)
 		fov = max_fov;
 	if (f<min_fov)
 		fov = min_fov;
-	view_scaling_factor = 0.5 * viewport_fov_diameter
+	pixel_per_rad = 0.5 * viewport_fov_diameter
 	  / (mapping ? mapping->fovToViewScalingFactor(fov*(M_PI/360.0)) : 1.0);
 }
 
@@ -375,7 +381,7 @@ void Projector::setCurrentFrame(FRAME_TYPE frameType) const
 		setCustomFrame(mat_j2000_to_eye);
 		break;
 	default:
-		cerr << "Unknown reference frame type: " << frameType << "." << endl;
+		cerr << "Unknown reference frame type: " << (int)frameType << "." << endl;
 	}
 }
 
@@ -386,7 +392,6 @@ void Projector::setCurrentFrame(FRAME_TYPE frameType) const
 void Projector::setCustomFrame(const Mat4d& m) const
 {
 	modelViewMatrix = m;
-//	inverseModelViewMatrix = modelViewMatrix.inverse();
 }
 
 /*************************************************************************
@@ -462,8 +467,8 @@ void Projector::setCurrentProjection(const std::string& projectionName)
 // 	  // invisible region of the sky (rval=false), we must finish
 // 	  // reprojecting, so that OpenGl can successfully eliminate
 // 	  // polygons by culling.
-// 	win[0] = viewport_center[0] + flip_horz * view_scaling_factor * win[0];
-// 	win[1] = viewport_center[1] + flip_vert * view_scaling_factor * win[1];
+// 	win[0] = viewport_center[0] + flip_horz * pixel_per_rad * win[0];
+// 	win[1] = viewport_center[1] + flip_vert * pixel_per_rad * win[1];
 // 	win[2] = (win[2] - zNear) / (zNear - zFar);
 // 	return rval;
 // }
@@ -473,8 +478,8 @@ void Projector::setCurrentProjection(const std::string& projectionName)
 *************************************************************************/
 bool Projector::unProject(double x, double y, Vec3d &v) const
 {
-	v[0] = flip_horz * (x - viewport_center[0]) / view_scaling_factor;
-	v[1] = flip_vert * (y - viewport_center[1]) / view_scaling_factor;
+	v[0] = flip_horz * (x - viewport_center[0]) / pixel_per_rad;
+	v[1] = flip_vert * (y - viewport_center[1]) / pixel_per_rad;
 	v[2] = 0;
 	const bool rval = mapping->backward(v);
 	  // Even when the reprojected point comes from an region of the screen,
@@ -544,7 +549,6 @@ void ComputeCosSinTheta(double phi,int segments) {
     cos_sin += 2;
     *--cos_sin_rev = -cos_sin[-1];
     *--cos_sin_rev =  cos_sin[-2];
-    segments--;
   }
 }
 
@@ -807,7 +811,8 @@ static void sSphereMapTexCoordFast(double rho_div_fov, double costheta, double s
 	             0.5 + rho_div_fov * sintheta);
 }
 
-void Projector::sSphere_map(GLdouble radius, GLint slices, GLint stacks, double texture_fov, int orient_inside) const
+void Projector::sSphere_map(GLdouble radius, GLint slices, GLint stacks,
+                            double texture_fov, int orient_inside) const
 {
 	double rho,x,y,z;
 	int i, j;
@@ -820,6 +825,7 @@ void Projector::sSphere_map(GLdouble radius, GLint slices, GLint stacks, double
 
 	const double dtheta = 2.0 * M_PI / slices;
 	assert(slices<=MAX_SLICES);
+
 	ComputeCosSinTheta(dtheta,slices);
 	double *cos_sin_theta_p;
 
@@ -838,7 +844,7 @@ void Projector::sSphere_map(GLdouble radius, GLint slices, GLint stacks, double
 		{
 			glBegin(GL_QUAD_STRIP);
 			for (j=0,cos_sin_theta_p=cos_sin_theta;
-			        j<=slices;++j,cos_sin_theta_p+=2)
+			     j<=slices;++j,cos_sin_theta_p+=2)
 			{
 				x = -cos_sin_theta_p[1] * cos_sin_rho_p[1];
 				y = cos_sin_theta_p[0] * cos_sin_rho_p[1];
@@ -868,7 +874,7 @@ void Projector::sSphere_map(GLdouble radius, GLint slices, GLint stacks, double
 		{
 			glBegin(GL_QUAD_STRIP);
 			for (j=0,cos_sin_theta_p=cos_sin_theta;
-			        j<=slices;++j,cos_sin_theta_p+=2)
+			     j<=slices;++j,cos_sin_theta_p+=2)
 			{
 				x = -cos_sin_theta_p[1] * cos_sin_rho_p[3];
 				y = cos_sin_theta_p[0] * cos_sin_rho_p[3];
@@ -944,40 +950,28 @@ void Projector::drawTextGravity180(const SFont* font, float x, float y, const ws
 	glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA); // Normal transparency mode
 	for (unsigned int i=0;i<ws.length();++i)
 	{
-		if (ws[i]>=16 && ws[i]<=18)
+		if( !speed_optimize )
 		{
-			// handle hilight colors (TUI)
-			// Note: this is hard coded - not generalized
-			if( ws[i]==17 )
-				glColor3f(0.5,1,0.5);  // normal
-			if( ws[i]==18 )
-				glColor3f(1,1,1);    // hilight
+			font->print_char_outlined(ws[i]);
 		}
 		else
 		{
-			if( !speed_optimize )
-			{
-				font->print_char_outlined(ws[i]);
-			}
-			else
-			{
-				font->print_char(ws[i]);
-			}
-
-			// with typeface need to manually advance
-			// TODO, absolute rotation would be better than relative
-			// TODO: would look better with kerning information...
-			glTranslatef(font->getStrLen(ws.substr(i,1)) * 1.05, 0, 0);
-
-			if( !speed_optimize )
-			{
-				psi = std::atan2((float)font->getStrLen(ws.substr(i,1))*1.05f,(float)d) * 180./M_PI;
-				if (psi>5)
-					psi = 5;
-			}
-			
-			glRotatef(psi,0,0,-1);
+			font->print_char(ws[i]);
 		}
+
+		// with typeface need to manually advance
+		// TODO, absolute rotation would be better than relative
+		// TODO: would look better with kerning information...
+		glTranslatef(font->getStrLen(ws.substr(i,1)) * 1.05, 0, 0);
+
+		if( !speed_optimize )
+		{
+			psi = std::atan2((float)font->getStrLen(ws.substr(i,1))*1.05f,(float)d) * 180./M_PI;
+			if (psi>5)
+				psi = 5;
+		}
+		
+		glRotatef(psi,0,0,-1);
 	}
 	glPopMatrix();
 }
@@ -1004,7 +998,7 @@ void Projector::drawText(const SFont* font, float x, float y, const wstring& str
 /*************************************************************************
  Draw a parallel arc in the current frame
 *************************************************************************/
-void Projector::drawParallel(const Vec3d& start, double length, bool labelAxis, const SFont* font, int nbSeg) const
+void Projector::drawParallel(const Vec3d& start, double length, bool labelAxis, const SFont* font, const Vec4f* textColor, int nbSeg) const
 {
 	if (nbSeg==-1)
 		nbSeg = 4 + (int)(length*44./(2.*M_PI));
@@ -1024,6 +1018,12 @@ void Projector::drawParallel(const Vec3d& start, double length, bool labelAxis,
 	// Draw label if needed
 	if (labelAxis)
 	{
+		static GLfloat tmpColor[4];
+		if (textColor)
+		{
+			glGetFloatv(GL_CURRENT_COLOR, tmpColor);
+			glColor4fv(*textColor);
+		}
 		double lon, lat;
 		StelUtils::rect_to_sphe(&lon, &lat, start);
 		Vec3d win0, win1;
@@ -1032,7 +1032,7 @@ void Projector::drawParallel(const Vec3d& start, double length, bool labelAxis,
 		project(start, win0);
 		project(v2, win1);
 		double angleDeg = std::atan2(win1[1]-win0[1], win1[0]-win0[0])*180./M_PI;
-		const wstring str = StelUtils::radToDmsWstrAdapt(lat);
+		const wstring str = StelUtils::radToDmsStrAdapt(lat).toStdWString();
 		float xshift=5;
 		if (angleDeg>90. || angleDeg<-90.)
 		{
@@ -1053,13 +1053,16 @@ void Projector::drawParallel(const Vec3d& start, double length, bool labelAxis,
 			xshift=-font->getStrLen(str)-5.f;
 		}
 		drawText(font, win1[0], win1[1], str, angleDeg, xshift, 3);
+		
+		if (textColor)
+			glColor4fv(tmpColor);
 	}
 }
 
 /*************************************************************************
  Draw a meridian arc in the current frame
 *************************************************************************/
-void Projector::drawMeridian(const Vec3d& start, double length, bool labelAxis, const SFont* font, int nbSeg) const
+void Projector::drawMeridian(const Vec3d& start, double length, bool labelAxis, const SFont* font, const Vec4f* textColor, int nbSeg) const
 {
 	if (nbSeg==-1)
 		nbSeg = 4 + (int)(length*54./(2.*M_PI));
@@ -1080,6 +1083,12 @@ void Projector::drawMeridian(const Vec3d& start, double length, bool labelAxis,
 	// Draw label if needed
 	if (labelAxis)
 	{
+		static GLfloat tmpColor[4];
+		if (textColor)
+		{
+			glGetFloatv(GL_CURRENT_COLOR, tmpColor);
+			glColor4fv(*textColor);
+		}
 		double lon, lat;
 		StelUtils::rect_to_sphe(&lon, &lat, start);
 		Vec3d win0, win1;
@@ -1089,7 +1098,7 @@ void Projector::drawMeridian(const Vec3d& start, double length, bool labelAxis,
 		project(v2, win1);
 		double angleDeg = std::atan2(win1[1]-win0[1], win1[0]-win0[0])*180./M_PI;
 		//angleDeg += start[1]>=0 ? 1.:180.;
-		const wstring str = StelUtils::radToHmsWstrAdapt(lon);
+		wstring str = StelUtils::radToHmsStrAdapt(lon).toStdWString();;
 		float xshift=20;
 		if (angleDeg>90. || angleDeg<-90.)
 		{
@@ -1109,10 +1118,45 @@ void Projector::drawMeridian(const Vec3d& start, double length, bool labelAxis,
 			angleDeg+=180.;
 			xshift=-font->getStrLen(str)-20.f;
 		}
+		StelUtils::rect_to_sphe(&lon, &lat, v);
+		str = StelUtils::radToHmsStrAdapt(lon).toStdWString();;
 		drawText(font, win1[0], win1[1], str, angleDeg, xshift, 3);
+		
+		if (textColor)
+			glColor4fv(tmpColor);
 	}
 }
 
+
+/*************************************************************************
+ draw a simple circle, 2d viewport coordinates in pixel
+*************************************************************************/
+void Projector::drawCircle(double x,double y,double r) const {
+  if (r <= 1.0) return;
+  const Vec2d center(x,y);
+  const Vec2d v_center(0.5*viewport_xywh[2],
+                       0.5*viewport_xywh[3]);
+  const double R = v_center.length();
+  const double d = (v_center-center).length();
+  if (d > r+R || d < r-R) return;
+  const int segments = 180;
+  const double phi = 2.0*M_PI/segments;
+  const double cp = cos(phi);
+  const double sp = sin(phi);
+  double dx = r;
+  double dy = 0;
+  glBegin(GL_LINE_LOOP);
+  for (int i=0;i<=segments;i++) {
+    glVertex2d(x+dx,y+dy);
+    r = dx*cp-dy*sp;
+    dy = dx*sp+dy*cp;
+    dx = r;
+  }
+  glEnd();
+}
+
+
+
 /*************************************************************************
  Same function but gives the already projected 2d position in input
 *************************************************************************/
@@ -1163,6 +1207,26 @@ void Projector::drawSprite2dMode(double x, double y, double size, double rotatio
 	glPopMatrix();
 }
 
+/*************************************************************************
+ Draw the given polygon
+*************************************************************************/
+void Projector::drawPolygon(const StelGeom::Polygon& poly) const
+{
+	const int size = poly.size();
+	if (size<3)
+		return;
+
+	Vec3d win;	
+	glBegin(GL_LINE_LOOP);
+	for (int i=0;i<size;++i)
+	{
+		project(poly[i], win);
+		glVertex3dv(win);
+	}
+	glEnd();
+}
+	
+
 /*************************************************************************
  Draw a GL_POINT at the given position
 *************************************************************************/
@@ -1217,20 +1281,6 @@ void Projector::drawVertex3v(const Vec3d& v) const
 	glVertex3dv(win);
 }
 
-/*************************************************************************
- Generalisation of glVertex3v. This method assumes that the current openGL
- projection matrix is a perspective one.
- This method is supposed to handle lighting operations properly. 
-*************************************************************************/
-void Projector::drawVertex3vWithLight(const Vec3d& v) const
-{
-	Vec3d win,vv;
-	project(v, win);
-	
-	// Can be optimized by avoiding matrix inversion if it's always the same
-	gluUnProject(win[0],win[1],win[2],modelViewMatrix,projectionMatrix,viewport_xywh,&vv[0],&vv[1],&vv[2]);
-	glVertex3dv(vv);
-}
 
 ///////////////////////////////////////////////////////////////////////////
 // Drawing methods for general (non-linear) mode
@@ -1285,7 +1335,7 @@ void Projector::sSphere(GLdouble radius, GLdouble one_minus_oblateness,
 	const double dtheta = 2.0 * M_PI / slices;
 	assert(slices<=MAX_SLICES);
 	ComputeCosSinTheta(dtheta,slices);
-	double *cos_sin_theta_p;
+	const double *cos_sin_theta_p;
 
 	// texturing: s goes from 0.0/0.25/0.5/0.75/1.0 at +y/+x/-y/-x/+y axis
 	// t goes from -1.0/+1.0 at z = -radius/+radius (linear along longitudes)
@@ -1296,7 +1346,7 @@ void Projector::sSphere(GLdouble radius, GLdouble one_minus_oblateness,
 
 	// draw intermediate  as quad strips
 	for (i = 0,cos_sin_rho_p = cos_sin_rho; i < stacks;
-	        i++,cos_sin_rho_p+=2)
+	     i++,cos_sin_rho_p+=2)
 	{
 		glBegin(GL_QUAD_STRIP);
 		s = 0.0;
