@@ -36,7 +36,9 @@
 #include "StelLocaleMgr.hpp"
 #include "StelSkyCultureMgr.hpp"
 #include "StelFileMgr.hpp"
+#include "StelModuleMgr.hpp"
 #include "Planet.hpp"
+#include <QTextStream>
 
 using namespace std;
 
@@ -44,10 +46,9 @@ SolarSystem::SolarSystem()
 	:sun(NULL),moon(NULL),earth(NULL),selected(NULL),
 	moonScale(1.), fontSize(14.),
 	planet_name_font(StelApp::getInstance().getFontManager().getStandardFont(StelApp::getInstance().getLocaleMgr().getAppLanguage(), fontSize)),
-	flagOrbits(false),flag_light_travel_time(false)
+	flagOrbits(false),flag_light_travel_time(false), lastHomePlanet(NULL)
 {
-	flagPoint = false;
-	dependenciesOrder["draw"]="stars";
+	setObjectName("SolarSystem");
 }
 
 void SolarSystem::setFontSize(float newFontSize)
@@ -74,15 +75,24 @@ SolarSystem::~SolarSystem()
 	earth = NULL;
 }
 
+/*************************************************************************
+ Reimplementation of the getCallOrder method
+*************************************************************************/
+double SolarSystem::getCallOrder(StelModuleActionName actionName) const
+{
+	if (actionName==StelModule::ACTION_DRAW)
+		return StelApp::getInstance().getModuleMgr().getModule("StarMgr")->getCallOrder(actionName)+10;
+	return 0;
+}
 
 // Init and load the solar system data
-void SolarSystem::init(const InitParser& conf, LoadingBar& lb)
+void SolarSystem::init(const InitParser& conf)
 {
-	loadPlanets(lb);	// Load planets data
+	loadPlanets();	// Load planets data
 
 	// Compute position and matrix of sun and all the satellites (ie planets)
 	// for the first initialization assert that center is sun center (only impacts on light speed correction)
-	computePositions(get_julian_from_sys());
+	computePositions(StelUtils::getJDFromSystem());
 	setSelected("");	// Fix a bug on macosX! Thanks Fumio!
 	setScale(conf.get_double ("stars:star_scale"));  // if reload config
 	setFlagMoonScale(conf.get_boolean("viewing", "flag_moon_scaled", conf.get_boolean("viewing", "flag_init_moon_scaled", false)));  // name change
@@ -93,7 +103,6 @@ void SolarSystem::init(const InitParser& conf, LoadingBar& lb)
 	setFlagLightTravelTime(conf.get_boolean("astro:flag_light_travel_time"));
 	setFlagTrails(conf.get_boolean("astro", "flag_object_trails", false));
 	startTrails(conf.get_boolean("astro", "flag_object_trails", false));	
-	setFlagPoint(conf.get_boolean("stars:flag_point_star"));
 	
 	StelApp::getInstance().getStelObjectMgr().registerStelObjectMgr(this);
 	texPointer = StelApp::getInstance().getTextureManager().createTexture("pointeur4.png");
@@ -166,7 +175,7 @@ void SolarSystem::drawPointer(const Projector* prj, const Navigator * nav)
 }
 
 // Init and load the solar system data
-void SolarSystem::loadPlanets(LoadingBar& lb)
+void SolarSystem::loadPlanets()
 {
 	cout << "Loading Solar System data...";
 	InitParser pd;	// The Planet data ini file parser
@@ -494,8 +503,8 @@ void SolarSystem::loadPlanets(LoadingBar& lb)
                                pd.get_double(secname, "oblateness", 0.0),
                                StelUtils::str_to_vec3f(pd.get_str(secname, "color").c_str()),
                                pd.get_double(secname, "albedo"),
-                               pd.get_str(secname, "tex_map"),
-                               pd.get_str(secname, "tex_halo"),
+                               pd.get_str(secname, "tex_map").c_str(),
+                               pd.get_str(secname, "tex_halo").c_str(),
                                posfunc,osculating_func,
                                close_orbit,
                                pd.get_boolean(secname, "hidden", 0));
@@ -517,12 +526,12 @@ void SolarSystem::loadPlanets(LoadingBar& lb)
 		if (pd.get_boolean(secname, "rings", 0)) {
 			const double r_min = pd.get_double(secname, "ring_inner_size")/AU;
 			const double r_max = pd.get_double(secname, "ring_outer_size")/AU;
-			Ring *r = new Ring(r_min,r_max,pd.get_str(secname, "tex_ring"));
+			Ring *r = new Ring(r_min,r_max,pd.get_str(secname, "tex_ring").c_str());
 			p->set_rings(r);
 		}
 
-		string bighalotexfile = pd.get_str(secname, "tex_big_halo", "");
-		if (!bighalotexfile.empty())
+		QString bighalotexfile = pd.get_str(secname, "tex_big_halo", "").c_str();
+		if (!bighalotexfile.isEmpty())
 		{
 			p->set_big_halo(bighalotexfile);
 			p->set_halo_size(pd.get_double(secname, "big_halo_size", 50.f));
@@ -584,9 +593,14 @@ void SolarSystem::computeTransMatrices(double date, const Vec3d& observerPos) {
 
 // Draw all the elements of the solar system
 // We are supposed to be in heliocentric coordinate
-double SolarSystem::draw(Projector * prj, const Navigator * nav, ToneReproducer* eye)
+double SolarSystem::draw(StelCore* core)
 {
-	if(!Planet::getflagShow()) return 0.0;
+	if(!Planet::getflagShow())
+		return 0.0;
+	
+	Navigator* nav = core->getNavigation();
+	Projector* prj = core->getProjection();
+	ToneReproducer* eye = core->getToneReproducer();
 	
 	Planet::set_font(&planet_name_font);
 	
@@ -640,11 +654,11 @@ double SolarSystem::draw(Projector * prj, const Navigator * nav, ToneReproducer*
 			glStencilFunc(GL_ALWAYS, 0x1, 0x1);
 			glStencilOp(GL_ZERO, GL_REPLACE, GL_REPLACE);
 
-			squaredDistance = (*iter)->draw(prj, nav, eye, flagPoint, 1);
+			squaredDistance = (*iter)->draw(prj, nav, eye, 1);
 		}
 		else
 		{
-			squaredDistance = (*iter)->draw(prj, nav, eye, flagPoint, 0);
+			squaredDistance = (*iter)->draw(prj, nav, eye, 0);
 		}
 		if (squaredDistance > maxSquaredDistance)
 			maxSquaredDistance = squaredDistance;
@@ -666,13 +680,13 @@ double SolarSystem::draw(Projector * prj, const Navigator * nav, ToneReproducer*
 	return maxSquaredDistance;
 }
 
-void SolarSystem::setColorScheme(const InitParser& conf, const std::string& section)
+void SolarSystem::setColorScheme(const InitParser& conf, const QString& section)
 {
 	// Load colors from config file
-	string defaultColor = conf.get_str(section,"default_color");
-	setNamesColor(StelUtils::str_to_vec3f(conf.get_str(section,"planet_names_color", defaultColor)));
-	setOrbitsColor(StelUtils::str_to_vec3f(conf.get_str(section,"planet_orbits_color", defaultColor)));
-	setTrailsColor(StelUtils::str_to_vec3f(conf.get_str(section,"object_trails_color", defaultColor)));
+	string defaultColor = conf.get_str(section.toStdString(),"default_color");
+	setNamesColor(StelUtils::str_to_vec3f(conf.get_str(section.toStdString(),"planet_names_color", defaultColor)));
+	setOrbitsColor(StelUtils::str_to_vec3f(conf.get_str(section.toStdString(),"planet_orbits_color", defaultColor)));
+	setTrailsColor(StelUtils::str_to_vec3f(conf.get_str(section.toStdString(),"object_trails_color", defaultColor)));
 }
 
 Planet* SolarSystem::searchByEnglishName(string planetEnglishName) const
@@ -720,7 +734,7 @@ StelObjectP SolarSystem::searchByName(const string& name) const
 }
 
 // Search if any Planet is close to position given in earth equatorial position and return the distance
-StelObject* SolarSystem::search(Vec3d pos, const Navigator * nav, const Projector * prj) const
+StelObject* SolarSystem::search(Vec3d pos, const StelCore* core) const
 {
 	pos.normalize();
 	Planet * closest = NULL;
@@ -730,7 +744,7 @@ StelObject* SolarSystem::search(Vec3d pos, const Navigator * nav, const Projecto
 	vector<Planet*>::const_iterator iter = system_planets.begin();
 	while (iter != system_planets.end())
 	{
-		equPos = (*iter)->getEarthEquatorialPos(nav);
+		equPos = (*iter)->getEarthEquatorialPos(core->getNavigation());
 		equPos.normalize();
 		double cos_ang_dist = equPos[0]*pos[0] + equPos[1]*pos[1] + equPos[2]*pos[2];
 		if (cos_ang_dist>cos_angle_closest)
@@ -738,7 +752,6 @@ StelObject* SolarSystem::search(Vec3d pos, const Navigator * nav, const Projecto
 			closest = *iter;
 			cos_angle_closest = cos_ang_dist;
 		}
-
 		iter++;
 	}
 
@@ -750,16 +763,13 @@ StelObject* SolarSystem::search(Vec3d pos, const Navigator * nav, const Projecto
 }
 
 // Return a stl vector containing the planets located inside the lim_fov circle around position v
-vector<StelObjectP> SolarSystem::searchAround(const Vec3d& vv,
-                                              double limitFov,
-                                              const Navigator * nav,
-                                              const Projector * prj) const
+vector<StelObjectP> SolarSystem::searchAround(const Vec3d& vv, double limitFov, const StelCore* core) const
 {
 	vector<StelObjectP> result;
 	if (!getFlagPlanets())
 		return result;
 		
-	Vec3d v = nav->j2000_to_earth_equ(vv);
+	Vec3d v = core->getNavigation()->j2000_to_earth_equ(vv);
 	v.normalize();
 	double cos_lim_fov = cos(limitFov * M_PI/180.);
 	static Vec3d equPos;
@@ -767,7 +777,7 @@ vector<StelObjectP> SolarSystem::searchAround(const Vec3d& vv,
 	vector<Planet*>::const_iterator iter = system_planets.begin();
 	while (iter != system_planets.end())
 	{
-		equPos = (*iter)->getEarthEquatorialPos(nav);
+		equPos = (*iter)->getEarthEquatorialPos(core->getNavigation());
 		equPos.normalize();
 		if (equPos[0]*v[0] + equPos[1]*v[1] + equPos[2]*v[2]>=cos_lim_fov)
 		{
@@ -800,38 +810,23 @@ vector<wstring> SolarSystem::getNamesI18(void)
 	return names;
 }
 
-
-// returns a newline delimited hash of localized:standard planet names for tui
-// Planet translated name is PARENT : NAME
 wstring SolarSystem::getPlanetHashString(void)
 {
-	wostringstream oss;
-	vector < Planet * >::iterator iter;
-
-	for (iter = system_planets.begin(); iter != system_planets.end(); ++iter) {
-		if((*iter)->get_parent() != NULL && (*iter)->get_parent()->getEnglishName() != "Sun") {
-			   oss << Translator::globalTranslator.translate((*iter)->get_parent()->getEnglishName()) 
-				   << L" : ";
+	QString str;
+	QTextStream oss(&str);
+	
+	vector <Planet *>::iterator iter;
+	for (iter = system_planets.begin(); iter != system_planets.end(); ++iter)
+	{
+		if((*iter)->get_parent() != NULL && (*iter)->get_parent()->getEnglishName() != "Sun")
+		{
+			oss << q_((*iter)->get_parent()->getEnglishName().c_str()) << " : ";
 		}
 		
-		oss << Translator::globalTranslator.translate((*iter)->getEnglishName()) << L"\n";
-		oss << StelUtils::stringToWstring((*iter)->getEnglishName()) << L"\n";
-	}
-		
-	// wcout <<  oss.str();
-
-	return oss.str();
-
-}
-
-
-void SolarSystem::updateTrails(const Navigator* nav)
-{
-	vector<Planet*>::iterator iter;
-	for( iter = system_planets.begin(); iter < system_planets.end(); iter++ )
-	{
-		(*iter)->update_trail(nav);
+		oss << q_((*iter)->getEnglishName().c_str()) << endl;
+		oss << (*iter)->getEnglishName().c_str() << endl;
 	}
+	return str.toStdWString();
 }
 
 void SolarSystem::startTrails(bool b)
@@ -967,7 +962,9 @@ void SolarSystem::draw_earth_shadow(const Navigator * nav, Projector * prj)
 
 	// umbra first
 	glBegin(GL_TRIANGLE_FAN);
-	glTexCoord2f(0,0);
+      // johannes: work-around for nasty ATI rendering bug:
+      // use y-texture coordinate of 0.5 instead of 0.0
+	glTexCoord2f(0.f,0.5f);
 	prj->drawVertex3v(shadow);
 
 	for (int i=0; i<=100; i++)
@@ -975,7 +972,7 @@ void SolarSystem::draw_earth_shadow(const Navigator * nav, Projector * prj)
 		r = Mat4d::rotation(shadow, 2*M_PI*i/100.) * upt;
 		s = shadow + r;
 
-		glTexCoord2f(0.6,0);  // position in texture of umbra edge
+		glTexCoord2f(0.6f,0.5f);  // position in texture of umbra edge
 		prj->drawVertex3v(s);
 	}
 	glEnd();
@@ -991,10 +988,10 @@ void SolarSystem::draw_earth_shadow(const Navigator * nav, Projector * prj)
 		s = shadow + r;
 		sp = shadow + u;
 
-		glTexCoord2f(0.6,0);
+		glTexCoord2f(0.6f,0.5f);
 		prj->drawVertex3v(sp);
 
-		glTexCoord2f(1.,0);  // position in texture of umbra edge
+		glTexCoord2f(1.f,0.5f);  // position in texture of umbra edge
 		prj->drawVertex3v(s);
 	}
 	glEnd();
@@ -1006,10 +1003,20 @@ void SolarSystem::draw_earth_shadow(const Navigator * nav, Projector * prj)
 
 void SolarSystem::update(double delta_time)
 {
+	bool restartTrails = false;
 	Navigator* nav = StelApp::getInstance().getCore()->getNavigation();
+
+	// Determine if home planet has changed, and restart planet trails
+	// since the data is no longer useful
+	if(nav->getHomePlanet() != lastHomePlanet) {
+		lastHomePlanet = nav->getHomePlanet();
+		restartTrails = true;
+	}
+
 	vector<Planet*>::iterator iter = system_planets.begin();
 	while (iter != system_planets.end())
 	{
+		if(restartTrails) (*iter)->startTrail(true);
 		(*iter)->update_trail(nav);
 		(*iter)->update((int)(delta_time*1000));
 		iter++;
@@ -1065,7 +1072,7 @@ vector<wstring> SolarSystem::listMatchingObjectsI18n(const wstring& objPrefix, u
 	return result;
 }
 
-void SolarSystem::selectedObjectChangeCallBack(bool added)
+void SolarSystem::selectedObjectChangeCallBack(StelModuleSelectAction action)
 {
 	const std::vector<StelObjectP> newSelected = StelApp::getInstance().getStelObjectMgr().getSelectedObject("Planet");
 	if (!newSelected.empty())
