@@ -19,12 +19,12 @@
 
 #include <cassert>
 #include <iostream>
-#include <string>
-#include <vector>
 
 #include "StelTextureMgr.hpp"
 #include "StelFileMgr.hpp"
 #include "StelApp.hpp"
+#include "InitParser.hpp"
+
 extern "C" {
 #include <jpeglib.h>
 }
@@ -32,70 +32,25 @@ extern "C" {
 
 #include "StelUtils.hpp"
 
-#if defined(__APPLE__) && defined(__MACH__)
-#include <OpenGL/glu.h>	/* Header File For The GLU Library */
-#else
-#include <GL/glu.h>	/* Header File For The GLU Library */
-#endif
-
 #include "fixx11h.h"
-#include <QTemporaryFile>
-#include <QDir>
+#include <QHttp>
+#include <QFileInfo>
+#include <QFile>
+#include <QDebug>
 #include <QThread>
-#include <QMutexLocker>
-
+				 				 
 using namespace std;
 
 // Initialize statics
-StelTextureMgr::PngLoader StelTextureMgr::pngLoader;
-StelTextureMgr::JpgLoader StelTextureMgr::jpgLoader;
-
-void ManagedSTexture::load(void)
-{
-	if (StelApp::getInstance().getTextureManager().loadImage(this)==false || StelApp::getInstance().getTextureManager().glLoadTexture(this)==false)
-	{
-		cerr << "Couldn't load texture " << this->fullPath << endl;
-		loadState = ManagedSTexture::LOAD_ERROR;
-		return;
-	}
-}
-
-/*************************************************************************
- Bind the texture so that it can be used for openGL drawing (calls glBindTexture)
- *************************************************************************/
-void ManagedSTexture::lazyBind()
-{
-	if (loadState==ManagedSTexture::LOADED)
-	{
-		bind();
-		return;
-	}
-	if (loadState==ManagedSTexture::UNLOADED)
-	{
-		load();
-	}
-}
-
-/*************************************************************************
- Return the average texture luminance, 0 is black, 1 is white
- *************************************************************************/
-float ManagedSTexture::getAverageLuminance(void)
-{
-	if (loadState==ManagedSTexture::LOADED)
-	{
-		if (avgLuminance<0)
-			avgLuminance = STexture::getAverageLuminance();
-		return avgLuminance;
-	}
-	return 0;
-};
+static PngLoader pngLoader;
+static JpgLoader jpgLoader;
 
 /*************************************************************************
  Constructor for the StelTextureMgr class
 *************************************************************************/
 StelTextureMgr::StelTextureMgr()
 {
-	loadQueueMutex = new QMutex();
+	downloader = new QHttp((QObject*)this);
 
 	// Init default values
 	setDefaultParams();
@@ -114,8 +69,6 @@ StelTextureMgr::StelTextureMgr()
 *************************************************************************/
 StelTextureMgr::~StelTextureMgr()
 {
-	delete loadQueueMutex;
-	loadQueueMutex = NULL;
 }
 
 /*************************************************************************
@@ -129,9 +82,9 @@ void StelTextureMgr::init(const InitParser& conf)
 	isNoPowerOfTwoAllowed = isNoPowerOfTwoAllowed && (GLEE_ARB_texture_non_power_of_two || GLEE_VERSION_2_0);
 	
 	// Check vendor and renderer
-	string glRenderer((char*)glGetString(GL_RENDERER));
-	string glVendor((char*)glGetString(GL_VENDOR));
-	string glVersion((char*)glGetString(GL_VERSION));
+	QString glRenderer((char*)glGetString(GL_RENDERER));
+	QString glVendor((char*)glGetString(GL_VENDOR));
+	QString glVersion((char*)glGetString(GL_VERSION));
 
 	// Get Maximum Texture Size Supported by the video card
 	glGetIntegerv(GL_MAX_TEXTURE_SIZE, &maxTextureSize);
@@ -152,227 +105,101 @@ void StelTextureMgr::setDefaultParams()
 /*************************************************************************
  Internal
 *************************************************************************/
-ManagedSTextureSP StelTextureMgr::initTex(const string& fullPath)
+STextureSP StelTextureMgr::initTex()
 {
-	ManagedSTextureSP tex(new ManagedSTexture());
+	STextureSP tex(new STexture());
 	// Set parameters than can be set for this texture
-	tex->minFilter = (mipmapsMode==true) ? GL_LINEAR_MIPMAP_NEAREST : minFilter;
+	tex->minFilter = ((mipmapsMode==true) ? GL_LINEAR_MIPMAP_NEAREST : minFilter);
 	tex->magFilter = magFilter;
 	tex->wrapMode = wrapMode;
-	tex->fullPath = fullPath;
 	tex->mipmapsMode = mipmapsMode;
 	tex->dynamicRangeMode = dynamicRangeMode;
-	
 	return tex;
 }
 
 /*************************************************************************
  Load an image from a file and create a new texture from it.
 *************************************************************************/
-ManagedSTextureSP StelTextureMgr::createTexture(const string& afilename, bool lazyLoading)
+STextureSP StelTextureMgr::createTexture(const QString& afilename)
 {
-	string ph;
+	if (afilename.isEmpty())
+		return STextureSP();
+	
+	STextureSP tex = initTex();
 	try
 	{
-		ph = StelApp::getInstance().getFileMgr().findFile(afilename);
+		tex->fullPath = StelApp::getInstance().getFileMgr().findFile(afilename);
 	}
 	catch (exception e)
 	{
 		try
 		{
-			ph = StelApp::getInstance().getFileMgr().findFile("textures/" + afilename);
+			tex->fullPath = StelApp::getInstance().getFileMgr().findFile("textures/" + afilename);
 		}
 		catch (exception e)
 		{
-			cerr << "WARNING : Can't find texture file " << afilename << ": " << e.what() << endl;
-			return ManagedSTextureSP();
+			qWarning() << "WARNING : Can't find texture file " << afilename << ": " << e.what() << endl;
+			tex->errorOccured = true;
+			return STextureSP();
 		}
 	}
-	
-	ManagedSTextureSP tex = initTex(ph);
-	if (tex==NULL)
-		return ManagedSTextureSP();
 
-	// Load only if lazyLoading is not true, else will load later
-	if (lazyLoading==true)
-		return tex;
+	tex->downloaded = true;
 	
 	// Simply load everything
-	if (loadImage(tex.get()) && glLoadTexture(tex.get()))
+	if (tex->imageLoad() && tex->glLoad())
 		return tex;
 	else
-		return ManagedSTextureSP();
+		return STextureSP();
 }
 
 
-/*************************************************************************
- Structure used to pass parameter to loading threads
-*************************************************************************/
-struct LoadQueueParam
-{
-	StelTextureMgr* texMgr;
-	std::vector<LoadQueueParam*>* loadQueue;
-	QMutex* loadQueueMutex;
-	QThread* thread;
-	ManagedSTextureSP tex;
-	bool toDownload;
-	std::string fileExtension;
-	
-	// Those 2 are used to return the final texture
-	std::vector<QueuedTex*>* outQueue;
-	QMutex* outQueueMutex;
-	std::string url;
-	std::string localPath;
-	std::string cookiesFile;
-	void* userPtr;
-	
-	QFile* file;
-};
-
-QueuedTex::~QueuedTex()
-{
-	if (file)
-		delete file;
-	file = NULL;
-}
-
-/*************************************************************************
- Local structure used by boost thread for running the thread
-*************************************************************************/
-class loadTextureThread : public QThread
-{
-public:
-	loadTextureThread(LoadQueueParam* p) : param(p) {;}
-	
-	virtual void run()
-	{
-		if (param->toDownload)
-		{
-			cout << "Downloading image " << param->url << " to " << param->localPath << endl;
-			StelUtils::downloadFile(param->url, param->localPath, StelApp::getApplicationName(), param->cookiesFile);
-			param->tex->fullPath = param->localPath;
-		}
-		
-		// Load the image
-		if (param->texMgr->loadImage(param->tex.get())==false)
-		{
-			param->tex->loadState = ManagedSTexture::LOAD_ERROR;
-		}
-		
-		// And add it to the loadQueue for final step in update()
-		QMutexLocker locker(param->loadQueueMutex);
-		param->loadQueue->push_back(param);
-	}
-
-private:
-	LoadQueueParam* param;
-};
 
 /*************************************************************************
  Load an image from a file and create a new texture from it in a new thread. 
- The created texture is inserted in the passed queue, protected by the given mutex.
- If the texture creation fails for any reasons, its loadState will be set to LOAD_ERROR
 *************************************************************************/
-bool StelTextureMgr::createTextureThread(const std::string& url, 
-	std::vector<QueuedTex*>* outQueue, QMutex* outQueueMutex, void* userPtr, 
-	const std::string& fileExtension, const std::string& cookiesFile)
+STextureSP StelTextureMgr::createTextureThread(const QString& url, const QString& fileExtension, bool lazyLoading)
 {
-	bool toDownload = false;
-	string filename = url;
-		
-	if (!StelFileMgr::exists(filename))
-	{
-		if (url[0]=='h' && url[1]=='t' && url[2]=='t' && url[3]=='p')
-		{
-			// Assume that the file must be downloaded
-			filename = "";
-			toDownload = true;
-		}
-		else
-		{
-			cerr << "WARNING : Can't find texture file " << filename << "!" << endl;
-			return ManagedSTextureSP();
-		}
-	}
+	if (url.isEmpty())
+		return STextureSP();
 	
-	ManagedSTextureSP tex = initTex(filename);
-	if (tex==NULL)
-		return false;
-
-	LoadQueueParam* tparam = new LoadQueueParam();
-	tparam->texMgr = this;
-	tparam->loadQueue = &loadQueue;
-	tparam->loadQueueMutex = loadQueueMutex;
-	tparam->tex = tex;
-	tparam->outQueue = outQueue;
-	tparam->outQueueMutex=outQueueMutex;
-	tparam->url = url;
-	tparam->cookiesFile = cookiesFile;
-	tparam->localPath = filename;
-	tparam->toDownload = toDownload;
-	tparam->userPtr = userPtr;
-	tparam->fileExtension = fileExtension;
-	tex->loadState = ManagedSTexture::LOADING_IMAGE;
-
-	// Create a temporary file name
-	if (toDownload)
+	STextureSP tex = initTex();
+	if (!url.startsWith("http://"))
 	{
-		QTemporaryFile* fic = new QTemporaryFile(QDir::tempPath() + "XXXXXX" + QString(tparam->fileExtension.c_str()));
-		if (!fic->open())
+		// Assume a local file
+		try
 		{
-			cerr << "WARNING in loadTextureThread::operator()(): can't create temp file." << endl;
+			tex->fullPath = StelApp::getInstance().getFileMgr().findFile(url);
+		}
+		catch (exception e)
+		{
+			try
+			{
+				tex->fullPath = StelApp::getInstance().getFileMgr().findFile("textures/" + url);
+			}
+			catch (exception e)
+			{
+				qWarning() << "WARNING : Can't find texture file " << url << ": " << e.what() << endl;
+				tex->errorOccured = true;
+				return STextureSP();
+			}
 		}
-		tparam->file = fic;
-		tparam->localPath = tparam->file->fileName().toStdString();
 	}
 	else
 	{
-		tparam->file = new QFile(tparam->localPath.c_str());
+		tex->fullPath = url;
 	}
-		
-	// Create and run the thread
-	QThread* thread = new loadTextureThread(tparam);
-	tparam->thread = thread;
-	thread->start();
-	return true;
-}
-
-/*************************************************************************
- Update loading of textures in threads
-*************************************************************************/
-void StelTextureMgr::update()
-{
-	// Load the successfully loaded images to openGL, because openGL is not thread safe,
-	// this has to be done in the main thread.
-	QMutexLocker locker(loadQueueMutex);
-	std::vector<LoadQueueParam*>::iterator iter = loadQueue.begin();
-	for (;iter!=loadQueue.end();++iter)
-	{
-		(*iter)->thread->wait();	// Ensure the thread is properly destroyed
-		
-		{
-			QMutexLocker locker((*iter)->outQueueMutex);
-			if ((*iter)->tex->loadState!=ManagedSTexture::LOAD_ERROR)
-			{
-				// Create openGL texture
-				if (glLoadTexture((*iter)->tex.get())==false)
-				{
-					// There was an error while loading the texture to openGL
-					(*iter)->tex->loadState=ManagedSTexture::LOAD_ERROR;
-				}
-			}
-			(*iter)->outQueue->push_back(new QueuedTex((*iter)->tex, (*iter)->userPtr, (*iter)->url, (*iter)->file));
-			delete (*iter);
-		}
-	}
-	loadQueue.clear();
+	tex->fileExtension = fileExtension;
+	if (!lazyLoading)
+		tex->bind();
+	return tex;
 }
 
 /*************************************************************************
  Adapt the scaling for the texture. Return true if there was no errors
  This method is re-entrant
 *************************************************************************/
-bool StelTextureMgr::reScale(ManagedSTexture* tex)
+bool StelTextureMgr::reScale(STexture* tex)
 {
 	const unsigned int nbPix = tex->width*tex->height;
 	const int bitpix = tex->internalFormat*8;
@@ -381,7 +208,7 @@ bool StelTextureMgr::reScale(ManagedSTexture* tex)
 	{
 		switch (tex->dynamicRangeMode)
 		{
-			case (ManagedSTexture::LINEAR):
+			case (STextureTypes::LINEAR):
 			{
 				if (tex->internalFormat==1)
 				{
@@ -396,11 +223,15 @@ bool StelTextureMgr::reScale(ManagedSTexture* tex)
 				{
 					return true;
 				}
+				if (tex->internalFormat==-4)
+				{
+					return true;
+				}
 				// Unsupported format..
-				cerr << "Internal format: " << tex->internalFormat << " is not supported for LUMINANCE texture " << tex->fullPath << endl;
+				qWarning() << "Internal format: " << tex->internalFormat << " is not supported for LUMINANCE texture " << tex->fullPath;
 				return false;
 			}
-			case (ManagedSTexture::MINMAX_QUANTILE):
+			case (STextureTypes::MINMAX_QUANTILE):
 			{
 				// Compute the image histogram
 				int* histo = (int*)calloc(sizeof(int), 1<<bitpix); 
@@ -422,7 +253,7 @@ bool StelTextureMgr::reScale(ManagedSTexture* tex)
 				else
 				{
 					// Unsupported format..
-					cerr << "Internal format: " << tex->internalFormat << " is not supported for LUMINANCE texture " << tex->fullPath << endl;
+					qWarning() << "Internal format: " << tex->internalFormat << " is not supported for LUMINANCE texture " << tex->fullPath;
 					return false;
 				}
 				
@@ -433,12 +264,12 @@ bool StelTextureMgr::reScale(ManagedSTexture* tex)
 				int thresh = (int)(minQuantile*nbPix);
 				int minI = 0;
 				// Start from 1 to ignore zeroed region in the image
-				for (int id=1;id<1<<bitpix;++id)
+				for (int idd=1;idd<1<<bitpix;++idd)
 				{
-					minI+=histo[id];
+					minI+=histo[idd];
 					if (minI>=thresh)
 					{
-						minCut = id;
+						minCut = idd;
 						break;
 					}
 				}
@@ -446,12 +277,12 @@ bool StelTextureMgr::reScale(ManagedSTexture* tex)
 				thresh = (int)((1.-maxQuantile)*nbPix);
 				int maxI = 0;
 				// Finish at 1 to ignore zeroed region in the image
-				for (int id=1<<bitpix;id>=1;--id)
+				for (int idd=1<<bitpix;idd>=1;--idd)
 				{
-					maxI+=histo[id];
+					maxI+=histo[idd];
 					if (maxI>=thresh)
 					{
-						maxCut = id;
+						maxCut = idd;
 						break;
 					}
 				}
@@ -485,14 +316,14 @@ bool StelTextureMgr::reScale(ManagedSTexture* tex)
 				else
 				{
 					// Unsupported format..
-					cerr << "Internal format: " << tex->internalFormat << " is not supported for LUMINANCE texture " << tex->fullPath << endl;
+					qWarning() << "Internal format: " << tex->internalFormat << " is not supported for LUMINANCE texture " << tex->fullPath;
 					return false;
 				}
 			}
 			break;
 			default:
 				// Unsupported dynamic range mode..
-				cerr << "Dynamic range mode: " << tex->dynamicRangeMode << " is not supported by the texture manager, texture " << tex->fullPath << " will not be loaded."<< endl;
+				qWarning() << "Dynamic range mode: " << (int)tex->dynamicRangeMode << " is not supported by the texture manager, texture " << tex->fullPath << " will not be loaded.";
 				return false;
 		}
 		return true;
@@ -507,29 +338,47 @@ bool StelTextureMgr::reScale(ManagedSTexture* tex)
 /*************************************************************************
   Load the image in memory by calling the associated ImageLoader
 *************************************************************************/
-bool StelTextureMgr::loadImage(ManagedSTexture* tex)
+bool StelTextureMgr::loadImage(STexture* tex)
 {
-	const string extension = tex->fullPath.substr((tex->fullPath.find_last_of('.', tex->fullPath.size()))+1);\
-	std::map<std::string, ImageLoader*>::iterator loadFuncIter = imageLoaders.find(extension);
+	if (tex->fileExtension.isEmpty())
+		tex->fileExtension = QFileInfo(tex->fullPath).suffix();
+	QMap<QString, ImageLoader*>::iterator loadFuncIter = imageLoaders.find(tex->fileExtension);
 	if (loadFuncIter==imageLoaders.end())
 	{
-		cerr << "Unsupported image file extension: " << extension << " for file: " << tex->fullPath << endl;
-		tex->loadState = ManagedSTexture::LOAD_ERROR;	// texture can't be loaded
+		qWarning() << "Unsupported image file extension: " << tex->fileExtension << " for file: " << tex->fullPath;
+		tex->texels = NULL;
 		return false;
 	}
 
 	// Load the image
-	if (!loadFuncIter->second->loadImage(tex->fullPath, *tex))
+	// Create a new texInfo withthe proper parameters
+	ImageLoader::TexInfo texInfo;
+	texInfo.format = tex->format;
+	texInfo.width = tex->width;
+	texInfo.height = tex->height;
+	texInfo.type = tex->type;
+	texInfo.internalFormat = tex->internalFormat;
+	texInfo.texels = tex->texels;
+	texInfo.fullPath = tex->fullPath;
+			
+	if (!loadFuncIter.value()->loadImage(tex->fullPath, texInfo))
 	{
-		cerr << "Image loading failed for file: " << tex->fullPath << endl;
-		tex->loadState = ManagedSTexture::LOAD_ERROR;	// texture can't be loaded
+		qWarning() << "Image loading failed for file: " << tex->fullPath;
+		tex->texels = NULL;
 		return false;
 	}
 
+	// Update texture parameters from TexInfo
+	tex->format = texInfo.format;
+	tex->width = texInfo.width;
+	tex->height = texInfo.height;
+	tex->type = texInfo.type;
+	tex->internalFormat = texInfo.internalFormat;
+	tex->texels = texInfo.texels;
+	
 	if (!tex->texels)
 	{
-		cerr << "Image loading failed for file: " << tex->fullPath << endl;
-		tex->loadState = ManagedSTexture::LOAD_ERROR;	// texture can't be loaded
+		qWarning() << "Image loading returned empty texels for file: " << tex->fullPath;
 		return false;
 	}
 
@@ -538,10 +387,14 @@ bool StelTextureMgr::loadImage(ManagedSTexture* tex)
 	{
 		free(tex->texels);
 		tex->texels = NULL;
-		tex->loadState = ManagedSTexture::LOAD_ERROR;
 		return false;
 	}
 
+// 	if (tex->computeLuminance==true)
+// 	{
+// 		
+// 	}
+	
 	// Repair texture size if non power of 2 is not allowed by the video driver
 	if (!isNoPowerOfTwoAllowed && (!StelUtils::isPowerOfTwo(tex->height) || !StelUtils::isPowerOfTwo(tex->width)))
 	{
@@ -551,6 +404,14 @@ bool StelTextureMgr::loadImage(ManagedSTexture* tex)
 		//cerr << "Resize to " << w << "x" << h << endl;
 		
 		GLubyte* texels2 = (GLubyte *)calloc (sizeof (GLubyte) * tex->internalFormat,  w*h);
+		if (texels2==NULL)
+		{
+			cerr << "Unsufficient memory for image data allocation: need to allocate array of " << w << "x" << h << " with " << sizeof (GLubyte) * tex->internalFormat << " bytes per pixels." << endl;
+			free(tex->texels);
+			tex->texels = NULL;
+			return false;
+		}
+		
 		// Copy data into the power of two buffer
 		for (int j=0;j<tex->height;++j)
 		{
@@ -589,43 +450,13 @@ bool StelTextureMgr::loadImage(ManagedSTexture* tex)
 	// Check that the image size is compatible with the hardware 
 	if (tex->width>maxTextureSize)
 	{
-		cerr << "Warning: texture " << tex->fullPath << " is larger than " << maxTextureSize << " pixels and might be not supported." << endl;
+		qWarning() << "Warning: texture " << tex->fullPath << " is larger than " << maxTextureSize << " pixels and might be not supported.";
 	}
 	
 	// The glLoading will be done later in the main thread
 	return true;
 }
 
-/*************************************************************************
- Actually load the texture already in the RAM to openGL memory
-*************************************************************************/
-bool StelTextureMgr::glLoadTexture(ManagedSTexture* tex)
-{
-	if (!tex->texels)
-		return false;
-	
-	// generate texture
-	glGenTextures (1, &(tex->id));
-	glBindTexture (GL_TEXTURE_2D, tex->id);
-	
-	// setup some parameters for texture filters and mipmapping
-	glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, tex->minFilter);
-	glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, tex->magFilter);
-	glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, tex->wrapMode);
-	glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, tex->wrapMode);
-
-	glTexImage2D (GL_TEXTURE_2D, 0, tex->internalFormat, tex->width, tex->height, 0, tex->format, tex->type, tex->texels);
-	if (tex->mipmapsMode==true)
-		gluBuild2DMipmaps (GL_TEXTURE_2D, tex->internalFormat, tex->width, tex->height, tex->format, tex->type, tex->texels);
-	// OpenGL has its own copy of texture data
-	free (tex->texels);
-	tex->texels = NULL;
-	
-	tex->loadState = ManagedSTexture::LOADED;	// texture loaded
-	
-	return true;
-}
-
 /*************************************************************************
  Load a PNG image from a file.
  Code borrowed from David HENRY with the following copyright notice:
@@ -654,7 +485,7 @@ bool StelTextureMgr::glLoadTexture(ManagedSTexture* tex)
  * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
  * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *************************************************************************/
-bool StelTextureMgr::PngLoader::loadImage(const string& filename, ManagedSTexture& texinfo)
+bool PngLoader::loadImage(const QString& filename, TexInfo& texinfo)
 {
 	png_byte magic[8];
 	png_structp png_ptr;
@@ -665,10 +496,10 @@ bool StelTextureMgr::PngLoader::loadImage(const string& filename, ManagedSTextur
 	int i;
 
 	/* open image file */
-	fp = fopen (filename.c_str(), "rb");
+	fp = fopen (QFile::encodeName(filename).constData(), "rb");
 	if (!fp)
 	{
-		cerr << "error: couldn't open \""<< filename << "\"!\n";
+		qWarning() << "error: couldn't open \""<< filename << "\"!";
 		return false;
 	}
 
@@ -678,7 +509,7 @@ bool StelTextureMgr::PngLoader::loadImage(const string& filename, ManagedSTextur
 	/* check for valid magic number */
 	if (!png_check_sig (magic, sizeof (magic)))
 	{
-		cerr << "error: \"" << filename << "\" is not a valid PNG image!\n";
+		qWarning() << "error: \"" << filename << "\" is not a valid PNG image!";
 		fclose (fp);
 		return false;
 	}
@@ -714,9 +545,10 @@ bool StelTextureMgr::PngLoader::loadImage(const string& filename, ManagedSTextur
 			free (texinfo.texels);
 		texinfo.texels = NULL;
 
+		qWarning() << "There was an error while loading PNG image: " << texinfo.fullPath;
 		return false;
 	}
-
+			
 	/* setup libpng for using standard C fread() function
 	   with our FILE pointer */
 	png_init_io (png_ptr, fp);
@@ -751,7 +583,6 @@ bool StelTextureMgr::PngLoader::loadImage(const string& filename, ManagedSTextur
 	/* update info structure to apply transformations */
 	png_read_update_info (png_ptr, info_ptr);
 
-	/* retrieve updated information */
 	/* retrieve updated information */
 	// johannes: never make pointer casts between pointers to int and long,
 	// because long is 64 bit on AMD64:
@@ -797,20 +628,34 @@ bool StelTextureMgr::PngLoader::loadImage(const string& filename, ManagedSTextur
 		// Badness
 		assert(0);
 	}
-
+	
 	/* we can now allocate memory for storing pixel data */
 	texinfo.texels = (GLubyte *)malloc (sizeof (GLubyte) * texinfo.width
 	                                     * texinfo.height * texinfo.internalFormat);
-
-	/* setup a pointer array.  Each one points at the begening of a row. */
+	if (!texinfo.texels)
+	{
+		qWarning() << "Not enough memory to allocate the PNG image texture " << texinfo.fullPath;
+		fclose (fp);
+		png_destroy_read_struct (&png_ptr, &info_ptr, NULL);
+		return false;
+	}
+	
+	/* setup a pointer array.  Each one points at the begining of a row. */
 	row_pointers = (png_bytep *)malloc (sizeof (png_bytep) * texinfo.height);
-
+	if (!row_pointers)
+	{
+		qWarning() << "Not enough memory to create the PNG image texture " << texinfo.fullPath;
+		fclose (fp);
+		png_destroy_read_struct (&png_ptr, &info_ptr, NULL);
+		return false;
+	}
+	
 	for (i = 0; i < texinfo.height; ++i)
 	{
 		row_pointers[i] = (png_bytep)(texinfo.texels +
 		                              ((texinfo.height - (i + 1)) * texinfo.width * texinfo.internalFormat));
 	}
-	
+
 	/* read pixel data using row pointers */
 	png_read_image (png_ptr, row_pointers);
 
@@ -877,17 +722,17 @@ void err_exit(j_common_ptr cinfo)
 }
 
 
-bool StelTextureMgr::JpgLoader::loadImage(const string& filename, ManagedSTexture& texinfo)
+bool JpgLoader::loadImage(const QString& filename, TexInfo& texinfo)
 {
 	FILE *fp = NULL;
 	struct jpeg_decompress_struct cinfo;
 	struct my_error_mgr jerr;
 
 	/* open image file */
-	fp = fopen (filename.c_str(), "rb");
+	fp = fopen(QFile::encodeName(filename).constData(), "rb");
 	if (!fp)
 	{
-		cerr << "Error: couldn't open \"" << filename << "\"!\n";
+		qWarning() << "Error: couldn't open \"" << filename << "\"!\n";
 		return false;
 	}
 
@@ -902,7 +747,7 @@ bool StelTextureMgr::JpgLoader::loadImage(const string& filename, ManagedSTextur
 	
 	if (setjmp(jerr.setjmp_buffer))
 	{
-		cerr << "Error: couldn't read jpeg file \"" << filename << "\"!\n";
+		qWarning() << "Error: couldn't read jpeg file \"" << filename << "\"!";
 		jpeg_destroy_decompress(&cinfo);
 		if (texinfo.texels)
 		{
