@@ -24,9 +24,10 @@
 #include <sstream>
 #include <iostream>
 #include <iomanip>
-
 #include <math.h>
 
+#include <QTextStream>
+
 #ifdef WIN32
   #include <windows.h> // GetSystemTimeAsFileTime
   #include <winsock2.h>
@@ -219,10 +220,9 @@ Telescope *Telescope::create(const string &url) {
 }
 
 
-Telescope::Telescope(const string &name) : name(name) {
-  std::wostringstream oss;
-  oss << name.c_str();
-  nameI18n = oss.str();
+Telescope::Telescope(const string &name) : name(name)
+{
+	nameI18n = StelUtils::stringToWstring(name);
 }
 
 wstring Telescope::getInfoString(const Navigator *nav) const {
@@ -232,15 +232,14 @@ wstring Telescope::getInfoString(const Navigator *nav) const {
   const Vec3d equatorial_pos = nav->j2000_to_earth_equ(j2000_pos);
   double dec_equ, ra_equ;
   StelUtils::rect_to_sphe(&ra_equ,&dec_equ,equatorial_pos);
-  std::wostringstream oss;
-  oss << nameI18n << endl
-      << _("J2000") << L" " << _("RA/DE: ")
-      << StelUtils::radToHmsWstr(ra_j2000,false)
-      << L"/" << StelUtils::radToDmsWstr(dec_j2000,false) << endl
-      << _("Equ of date") << L" " << _("RA/DE: ")
-      << StelUtils::radToHmsWstr(ra_equ)
-      << L"/" << StelUtils::radToDmsWstr(dec_equ);
-  return oss.str();
+  QString str;
+  QTextStream oss(&str);
+  oss << QString::fromStdWString(nameI18n) << endl
+		<< q_("J2000") << " " << q_("RA/DE: ") << StelUtils::radToHmsStr(ra_j2000,false)
+		<< "/" << StelUtils::radToDmsStr(dec_j2000,false) << endl
+		<< q_("Equ of date") << " " << q_("RA/DE: ")
+		<< StelUtils::radToHmsStr(ra_equ) << "/" << StelUtils::radToDmsStr(dec_equ);
+  return str.toStdWString();
 }
 
 wstring Telescope::getShortInfoString(const Navigator*) const {
@@ -600,7 +599,7 @@ void TelescopeTcp::handleSelectFds(const fd_set &read_fds,
                                    const fd_set &write_fds) {
   if (!IS_INVALID_SOCKET(fd)) {
     if (wait_for_connection_establishment) {
-      if (FD_ISSET(fd,&write_fds)) {
+		if (FD_ISSET(fd,const_cast<fd_set *>(&write_fds))) {
         wait_for_connection_establishment = false;
         int err = 0;
         SOCKLEN_T length = sizeof(err);
@@ -620,10 +619,10 @@ void TelescopeTcp::handleSelectFds(const fd_set &read_fds,
         }
       }
     } else { // connection already established
-      if (FD_ISSET(fd,&write_fds)) {
+		if (FD_ISSET(fd,const_cast<fd_set *>(&write_fds))) {
         performWriting();
       }
-      if (!IS_INVALID_SOCKET(fd) && FD_ISSET(fd,&read_fds)) {
+	  if (!IS_INVALID_SOCKET(fd) && FD_ISSET(fd,const_cast<fd_set *>(&read_fds))) {
         performReading();
       }
     }
