@@ -20,11 +20,12 @@
 // manage an audio track (SDL mixer music track)
 
 #include <iostream>
-#include "audio.h"
-#include "stellarium.h"
-#include "translator.h"
+#include <config.h>
 
-#ifdef HAVE_SDL_MIXER_H
+#include "audio.h"
+#include "Translator.hpp"
+
+#ifdef HAVE_SDL_SDL_MIXER_H
 
 float Audio::master_volume = 0.5;
 
@@ -72,7 +73,7 @@ void Audio::play(bool loop) {
 }
 
 // used solely to track elapsed seconds of play
-void Audio::update(int delta_time) {
+void Audio::update(double delta_time) {
 	
 	if(track) elapsed_seconds += delta_time/1000.f;
 
@@ -82,12 +83,11 @@ void Audio::update(int delta_time) {
 void Audio::sync() {
 	if(track==NULL) return;
 
-	Mix_RewindMusic();
 	Mix_SetMusicPosition(elapsed_seconds);  // ISSUE doesn't work for all audio formats
 	Mix_ResumeMusic();
 	is_playing = 1;
 
-	//	printf("Synced audio to %f seconds\n", elapsed_seconds);
+	// printf("Synced audio to %f seconds\n", elapsed_seconds);
 }
 
 void Audio::pause() {
