@@ -20,13 +20,18 @@
 // manage an assortment of script loaded images
 
 #include <iostream>
+#include <QFile>
 #include "image_mgr.h"
 #include "Projector.hpp"
 #include "Navigator.hpp"
+#include "script_mgr.h"
+#include "StelApp.hpp"
+#include "StelModuleMgr.hpp"
+#include "StelCore.hpp"
 
 ImageMgr::ImageMgr()
 {
-	dependenciesOrder["draw"]="landscape";
+	setObjectName("ImageMgr");
 }
 
 ImageMgr::~ImageMgr()
@@ -34,7 +39,17 @@ ImageMgr::~ImageMgr()
     drop_all_images();
 }
 
-int ImageMgr::load_image(string filename, string name, Image::IMAGE_POSITIONING position_type)
+/*************************************************************************
+ Reimplementation of the getCallOrder method
+*************************************************************************/
+double ImageMgr::getCallOrder(StelModuleActionName actionName) const
+{
+	if (actionName==StelModule::ACTION_DRAW)
+		return StelApp::getInstance().getModuleMgr().getModule("LandscapeMgr")->getCallOrder(actionName)+10;
+	return 0;
+}
+
+int ImageMgr::load_image(QString filename, string name, Image::IMAGE_POSITIONING position_type)
 {
 
     // if name already exists, replace with new image (hash would have been easier...)
@@ -48,7 +63,7 @@ int ImageMgr::load_image(string filename, string name, Image::IMAGE_POSITIONING
         }
     }
 
-    Image *img = new Image(filename, name, position_type);
+    Image *img = new Image(QFile::encodeName(filename).constData(), name, position_type);
 
     if (!img || img->image_loaded())
     {
@@ -95,21 +110,28 @@ Image * ImageMgr::get_image(string name)
 
 void ImageMgr::update(double delta_time)
 {
+	ScriptMgr* scripts = (ScriptMgr*)StelApp::getInstance().getModuleMgr().getModule("ScriptMgr");
+	if(scripts->is_paused())
+		return;
     for (vector<Image*>::iterator iter = active_images.begin(); iter != active_images.end(); ++iter)
     {
         (*iter)->update(delta_time);
     }
 }
 
-double ImageMgr::draw(Projector *prj, const Navigator *nav, ToneReproducer *eye)
+double ImageMgr::draw(StelCore* core)
 {
+	Navigator* nav = core->getNavigation();
+	Projector* prj = core->getProjection();
+	
     for (vector<Image*>::iterator iter = active_images.begin(); iter != active_images.end(); ++iter)
     {
         (*iter)->draw(nav, prj);
     }
-	
 
-	if(active_images.begin() == active_images.end()) return 0.0;  
-	else return 100.0;  // TODO: determine max pixel movement from images
+	if(active_images.begin() == active_images.end())
+		return 0.0;
+	else
+		return 100.0;  // TODO: determine max pixel movement from images
 }
 
