@@ -20,6 +20,9 @@
 #include <iostream>
 #include <sstream>
 #include <fstream>
+#include <QTextStream>
+#include <QStringList>
+
 #include "s_gui.h"
 #include "StelUtils.hpp"
 #include "STexture.hpp"
@@ -1258,14 +1261,14 @@ bool EditBox::onKey(Uint16 k, Uint8 s, StelMod mod)
         }
   		else if (k == StelKey_LEFT)  		
   		{
-            if (mod & StelMod_CTRL)
+            if (mod & COMPATIBLE_StelMod_CTRL)
                 cursorToPrevWord();
             else
                 if (cursorPos > 0) cursorPos--;
         }
         else if (k == StelKey_RIGHT)
         {
-            if (mod & StelMod_CTRL)
+            if (mod & COMPATIBLE_StelMod_CTRL)
                 cursorToNextWord();
             else
               if (cursorPos < text.length()) cursorPos++;
@@ -1693,11 +1696,11 @@ void ListBox::addItems(const vector<wstring> _items)
 
 void ListBox::addItemList(const wstring& s)
 {
-	wistringstream is(s);
-	wstring elem;
-	while(getline(is, elem))
+	QString str = QString::fromStdWString(s);
+	QStringList l = str.split('\n');
+	for (int i=0;i<l.size();++i)
 	{
-		addItem(elem);
+		addItem(l.at(i).toStdWString());
 	}
 }
 
@@ -1852,21 +1855,23 @@ void TextLabel::setLabel(const wstring& _label)
     childs.clear();
 
     Label * tempLabel;
-    wstring pch;
 
     unsigned int i = 0;
 	unsigned int lineHeight = (int)painter.getFont()->getLineHeight()+1;
 
-	wistringstream is(label);
-    while (getline(is, pch))
-    {
-        tempLabel = new Label();
+    QString sp = QString::fromStdWString(label);
+	QTextStream is(&sp);
+	is.reset();
+	while(!is.atEnd())
+	{
+		tempLabel = new Label();
 		tempLabel->setPainter(painter);
-        tempLabel->setLabel(pch);
-        tempLabel->setPos(0,i*lineHeight);
-        addComponent(tempLabel);
-        i++;
-    }
+		QString elem = is.readLine();
+		tempLabel->setLabel(elem.toStdWString());
+		tempLabel->setPos(0,i*lineHeight);
+		addComponent(tempLabel);
+		++i;
+	}
     adjustSize();
 }
 
@@ -2674,7 +2679,7 @@ void FloatIncDec::draw()
 	}
 	else if (format == FORMAT_LONGITUDE || format == FORMAT_LATITUDE)
 	{
-		wstring l = StelUtils::radToDmsWstr(value*M_PI/180.);
+		wstring l = StelUtils::radToDmsStr(value*M_PI/180.).toStdWString();
 		wstring m = l.substr(1);
 		if (format == FORMAT_LATITUDE)
 		{
@@ -2719,7 +2724,7 @@ Time_item::Time_item(SFont* _font, const STextureSP tex_up,
 	if (_font) setFont(_font);
 
 	// ranges are +1 and -1 from normal to allow rollover
-	y = new IntIncDec(getFont(), tex_up, tex_down, -9999, 99999, 1930, 1);
+	y = new IntIncDec(getFont(), tex_up, tex_down, -99999, 99999, 1930, 1);
 	m = new IntIncDec(getFont(), tex_up, tex_down, 1, 12, 12, 1, true);
 	d = new IntIncDec(getFont(), tex_up, tex_down, 1, 31, 11, 1, true);
 	h = new IntIncDec(getFont(), tex_up, tex_down, 0, 23, 16, 1, true);
@@ -2801,14 +2806,29 @@ double Time_item::getJDay(void) const
 // for use with commands - no special characters, just the local date
 string Time_item::getDateString(void)
 {
-	ostringstream os;
-	os << y->getValue() << ":"
-	   << m->getValue() << ":"
-	   << d->getValue() << "T"
-	   << h->getValue() << ":"
-	   << mn->getValue() << ":"
-	   << s->getValue();
-	return os.str();
+	QString outStr;
+	QTextStream os(&outStr); 
+	
+	int yearAbs = (int)abs(y->getValue());
+    //If needed, convert the year to BC and deal with year zero. (year -2 = 3BC, year 0 = 1BC
+	QString yStr;
+	if (y->getValue() <= 0) 
+    {
+        yStr = QString("-%1").arg(yearAbs+1, 3, 10, QLatin1Char('0'));
+    }
+    else 
+    {
+    	yStr = QString("%1").arg(yearAbs, 4, 10, QLatin1Char('0'));
+    }
+    
+	os << yStr << ":"
+		<< QString("%1").arg((int)m->getValue(),2, 10, QLatin1Char('0')) << ":"
+		<< QString("%1").arg((int)d->getValue(),  2, 10, QLatin1Char('0')) << "T"
+		<< QString("%1").arg((int)h->getValue(), 2, 10, QLatin1Char('0')) << ":"
+		<< QString("%1").arg((int)mn->getValue(),  2, 10, QLatin1Char('0')) << ":"
+		<< QString("%1").arg((int)s->getValue(),  2, 10, QLatin1Char('0'));   
+					
+	return outStr.toStdString();
 }
 
 void Time_item::setJDay(double JD)
@@ -3169,7 +3189,7 @@ bool MapPicture::onKey(Uint16 k, Uint8 s, StelMod mod)
 
 void MapPicture::calcPointerPos(int x, int y, StelMod mod)
 {
-	if (mod & StelMod_CTRL)
+	if (mod & COMPATIBLE_StelMod_CTRL)
 	{
 		nearestIndex = cities.getNearest(getLongitudeFromx(x - pos[0]), getLatitudeFromy(y - pos[1]));
 		if (nearestIndex != -1)
