@@ -27,20 +27,21 @@ using namespace std;
 
 #include <fstream>
 #include <string>
-
+#include <QString>
+				 
 class Script
 {
 
  public:
   Script();
   ~Script();
-  int load(string script_file, string script_path);         // open a script file
+  int load(QString script_file, QString script_path);         // open a script file
   int next_command(string &command);    // retreive next command to execute
-  string get_path() { return path; };
+  QString get_path() { return path; };
 
  private:
   ifstream * input_file;
-  string path;
+  QString path;
 
 };
 
