@@ -23,31 +23,41 @@
 #include <cstdio>
 #include <sstream>
 #include <iomanip>
+#include <QFile>
 
 #include "script_mgr.h"
 #include "script.h"
 #include "stel_command_interface.h"
 #include "StelApp.hpp"
 #include "StelFileMgr.hpp"
+#include "InitParser.hpp"
 
 using namespace std;
 
 ScriptMgr::ScriptMgr(StelCommandInterface *command_interface) : play_paused(false) {
+	setObjectName("ScriptMgr");
 	commander = command_interface;
 	recording = 0;
 	playing = 0;
 	record_elapsed_time = 0;
-
+	scripts_can_write_files = false;
 	// used when scripts are on a CD that needs to be mounted manually
 	RemoveableScriptDirectory = "";
 	RemoveableDirectoryMounted = 0;
+
 }
 
 ScriptMgr::~ScriptMgr() {
 }
 
+void ScriptMgr::init(const InitParser& conf)
+{
+	set_allow_ui( conf.get_boolean("scripts","flag_script_allow_ui",0) );
+	scripts_can_write_files = conf.get_boolean("scripts","scripting_allow_write_files", false);
+}
+
 // path is used for loading script assets 
-bool ScriptMgr::play_script(string script_file, string script_path) {
+bool ScriptMgr::play_script(const QString& script_file, const QString& script_path) {
 	// load script...
 	
 	if(playing){
@@ -61,11 +71,11 @@ bool ScriptMgr::play_script(string script_file, string script_path) {
 	script = new Script();
 
 	// if script is on mountable disk, mount that now
-	if( RemoveableScriptDirectory != "" &&
-		script_file.compare(0,RemoveableScriptDirectory.length(), RemoveableScriptDirectory) ==0) {
+	if( RemoveableScriptDirectory != "" && script_file.startsWith(RemoveableScriptDirectory))
+	{
 		try
 		{
-			system(StelApp::getInstance().getFileMgr().findFile("data/script_mount_script_disk" ).c_str());	  
+			system(QFile::encodeName(StelApp::getInstance().getFileMgr().findFile("data/script_mount_script_disk")).constData());	  
 			cout << "MOUNT DISK to read script" << endl;
 			RemoveableDirectoryMounted = 1;
 		}
@@ -98,7 +108,7 @@ void ScriptMgr::cancel_script() {
 	if(RemoveableDirectoryMounted) {
 		try
 		{
-			system(StelApp::getInstance().getFileMgr().findFile("data/script_unmount_script_disk" ).c_str());	  
+			system(QFile::encodeName(StelApp::getInstance().getFileMgr().findFile("data/script_unmount_script_disk")).constData());  
 			cout << "UNMOUNT DISK" << endl;
 			RemoveableDirectoryMounted = 0;
 		}
@@ -133,9 +143,10 @@ void ScriptMgr::record_script(string script_filename) {
 
 	// If we get no script filename as a parameter we should make a new one.
 	if(script_filename == "") {
-		string scriptSaveDir;
+		QString scriptSaveDir;
 		try
 		{
+			// this probably wont work with non-ascii username.  handle this in StelFileMgr?  nkerr
 			scriptSaveDir = StelApp::getInstance().getFileMgr().getUserDir() + "/scripts";
 			if (!StelApp::getInstance().getFileMgr().exists(scriptSaveDir))
 			{
@@ -151,12 +162,12 @@ void ScriptMgr::record_script(string script_filename) {
 			return;
 		}
 		
-		string scriptPath;
+		QString scriptPath;
 		for(int j=0; j<1000; ++j)
 		{
 			stringstream oss;
 			oss << setfill('0') << setw(3) << j;
-			scriptPath = scriptSaveDir +"/"+ (string("recorded-") + oss.str() + ".sts");
+			scriptPath = scriptSaveDir +"/"+ "recorded-" + oss.str().c_str() + ".sts";
 			if (!StelApp::getInstance().getFileMgr().exists(scriptPath))
 				break;
 		}
@@ -168,7 +179,7 @@ void ScriptMgr::record_script(string script_filename) {
 		}
 		else
 		{
-			script_filename = scriptPath;
+			script_filename = QFile::encodeName(scriptPath).constData();
 		}
 	}
 	
@@ -216,20 +227,16 @@ void ScriptMgr::cancel_record_script() {
 // note that waits can drift by up to 1/fps seconds
 void ScriptMgr::update(double delta_time) 
 {
-
-	if(recording) record_elapsed_time += (unsigned long int)delta_time;
+	if(recording) record_elapsed_time += (unsigned long int)(delta_time * 1000);
 
 	if(playing && !play_paused) 
 	{
-
-		elapsed_time += (unsigned long int) delta_time;  // time elapsed since last command (should have been) executed
-
+		// time elapsed since last command (should have been) executed
+		elapsed_time += (unsigned long int)(delta_time * 1000);  
+		
 		if(elapsed_time >= wait_time) 
 		{
 			// now time to run next command
-
-
-			//      cout << "dt " << delta_time << " et: " << elapsed_time << endl;
 			elapsed_time -= wait_time;
 			string comd;
 			unsigned long int wait;
@@ -256,15 +263,14 @@ void ScriptMgr::update(double delta_time)
  returns a string list of script file names, delimited with the '\n' 
  character
 ****************************************************************************/
-string ScriptMgr::get_script_list(string directory) {
+string ScriptMgr::get_script_list(QString directory) {
 	string result="";
 	// if directory is on mountable disk, mount that now
-	if(RemoveableScriptDirectory!="" 
-	   && directory.compare(0,RemoveableScriptDirectory.length(), RemoveableScriptDirectory)==0) 
+	if(RemoveableScriptDirectory!="" && directory.startsWith(RemoveableScriptDirectory)) 
 	{
 		try
 		{
-			system(StelApp::getInstance().getFileMgr().findFile("data/script_mount_script_disk").c_str());	  
+			system(QFile::encodeName(StelApp::getInstance().getFileMgr().findFile("data/script_mount_script_disk")).constData());
 			cout << "MOUNT DISK to read directory\n";
 			directory += "/scripts";
 			RemoveableDirectoryMounted = 1;
@@ -278,12 +284,12 @@ string ScriptMgr::get_script_list(string directory) {
 	try
 	{
 		// we add an entry if there exists <directory>/scriptname/scriptname.sts
-		set<string> scriptList = StelApp::getInstance().getFileMgr().listContents(directory, StelFileMgr::FILE);
-		for(set<string>::iterator i=scriptList.begin(); i!=scriptList.end(); i++)
+		QSet<QString> scriptList = StelApp::getInstance().getFileMgr().listContents(directory, StelFileMgr::FILE);
+		for(QSet<QString>::iterator i=scriptList.begin(); i!=scriptList.end(); i++)
 		{
-			if (string(*i, i->length()-4, 4) == ".sts" )
+			if (i->endsWith(".sts"))
 			{
-				result = result + *i + '\n';
+				result = result + (*i).toUtf8().data() + '\n';
 			}
 		}
 	}
@@ -295,7 +301,7 @@ string ScriptMgr::get_script_list(string directory) {
 	if(RemoveableDirectoryMounted) {
 		try
 		{
-			system(StelApp::getInstance().getFileMgr().findFile("data/script_unmount_script_disk").c_str());	  
+			system(QFile::encodeName(StelApp::getInstance().getFileMgr().findFile("data/script_unmount_script_disk")).constData());
 			cout << "UNMOUNT DISK" << endl;
 			RemoveableDirectoryMounted = 0;
 		}
@@ -308,7 +314,7 @@ string ScriptMgr::get_script_list(string directory) {
 	return result;
 }
 
-string ScriptMgr::get_script_path() { 
+QString ScriptMgr::get_script_path() { 
 	if(script) return script->get_path(); 
 	return ""; 
 }
@@ -324,8 +330,8 @@ bool ScriptMgr::play_startup_script() {
 	} 
 	else {
 		try {
-			string fullPath(StelApp::getInstance().getFileMgr().findFile("scripts/startup.sts")); 
-			string parentDir(StelApp::getInstance().getFileMgr().dirName(fullPath));
+			QString fullPath(StelApp::getInstance().getFileMgr().findFile("scripts/startup.sts")); 
+			QString parentDir(StelApp::getInstance().getFileMgr().dirName(fullPath));
 			play_script(fullPath, parentDir + "/");
 		}
 		catch(exception& e)
