@@ -21,6 +21,7 @@
 #include <sstream>
 #include <string>
 #include <algorithm>
+#include <QFile>
 
 #include "stel_command_interface.h"
 #include "StelCore.hpp"
@@ -28,6 +29,7 @@
 #include "audio.h"
 #include "image.h"
 #include "stel_ui.h"
+#include "script_mgr.h"
 #include "StarMgr.hpp"
 #include "ConstellationMgr.hpp"
 #include "SolarSystem.hpp"
@@ -54,6 +56,7 @@ using namespace std;
 
 StelCommandInterface::StelCommandInterface(StelCore * core, StelApp * app) : FlagTimePause(0)
 {
+	setObjectName("StelCommandInterface");
   stcore = core;
   stapp = app;
   audio = NULL;
@@ -96,7 +99,7 @@ int StelCommandInterface::execute_command(string command, int arg) {
 // they are "trusted" - TODO details TBD when needed
 int StelCommandInterface::execute_command(string commandline, unsigned long int &wait, bool trusted) {
 	string command;
-	stringHash_t args;
+	map<string, string> args;
 	int status = 0;  // true if command was understood
 	int recordable = 1;  // true if command should be recorded (if recording)
 	wstring debug_message;  // detailed errors can be placed in here for printout at end of method
@@ -105,17 +108,22 @@ int StelCommandInterface::execute_command(string commandline, unsigned long int
 
 	status = parse_command(commandline, command, args);
 
-	ConstellationMgr* cmgr = (ConstellationMgr*)StelApp::getInstance().getModuleMgr().getModule("constellations");
-	StarMgr* smgr = (StarMgr*)StelApp::getInstance().getModuleMgr().getModule("stars");
-	NebulaMgr* nmgr = (NebulaMgr*)StelApp::getInstance().getModuleMgr().getModule("nebulas");
-	SolarSystem* ssmgr = (SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("ssystem");
-	LandscapeMgr* lmgr = (LandscapeMgr*)StelApp::getInstance().getModuleMgr().getModule("landscape");
-	MovementMgr* mvmgr = (MovementMgr*)StelApp::getInstance().getModuleMgr().getModule("movements");
-	MeteorMgr* metmgr = (MeteorMgr*)StelApp::getInstance().getModuleMgr().getModule("meteors");
+	ConstellationMgr* cmgr = (ConstellationMgr*)StelApp::getInstance().getModuleMgr().getModule("ConstellationMgr");
+	StarMgr* smgr = (StarMgr*)StelApp::getInstance().getModuleMgr().getModule("StarMgr");
+	NebulaMgr* nmgr = (NebulaMgr*)StelApp::getInstance().getModuleMgr().getModule("NebulaMgr");
+	SolarSystem* ssmgr = (SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("SolarSystem");
+	LandscapeMgr* lmgr = (LandscapeMgr*)StelApp::getInstance().getModuleMgr().getModule("LandscapeMgr");
+	MovementMgr* mvmgr = (MovementMgr*)StelApp::getInstance().getModuleMgr().getModule("MovementMgr");
+	MeteorMgr* metmgr = (MeteorMgr*)StelApp::getInstance().getModuleMgr().getModule("MeteorMgr");
+	ScriptMgr* scripts = (ScriptMgr*)StelApp::getInstance().getModuleMgr().getModule("ScriptMgr");
 	
 	// stellarium specific logic to run each command
 
-	if(command == "flag") {
+	if(command == "echo") {
+		// For debugging purposes
+		cout << commandline << endl;
+
+	} else if (command == "flag") {
 
 		// could loop if want to allow that syntax
 		if(args.begin() != args.end()) {  
@@ -132,7 +140,6 @@ int StelCommandInterface::execute_command(string commandline, unsigned long int
 		} else status = 0;
 
 	}  else if (command == "wait" && args["duration"]!="") {
-
 		float fdelay = StelUtils::stringToDouble(args["duration"]);
 		if(fdelay > 0) wait = (int)(fdelay*1000);
 
@@ -142,18 +149,18 @@ int StelCommandInterface::execute_command(string commandline, unsigned long int
 		// TODO: some bounds/error checking here
 		
 		if(args["atmosphere_fade_duration"]!="") lmgr->setAtmosphereFadeDuration(StelUtils::stringToDouble(args["atmosphere_fade_duration"]));
-		else if(args["auto_move_duration"]!="") mvmgr->setAutomoveDuration( StelUtils::stringToDouble(args["auto_move_duration"]));
+		else if(args["auto_move_duration"]!="") mvmgr->setAutoMoveDuration( StelUtils::stringToDouble(args["auto_move_duration"]));
 		else if(args["constellation_art_fade_duration"]!="") cmgr->setArtFadeDuration(StelUtils::stringToDouble(args["constellation_art_fade_duration"]));
 		else if(args["constellation_art_intensity"]!="") cmgr->setArtIntensity(StelUtils::stringToDouble(args["constellation_art_intensity"]));
-		else if(args["home_planet"]!="") stcore->setHomePlanet(args["home_planet"]);
-		else if(args["landscape_name"]!="") lmgr->setLandscape(args["landscape_name"]);
+		else if(args["home_planet"]!="") stcore->getObservatory()->setHomePlanet(args["home_planet"].c_str());
+		else if(args["landscape_name"]!="") lmgr->setLandscapeByName(args["landscape_name"].c_str());
 		else if(args["light_pollution_luminance"]!="") 
 			lmgr->setAtmosphereLightPollutionLuminance(StelUtils::stringToDouble(args["light_pollution_luminance"]));
 		else if(args["max_mag_nebula_name"]!="") nmgr->setMaxMagHints(StelUtils::stringToDouble(args["max_mag_nebula_name"]));
 		else if(args["max_mag_star_name"]!="") smgr->setMaxMagName(StelUtils::stringToDouble(args["max_mag_star_name"]));
 		else if(args["moon_scale"]!="") ssmgr->setMoonScale(StelUtils::stringToDouble(args["moon_scale"]));
-		else if(args["sky_culture"]!="") stapp->getSkyCultureMgr().setSkyCultureDir(args["sky_culture"]);
-		else if(args["sky_locale"]!="") stapp->getLocaleMgr().setSkyLanguage(args["sky_locale"]);
+		else if(args["sky_culture"]!="") stapp->getSkyCultureMgr().setSkyCultureDir(args["sky_culture"].c_str());
+		else if(args["sky_locale"]!="") stapp->getLocaleMgr().setSkyLanguage(args["sky_locale"].c_str());
 		else if(args["star_mag_scale"]!="") smgr->setMagScale(StelUtils::stringToDouble(args["star_mag_scale"]));
 		else if(args["star_scale"]!="") {
 			float scale = StelUtils::stringToDouble(args["star_scale"]);
@@ -168,7 +175,7 @@ int StelCommandInterface::execute_command(string commandline, unsigned long int
 		else if(args["star_twinkle_amount"]!="") smgr->setTwinkleAmount(StelUtils::stringToDouble(args["star_twinkle_amount"]));
 		else if(args["time_zone"]!="") stapp->getLocaleMgr().setCustomTimezone(args["time_zone"]);
 		else if(args["milky_way_intensity"]!="") {
-			MilkyWay* mw = (MilkyWay*)stapp->getModuleMgr().getModule("milkyway");
+			MilkyWay* mw = (MilkyWay*)stapp->getModuleMgr().getModule("MilkyWay");
 			mw->setIntensity(StelUtils::stringToDouble(args["milky_way_intensity"]));
 			// safety feature to be able to turn back on
 			if(mw->getIntensity()) mw->setFlagShow(true);
@@ -205,23 +212,23 @@ int StelCommandInterface::execute_command(string commandline, unsigned long int
 
 		
 		if(args["hp"]!=""){
-			StelApp::getInstance().getStelObjectMgr().setSelectedObject( smgr->searchByName(string("HP") + args["hp"]), false);
+			StelApp::getInstance().getStelObjectMgr().setSelectedObject( smgr->searchByName(string("HP") + args["hp"]), StelModule::REPLACE_SELECTION);
 		}
 		else if(args["star"]!="") {
-			StelApp::getInstance().getStelObjectMgr().setSelectedObject( smgr->searchByName(args["star"]), false);
+			StelApp::getInstance().getStelObjectMgr().setSelectedObject( smgr->searchByName(args["star"]), StelModule::REPLACE_SELECTION);
 		} 
 		else if(args["planet"]!=""){
-			StelApp::getInstance().getStelObjectMgr().setSelectedObject( ssmgr->searchByName(args["planet"]), false);
+			StelApp::getInstance().getStelObjectMgr().setSelectedObject( ssmgr->searchByName(args["planet"]), StelModule::REPLACE_SELECTION);
 		} 
 		else if(args["nebula"]!=""){
-			StelApp::getInstance().getStelObjectMgr().setSelectedObject( nmgr->searchByName(args["nebula"]), false);
+			StelApp::getInstance().getStelObjectMgr().setSelectedObject( nmgr->searchByName(args["nebula"]), StelModule::REPLACE_SELECTION);
 		} 
 		else if(args["constellation"]!=""){
-			StelApp::getInstance().getStelObjectMgr().setSelectedObject( cmgr->searchByName(args["constellation"]), true);
+			StelApp::getInstance().getStelObjectMgr().setSelectedObject( cmgr->searchByName(args["constellation"]), StelModule::ADD_TO_SELECTION);
 		} 
 		else if(args["constellation_star"]!=""){
 			// This is no longer supported as easy to just select a star.  Here for backward compatibility.
-			StelApp::getInstance().getStelObjectMgr().setSelectedObject( cmgr->searchByName(args["constellation_star"]), true);
+			StelApp::getInstance().getStelObjectMgr().setSelectedObject( cmgr->searchByName(args["constellation_star"]), StelModule::ADD_TO_SELECTION);
 			cout << "WARNING: select constellation_star comand is no longer fully supported.\n";
 		} else {
 			// unselect current selection 
@@ -239,22 +246,21 @@ int StelCommandInterface::execute_command(string commandline, unsigned long int
     
 
 	} else if (command == "deselect") {
-		/* TODO
 		if(args["constellation"] != "") { 
-			stcore->unsetSelectedConstellation(args["constellation"]);
+			StelApp::getInstance().getStelObjectMgr().setSelectedObject( cmgr->searchByName(args["constellation"]), StelModule::REMOVE_FROM_SELECTION);
 		} else {
-			stcore->deselect();
+			StelApp::getInstance().getStelObjectMgr().unSelect();
 		}
-		*/
-
-		StelApp::getInstance().getStelObjectMgr().unSelect();
 
 	} else if(command == "look") {  // change direction of view
 
 		if(args["delta_az"]!="" || args["delta_alt"]!="") {
 			// immediately change viewing direction
-			mvmgr->panView(StelUtils::stringToDouble(args["delta_az"]),
-							StelUtils::stringToDouble(args["delta_alt"]));
+			double dAz = 0.0;
+			double dAlt = 0.0;
+			if (args["delta_az"]!="") dAz = StelUtils::stringToDouble(args["delta_az"]);
+			if (args["delta_alt"]!="") dAlt = StelUtils::stringToDouble(args["delta_alt"]);
+			mvmgr->panView(dAz, dAlt);
 		}	else status = 0;
 
 		// TODO absolute settings (see RFE 1311031)
@@ -263,7 +269,8 @@ int StelCommandInterface::execute_command(string commandline, unsigned long int
 	  
 
 	} else if(command == "zoom") {
-		double duration = StelUtils::stringToDouble(args["duration"]);
+		double duration=0.0;
+		if (args["duration"]!="") duration = StelUtils::stringToDouble(args["duration"]);
 
 		if(args["auto"]!="") {
 			// auto zoom using specified or default duration
@@ -277,7 +284,7 @@ int StelCommandInterface::execute_command(string commandline, unsigned long int
 
 		} else if (args["fov"]!="") {
 			// zoom to specific field of view
-			mvmgr->zoomTo( StelUtils::stringToDouble(args["fov"]), StelUtils::stringToDouble(args["duration"]));
+			mvmgr->zoomTo( StelUtils::stringToDouble(args["fov"]), duration);
 
 		} else if (args["delta_fov"]!="") stcore->getProjection()->setFov(stcore->getProjection()->getFov() + StelUtils::stringToDouble(args["delta_fov"]));
 		// should we record absolute fov instead of delta? isn't usually smooth playback
@@ -333,7 +340,7 @@ int StelCommandInterface::execute_command(string commandline, unsigned long int
 
 			if(args["local"][0] == 'T') {
 				// set time only (don't change day)
-				string sky_date = stapp->getLocaleMgr().get_ISO8601_time_local(stcore->getNavigation()->getJDay());
+				string sky_date = stapp->getLocaleMgr().get_ISO8601_time_local(stcore->getNavigation()->getJDay()).toStdString();
 				new_date = sky_date.substr(0,10) + args["local"];
 			} else new_date = args["local"];
 
@@ -368,14 +375,14 @@ int StelCommandInterface::execute_command(string commandline, unsigned long int
 
 		} else if(args["load"]=="current") {
 			// set date to current date
-			stcore->getNavigation()->setJDay(get_julian_from_sys());
+			stcore->getNavigation()->setJDay(StelUtils::getJDFromSystem());
 		} else if(args["load"]=="preset") {
 			// set date to preset (or current) date, based on user setup
 			// TODO: should this record as the actual date used?
 			if (stcore->getNavigation()->getStartupTimeMode()=="preset" || stcore->getNavigation()->getStartupTimeMode()=="Preset")
 				stcore->getNavigation()->setJDay(stcore->getNavigation()->getPresetSkyTime() -
 				                stapp->getLocaleMgr().get_GMT_shift(stcore->getNavigation()->getPresetSkyTime()) * JD_HOUR);
-			else stcore->getNavigation()->setJDay(get_julian_from_sys());
+			else stcore->getNavigation()->setJDay(StelUtils::getJDFromSystem());
 
 		} else status=0;
 	  
@@ -388,21 +395,23 @@ int StelCommandInterface::execute_command(string commandline, unsigned long int
 			double lat = observatory->get_latitude();
 			double lon = observatory->get_longitude();
 			double alt = observatory->get_altitude();
+			
 			string name;
-			int delay;
+			int delay = 0;
 		  
 			if(args["name"]!="") name = args["name"];
 			if(args["lat"]!="") lat = StelUtils::stringToDouble(args["lat"]);
 			if(args["lon"]!="") lon = StelUtils::stringToDouble(args["lon"]);
 			if(args["alt"]!="") alt = StelUtils::stringToDouble(args["alt"]);
-			delay = (int)(1000.*StelUtils::stringToDouble(args["duration"]));
+			
+			if (args["delay"]!="") delay = (int)(1000.*StelUtils::stringToDouble(args["duration"]));
 		  
 			stcore->getObservatory()->moveTo(lat,lon,alt,delay,StelUtils::stringToWstring(name));
 		} else status = 0;
 
 	} else if(command=="image") {
 
-		ImageMgr* script_images = (ImageMgr*)StelApp::getInstance().getModuleMgr().getModule("image_mgr");
+		ImageMgr* script_images = (ImageMgr*)StelApp::getInstance().getModuleMgr().getModule("ImageMgr");
 
 		if(args["name"]=="") {
 			debug_message = _("Image name required.");
@@ -416,21 +425,21 @@ int StelCommandInterface::execute_command(string commandline, unsigned long int
 				else if(args["coordinate_system"] == "equatorial") img_pos = Image::POS_EQUATORIAL;
 				else if(args["coordinate_system"] == "j2000") img_pos = Image::POS_J2000;
 
-				string image_filename;
-				if(stapp->scripts->is_playing())
-					image_filename = stapp->scripts->get_script_path() + args["filename"];
+				QString image_filename;
+				if(scripts->is_playing())
+					image_filename = scripts->get_script_path() + args["filename"].c_str();
 				else
-					image_filename = "data/" + args["filename"];
+					image_filename = QString("data/") + args["filename"].c_str();
 					
 				try
 				{
 					image_filename = stapp->getFileMgr().findFile(image_filename);
-					script_images->load_image(image_filename, args["name"], img_pos);
+					script_images->load_image(image_filename, args["name"].c_str(), img_pos);
 				}
 				catch(exception& e)
 				{
 					cerr << "ERROR finding script: " << e.what() << endl;
-					debug_message = _("Unable to open file: ") + StelUtils::stringToWstring(image_filename);
+					debug_message = _("Unable to open file: ") + image_filename.toStdWString();
 				}				  
 			}
 
@@ -438,21 +447,19 @@ int StelCommandInterface::execute_command(string commandline, unsigned long int
 				Image * img = script_images->get_image(args["name"]);
 			  
 				if(img != NULL) {
-					if(args["alpha"]!="") img->set_alpha(StelUtils::stringToDouble(args["alpha"]), 
-														 StelUtils::stringToDouble(args["duration"]));
-					if(args["scale"]!="") img->set_scale(StelUtils::stringToDouble(args["scale"]), 
-														 StelUtils::stringToDouble(args["duration"]));
-					if(args["rotation"]!="") img->set_rotation(StelUtils::stringToDouble(args["rotation"]), 
-															   StelUtils::stringToDouble(args["duration"]));
-					if(args["xpos"]!="" || args["ypos"]!="") 
+					double duration=0.0;
+					if (args["duration"]!="") duration = StelUtils::stringToDouble(args["duration"]);
+					if(args["alpha"]!="") img->set_alpha(StelUtils::stringToDouble(args["alpha"]), duration);
+					if(args["scale"]!="") img->set_scale(StelUtils::stringToDouble(args["scale"]), duration);
+					if(args["rotation"]!="") img->set_rotation(StelUtils::stringToDouble(args["rotation"]), duration);
+					if(args["xpos"]!="" || args["ypos"]!="")
 						img->set_location(StelUtils::stringToDouble(args["xpos"]), args["xpos"]!="",
-										  StelUtils::stringToDouble(args["ypos"]), args["ypos"]!="",
-										  StelUtils::stringToDouble(args["duration"]));
+							StelUtils::stringToDouble(args["ypos"]), args["ypos"]!="",
+							duration);
 					// for more human readable scripts, as long as someone doesn't do both...
 					if(args["altitude"]!="" || args["azimuth"]!="") 
 						img->set_location(StelUtils::stringToDouble(args["altitude"]), args["altitude"]!="",
-										  StelUtils::stringToDouble(args["azimuth"]), args["azimuth"]!="",
-										  StelUtils::stringToDouble(args["duration"]));
+										  StelUtils::stringToDouble(args["azimuth"]), args["azimuth"]!="", duration);
 				} else {
 					debug_message = _("Unable to find image: ") + StelUtils::stringToWstring(args["name"]);
 					status=0;
@@ -477,15 +484,18 @@ int StelCommandInterface::execute_command(string commandline, unsigned long int
 		} else if(args["action"]=="pause") {
 			if(audio) audio->pause();
 
+		} else if(args["action"]=="resume") {
+			if(audio) audio->resume();
+
 		} else if( args["action"]=="play" && args["filename"]!="") {
 			// only one track at a time allowed
 			if(audio) delete audio;
 		  
-			if(stapp->scripts->is_playing())
+			if(scripts->is_playing())
 			{
 				// If we're playing the audio file from a script, search for the audio file
 				// in the script directory where the script file exists.
-				audio = new Audio(stapp->scripts->get_script_path() + args["filename"],
+				audio = new Audio(scripts->get_script_path().toStdString() + args["filename"],
 						"default track",
       						StelUtils::stringToLong(args["output_rate"]));
 				audio->play(args["loop"]=="on");
@@ -497,8 +507,8 @@ int StelCommandInterface::execute_command(string commandline, unsigned long int
 				// from the pwd and so on.
 				try
 				{
-					string audioFilePath = StelApp::getInstance().getFileMgr().findFile(args["filename"], StelFileMgr::FILE);
-					audio = new Audio(audioFilePath, "default track", StelUtils::stringToLong(args["output_rate"]));
+					QString audioFilePath = StelApp::getInstance().getFileMgr().findFile(args["filename"].c_str(), StelFileMgr::FILE);
+					audio = new Audio(QFile::encodeName(audioFilePath).constData(), "default track", StelUtils::stringToLong(args["output_rate"]));
 					audio->play(args["loop"]=="on");
 				}
 				catch(exception& e)
@@ -525,7 +535,7 @@ int StelCommandInterface::execute_command(string commandline, unsigned long int
 	}
 	else if(command=="script") {
 
-		ImageMgr* script_images = (ImageMgr*)StelApp::getInstance().getModuleMgr().getModule("image_mgr");
+		ImageMgr* script_images = (ImageMgr*)StelApp::getInstance().getModuleMgr().getModule("ImageMgr");
 
 		if(args["action"]=="end") {
 			// stop script, audio, and unload any loaded images
@@ -533,40 +543,40 @@ int StelCommandInterface::execute_command(string commandline, unsigned long int
 				delete audio;
 				audio = NULL;
 			}
-			stapp->scripts->cancel_script();
+			scripts->cancel_script();
 			script_images->drop_all_images();
 
 		} else if(args["action"]=="play" && args["filename"]!="") {
-			if(stapp->scripts->is_playing()) {
+			if(scripts->is_playing()) {
 
-				string script_path = stapp->scripts->get_script_path();
+				QString script_path = scripts->get_script_path();
 
 				// stop script, audio, and unload any loaded images
 				if(audio) {
 					delete audio;
 					audio = NULL;
 				}
-				stapp->scripts->cancel_script();
+				scripts->cancel_script();
 				script_images->drop_all_images();
 
 				// keep same script path 
-				stapp->scripts->play_script(script_path + args["filename"], script_path);
+				scripts->play_script(script_path + args["filename"].c_str(), script_path);
 			} else {
-				stapp->scripts->play_script(args["path"] + args["filename"], args["path"]);
+				scripts->play_script(QString(args["path"].c_str()) + args["filename"].c_str(), args["path"].c_str());
 			}
 
 		} else if(args["action"]=="record") {
-			stapp->scripts->record_script(args["filename"]);
+			scripts->record_script(args["filename"]);
 			recordable = 0;  // don't record this command!
 		} else if(args["action"]=="cancelrecord") {
-			stapp->scripts->cancel_record_script();
+			scripts->cancel_record_script();
 			recordable = 0;  // don't record this command!
-		} else if(args["action"]=="pause" && !stapp->scripts->is_paused()) {
+		} else if(args["action"]=="pause" && !scripts->is_paused()) {
 			// n.b. action=pause TOGGLES pause
 			if(audio) audio->pause();
-			stapp->scripts->pause_script();
+			scripts->pause_script();
 		} else if (args["action"]=="pause" || args["action"]=="resume") {
-			stapp->scripts->resume_script();
+			scripts->resume_script();
 			if(audio) audio->sync();
 		} else status =0;
 
@@ -619,8 +629,11 @@ int StelCommandInterface::execute_command(string commandline, unsigned long int
 	} else if(command=="landscape" && args["action"] == "load") {
 
 		// textures are relative to script
-		args["path"] = stapp->scripts->get_script_path();
-		lmgr->loadLandscape(args);
+		args["path"] = QFile::encodeName(scripts->get_script_path()).constData();
+		QMap<QString, QString> tmpArgs;
+		for (std::map<string, string>::const_iterator iter=args.begin();iter!=args.end();++iter)
+			tmpArgs.insert(iter->first.c_str(), iter->second.c_str());
+		lmgr->loadLandscape(tmpArgs);
 	  
 	} else if(command=="meteors") {
 		if(args["zhr"]!="") {
@@ -662,7 +675,7 @@ int StelCommandInterface::execute_command(string commandline, unsigned long int
 		// 			  }
 		// 		  else
 		// 			  {
-		// 				  stcore->navigation->set_JDay(get_julian_from_sys());
+		// 				  stcore->navigation->set_JDay(getJDFromSystem());
 		// 			  }
 		// 		  if(stcore->getFlagPlanetsTrails() && stcore->ssystem) stcore->startPlanetsTrails(true);
 		// 		  else stcore->startPlanetsTrails(false);
@@ -674,7 +687,26 @@ int StelCommandInterface::execute_command(string commandline, unsigned long int
 		// 		  system( ( stcore->getDataDir() + "script_loadConfig " ).c_str() );
 		// 
 		// 	  } else status = 0;
+	} else if(command=="screenshot") {
+		if (!scripts->can_write_files())
+		{
+			debug_message = _("Scripting cannot write files (check setting files:scripts_can_write_files)");
+			status = 0;	
+		}
+		else
+		{
+			if(args["prefix"]=="")
+			{
+				debug_message = _("mandatory argument \"prefix\" not specified");
+				status = 0;
+			}
+			else
+				{
+					StelApp::getInstance().saveScreenShot(args["prefix"].c_str(), args["dir"].c_str());
+				status = 1;
 
+			}
+		}
 	} else {
 		debug_message = _("Unrecognized or malformed command name.");
 		status = 0;
@@ -683,17 +715,19 @@ int StelCommandInterface::execute_command(string commandline, unsigned long int
 	if(status ) {
 
 		// if recording commands, do that now
-		if(recordable) stapp->scripts->record_command(commandline);
+		if(recordable) scripts->record_command(commandline);
 
 		//    cout << commandline << endl;
 
 	} else {
 
 		// Show gui error window only if script asked for gui debugging
-		if(stapp->scripts->is_playing() && stapp->scripts->get_gui_debug()) 
-			stapp->ui->show_message(_("Could not execute command:") + wstring(L"\n\"") + 
+		if(scripts->is_playing() && scripts->get_gui_debug())
+		{
+			StelUI* ui = (StelUI*)StelApp::getInstance().getModuleMgr().getModule("StelUI");
+			ui->show_message(_("Could not execute command:") + wstring(L"\n\"") + 
 									StelUtils::stringToWstring(commandline) + wstring(L"\"\n\n") + debug_message, 7000);
-			
+		}	
 		cerr << "Could not execute: " << commandline << endl << StelUtils::wstringToString(debug_message) << endl;
 	}
 
@@ -725,17 +759,17 @@ int StelCommandInterface::set_flag(string name, string value, bool &newval, bool
 				newval = !stcore->getFlagEnableMoveKeys();
 				stcore->setFlagEnableMoveKeys(newval); }
 			else if(name=="enable_move_mouse") newval = (stapp->FlagEnableMoveMouse = !stapp->FlagEnableMoveMouse);
-			else if(name=="menu") newval = (stapp->ui->FlagMenu = !stapp->ui->FlagMenu);
-			else if(name=="help") newval = (stapp->ui->FlagHelp = !stapp->ui->FlagHelp);
-			else if(name=="infos") newval = (stapp->ui->FlagInfos = !stapp->ui->FlagInfos);
-			else if(name=="show_topbar") newval = (stapp->ui->FlagShowTopBar = !stapp->ui->FlagShowTopBar);
-			else if(name=="show_time") newval = (stapp->ui->FlagShowTime = !stapp->ui->FlagShowTime);
-			else if(name=="show_date") newval = (stapp->ui->FlagShowDate = !stapp->ui->FlagShowDate);
-			else if(name=="show_appname") newval = (stapp->ui->FlagShowAppName = !stapp->ui->FlagShowAppName);
-			else if(name=="show_fps") newval = (stapp->ui->FlagShowFps = !stapp->ui->FlagShowFps);
-			else if(name=="show_fov") newval = (stapp->ui->FlagShowFov = !stapp->ui->FlagShowFov);
-			else if(name=="enable_tui_menu") newval = (stapp->ui->FlagEnableTuiMenu = !stapp->ui->FlagEnableTuiMenu);
-			else if(name=="show_gravity_ui") newval = (stapp->ui->FlagShowGravityUi = !stapp->ui->FlagShowGravityUi);
+			else if(name=="menu") newval = (ui->FlagMenu = !ui->FlagMenu);
+			else if(name=="help") newval = (ui->FlagHelp = !ui->FlagHelp);
+			else if(name=="infos") newval = (ui->FlagInfos = !ui->FlagInfos);
+			else if(name=="show_topbar") newval = (ui->FlagShowTopBar = !ui->FlagShowTopBar);
+			else if(name=="show_time") newval = (ui->FlagShowTime = !ui->FlagShowTime);
+			else if(name=="show_date") newval = (ui->FlagShowDate = !ui->FlagShowDate);
+			else if(name=="show_appname") newval = (ui->FlagShowAppName = !ui->FlagShowAppName);
+			else if(name=="show_fps") newval = (ui->FlagShowFps = !ui->FlagShowFps);
+			else if(name=="show_fov") newval = (ui->FlagShowFov = !ui->FlagShowFov);
+			else if(name=="enable_tui_menu") newval = (ui->FlagEnableTuiMenu = !ui->FlagEnableTuiMenu);
+			else if(name=="show_gravity_ui") newval = (ui->FlagShowGravityUi = !ui->FlagShowGravityUi);
 			else if(name=="gravity_labels") {
 				newval = !stcore->getFlagGravityLabels();
 				stcore->setFlagGravityLabels(newval);
@@ -746,13 +780,15 @@ int StelCommandInterface::set_flag(string name, string value, bool &newval, bool
 
 		} else status = 0;
 
-		ConstellationMgr* cmgr = (ConstellationMgr*)StelApp::getInstance().getModuleMgr().getModule("constellations");
-		StarMgr* smgr = (StarMgr*)StelApp::getInstance().getModuleMgr().getModule("stars");
-		NebulaMgr* nmgr = (NebulaMgr*)StelApp::getInstance().getModuleMgr().getModule("nebulas");
-		SolarSystem* ssmgr = (SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("ssystem");
-		LandscapeMgr* lmgr = (LandscapeMgr*)StelApp::getInstance().getModuleMgr().getModule("landscape");
-		GridLinesMgr* grlmgr = (GridLinesMgr*)StelApp::getInstance().getModuleMgr().getModule("gridlines");
-		MovementMgr* mvmgr = (MovementMgr*)StelApp::getInstance().getModuleMgr().getModule("movements");
+		ConstellationMgr* cmgr = (ConstellationMgr*)StelApp::getInstance().getModuleMgr().getModule("ConstellationMgr");
+		StarMgr* smgr = (StarMgr*)StelApp::getInstance().getModuleMgr().getModule("StarMgr");
+		NebulaMgr* nmgr = (NebulaMgr*)StelApp::getInstance().getModuleMgr().getModule("NebulaMgr");
+		SolarSystem* ssmgr = (SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("SolarSystem");
+		LandscapeMgr* lmgr = (LandscapeMgr*)StelApp::getInstance().getModuleMgr().getModule("LandscapeMgr");
+		GridLinesMgr* grlmgr = (GridLinesMgr*)StelApp::getInstance().getModuleMgr().getModule("GridLinesMgr");
+		MovementMgr* mvmgr = (MovementMgr*)StelApp::getInstance().getModuleMgr().getModule("MovementMgr");
+		StelUI* ui = (StelUI*)StelApp::getInstance().getModuleMgr().getModule("StelUI");
+		ScriptMgr* scripts = (ScriptMgr*)StelApp::getInstance().getModuleMgr().getModule("ScriptMgr");
 		
 		if(name=="constellation_drawing") {
 			newval = !cmgr->getFlagLines();
@@ -782,13 +818,13 @@ int StelCommandInterface::set_flag(string name, string value, bool &newval, bool
 			newval = !smgr->getFlagPointStar();
 			smgr->setFlagPointStar(newval);
 		}
-		else if(name=="show_selected_object_info") newval = (stapp->ui->FlagShowSelectedObjectInfo = !stapp->ui->FlagShowSelectedObjectInfo);
-		else if(name=="show_tui_datetime") newval = (stapp->ui->FlagShowTuiDateTime = !stapp->ui->FlagShowTuiDateTime);
-		else if(name=="show_tui_short_obj_info") newval = (stapp->ui->FlagShowTuiShortObjInfo = !stapp->ui->FlagShowTuiShortObjInfo);
+		else if(name=="show_selected_object_info") newval = (ui->FlagShowSelectedObjectInfo = !ui->FlagShowSelectedObjectInfo);
+		else if(name=="show_tui_datetime") newval = (ui->FlagShowTuiDateTime = !ui->FlagShowTuiDateTime);
+		else if(name=="show_tui_short_obj_info") newval = (ui->FlagShowTuiShortObjInfo = !ui->FlagShowTuiShortObjInfo);
 		else if(name=="manual_zoom") {
 			newval = !mvmgr->getFlagManualAutoZoom();  
 			mvmgr->setFlagManualAutoZoom(newval); }
-		else if(name=="show_script_bar") newval = (stapp->ui->FlagShowScriptBar = !stapp->ui->FlagShowScriptBar);
+		else if(name=="show_script_bar") newval = (ui->FlagShowScriptBar = !ui->FlagShowScriptBar);
 		else if(name=="fog") {
 			newval = !lmgr->getFlagFog();
 			lmgr->setFlagFog(newval); 
@@ -796,7 +832,7 @@ int StelCommandInterface::set_flag(string name, string value, bool &newval, bool
 		else if(name=="atmosphere") {
 			newval = !lmgr->getFlagAtmosphere();
 			lmgr->setFlagAtmosphere(newval);
-			if(!newval) lmgr->setFlagFog(false);  // turn off fog with atmosphere
+			lmgr->setFlagFog(newval);
 		}
 		/*		else if(name=="chart") {
 			newval = !stapp->getVisionModeChart();
@@ -872,7 +908,7 @@ int StelCommandInterface::set_flag(string name, string value, bool &newval, bool
 			nmgr->setFlagHints(newval);
 		}
 		else if(name=="milky_way") {
-			MilkyWay* mw = (MilkyWay*)stapp->moduleMgr->getModule("milkyway");
+			MilkyWay* mw = (MilkyWay*)stapp->getModuleMgr().getModule("MilkyWay");
 			newval = !mw->getFlagShow();
 			mw->setFlagShow(newval);
 		}
@@ -890,8 +926,8 @@ int StelCommandInterface::set_flag(string name, string value, bool &newval, bool
 			mvmgr->setFlagTracking(newval);
 		}
 		else if(name=="script_gui_debug") {  // Not written to config - script specific
-			newval = !stapp->scripts->get_gui_debug();
-			stapp->scripts->set_gui_debug(newval);
+			newval = !scripts->get_gui_debug();
+			scripts->set_gui_debug(newval);
 		}
 		else if(name=="landscape_sets_location")
 		{
@@ -911,17 +947,17 @@ int StelCommandInterface::set_flag(string name, string value, bool &newval, bool
 			if(name=="enable_zoom_keys") stcore->setFlagEnableZoomKeys(newval);
 			else if(name=="enable_move_keys") stcore->setFlagEnableMoveKeys(newval);
 			else if(name=="enable_move_mouse") stapp->FlagEnableMoveMouse = newval;
-			else if(name=="menu") stapp->ui->FlagMenu = newval;
-			else if(name=="help") stapp->ui->FlagHelp = newval;
-			else if(name=="infos") stapp->ui->FlagInfos = newval;
-			else if(name=="show_topbar") stapp->ui->FlagShowTopBar = newval;
-			else if(name=="show_time") stapp->ui->FlagShowTime = newval;
-			else if(name=="show_date") stapp->ui->FlagShowDate = newval;
-			else if(name=="show_appname") stapp->ui->FlagShowAppName = newval;
-			else if(name=="show_fps") stapp->ui->FlagShowFps = newval;
-			else if(name=="show_fov") stapp->ui->FlagShowFov = newval;
-			else if(name=="enable_tui_menu") stapp->ui->FlagEnableTuiMenu = newval;
-			else if(name=="show_gravity_ui") stapp->ui->FlagShowGravityUi = newval;
+			else if(name=="menu") ui->FlagMenu = newval;
+			else if(name=="help") ui->FlagHelp = newval;
+			else if(name=="infos") ui->FlagInfos = newval;
+			else if(name=="show_topbar") ui->FlagShowTopBar = newval;
+			else if(name=="show_time") ui->FlagShowTime = newval;
+			else if(name=="show_date") ui->FlagShowDate = newval;
+			else if(name=="show_appname") ui->FlagShowAppName = newval;
+			else if(name=="show_fps") ui->FlagShowFps = newval;
+			else if(name=="show_fov") ui->FlagShowFov = newval;
+			else if(name=="enable_tui_menu") ui->FlagEnableTuiMenu = newval;
+			else if(name=="show_gravity_ui") ui->FlagShowGravityUi = newval;
 			else if(name=="gravity_labels") stcore->setFlagGravityLabels(newval);
 			else status = 0;
 
@@ -930,13 +966,15 @@ int StelCommandInterface::set_flag(string name, string value, bool &newval, bool
 		
 		} else status = 0;
 
-		ConstellationMgr* cmgr = (ConstellationMgr*)StelApp::getInstance().getModuleMgr().getModule("constellations");
-		StarMgr* smgr = (StarMgr*)StelApp::getInstance().getModuleMgr().getModule("stars");
-		NebulaMgr* nmgr = (NebulaMgr*)StelApp::getInstance().getModuleMgr().getModule("nebulas");
-		SolarSystem* ssmgr = (SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("ssystem");
-		LandscapeMgr* lmgr = (LandscapeMgr*)StelApp::getInstance().getModuleMgr().getModule("landscape");
-		GridLinesMgr* grlmgr = (GridLinesMgr*)StelApp::getInstance().getModuleMgr().getModule("gridlines");
-		MovementMgr* mvmgr = (MovementMgr*)StelApp::getInstance().getModuleMgr().getModule("movements");
+		ConstellationMgr* cmgr = (ConstellationMgr*)StelApp::getInstance().getModuleMgr().getModule("ConstellationMgr");
+		StarMgr* smgr = (StarMgr*)StelApp::getInstance().getModuleMgr().getModule("StarMgr");
+		NebulaMgr* nmgr = (NebulaMgr*)StelApp::getInstance().getModuleMgr().getModule("NebulaMgr");
+		SolarSystem* ssmgr = (SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("SolarSystem");
+		LandscapeMgr* lmgr = (LandscapeMgr*)StelApp::getInstance().getModuleMgr().getModule("LandscapeMgr");
+		GridLinesMgr* grlmgr = (GridLinesMgr*)StelApp::getInstance().getModuleMgr().getModule("GridLinesMgr");
+		MovementMgr* mvmgr = (MovementMgr*)StelApp::getInstance().getModuleMgr().getModule("MovementMgr");
+		StelUI* ui = (StelUI*)StelApp::getInstance().getModuleMgr().getModule("StelUI");
+		ScriptMgr* scripts = (ScriptMgr*)StelApp::getInstance().getModuleMgr().getModule("ScriptMgr");
 		
 		if(name=="constellation_drawing") cmgr->setFlagLines(newval);
 		else if(name=="constellation_names") cmgr->setFlagNames(newval);
@@ -945,11 +983,11 @@ int StelCommandInterface::set_flag(string name, string value, bool &newval, bool
      	else if(name=="constellation_pick") cmgr->setFlagIsolateSelected(newval);
 		else if(name=="star_twinkle") smgr->setFlagTwinkle(newval);
 		else if(name=="point_star") smgr->setFlagPointStar(newval);
-		else if(name=="show_selected_object_info") stapp->ui->FlagShowSelectedObjectInfo = newval;
-		else if(name=="show_tui_datetime") stapp->ui->FlagShowTuiDateTime = newval;
-		else if(name=="show_tui_short_obj_info") stapp->ui->FlagShowTuiShortObjInfo = newval;
+		else if(name=="show_selected_object_info") ui->FlagShowSelectedObjectInfo = newval;
+		else if(name=="show_tui_datetime") ui->FlagShowTuiDateTime = newval;
+		else if(name=="show_tui_short_obj_info") ui->FlagShowTuiShortObjInfo = newval;
 		else if(name=="manual_zoom") mvmgr->setFlagManualAutoZoom(newval);
-		else if(name=="show_script_bar") stapp->ui->FlagShowScriptBar = newval;
+		else if(name=="show_script_bar") ui->FlagShowScriptBar = newval;
 		else if(name=="fog") lmgr->setFlagFog(newval);
 		else if(name=="atmosphere") { 
 			lmgr->setFlagAtmosphere ( newval);
@@ -981,13 +1019,13 @@ int StelCommandInterface::set_flag(string name, string value, bool &newval, bool
 		}
 		else if(name=="milky_way")
 		{
-			MilkyWay* mw = (MilkyWay*)stapp->moduleMgr->getModule("milkyway");
+			MilkyWay* mw = (MilkyWay*)stapp->getModuleMgr().getModule("MilkyWay");
 			mw->setFlagShow(newval);
 		}
 		else if(name=="bright_nebulae") nmgr->setFlagBright(newval);
 		else if(name=="object_trails") ssmgr->setFlagTrails(newval);
 		else if(name=="track_object") mvmgr->setFlagTracking(newval);
-		else if(name=="script_gui_debug") stapp->scripts->set_gui_debug(newval); // Not written to config - script specific
+		else if(name=="script_gui_debug") scripts->set_gui_debug(newval); // Not written to config - script specific
 		else if(name=="landscape_sets_location") lmgr->setFlagLandscapeSetsLocation(newval);
 		else return(status);
 
@@ -999,6 +1037,12 @@ int StelCommandInterface::set_flag(string name, string value, bool &newval, bool
 }
 
 
-void StelCommandInterface::update(double delta_time) {
-	if(audio) audio->update(delta_time);
+void StelCommandInterface::update(double delta_time)
+{
+	ScriptMgr* scripts = (ScriptMgr*)StelApp::getInstance().getModuleMgr().getModule("ScriptMgr");
+	// keep audio position updated if changing time multiplier
+	if (scripts->is_paused())
+		return;
+	if (audio)
+		audio->update(delta_time);
 }
