@@ -44,6 +44,7 @@
 #include "Navigator.hpp"
 #include "Observer.hpp"
 #include "Planet.hpp"
+#include "script_mgr.h"
 
 ////////////////////////////////////////////////////////////////////////////////
 //								CLASS FUNCTIONS
@@ -95,6 +96,7 @@ StelUI::StelUI(StelCore * _core, StelApp * _app) :
 	mapLastPlanet(NULL),
 	tui_root(NULL)
 {
+	setObjectName("StelUI");
 	if (!_core)
 	{
 		printf("ERROR : In stel_ui constructor, unvalid core.");
@@ -113,6 +115,17 @@ StelUI::~StelUI()
 	delete desktop; 	desktop = NULL;
 	if (tui_root) delete tui_root; tui_root=NULL;
 	Component::deleteScissor();
+	Component::setDefaultPainter(Painter());
+}
+
+/*************************************************************************
+ Reimplementation of the getCallOrder method
+*************************************************************************/
+double StelUI::getCallOrder(StelModuleActionName actionName) const
+{
+	if (actionName==StelModule::ACTION_DRAW)
+		return StelApp::getInstance().getModuleMgr().getModule("SolarSystem")->getCallOrder(actionName)+1000;
+	return 0;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -221,10 +234,11 @@ void StelUI::init(const InitParser& conf)
 	desktop->addComponent(createSearchWindow());
 	setTitleObservatoryName(getTitleWithAltitude());
 	
- initialised = true;
+	init_tui();
+ 	initialised = true;
 }
 
-double StelUI::draw(Projector *prj, const Navigator *nav, ToneReproducer *eye)
+double StelUI::draw(StelCore* core)
 {
 	if (initialised)
 		drawTui();
@@ -277,7 +291,7 @@ Component* StelUI::createTopBar(SFont& baseFont)
 	top_bar_hour_lbl = new Label(L"-", &baseFont);	top_bar_hour_lbl->setPos(110,1);
 	top_bar_fps_lbl = new Label(L"-", &baseFont);	top_bar_fps_lbl->setPos(StelApp::getInstance().getScreenW()-100,1);
 	top_bar_fov_lbl = new Label(L"-", &baseFont);	top_bar_fov_lbl->setPos(StelApp::getInstance().getScreenW()-220,1);
-	top_bar_appName_lbl = new Label(StelUtils::stringToWstring(StelApp::getApplicationName()), &baseFont);
+	top_bar_appName_lbl = new Label(StelApp::getApplicationName().toStdWString(), &baseFont);
 	top_bar_appName_lbl->setPos(StelApp::getInstance().getScreenW()/2-top_bar_appName_lbl->getSizex()/2,1);
 	top_bar_ctr = new FilledContainer();
 	top_bar_ctr->reshape(0,0,StelApp::getInstance().getScreenW(),(int)(baseFont.getLineHeight()+0.5)+5);
@@ -317,18 +331,20 @@ void StelUI::updateTopBar(void)
 
 	if (FlagShowFov)
 	{
-		wstringstream wos;
-		wos << L"FOV=" << setprecision(3) << core->getProjection()->getFov() << L"\u00B0";
-		top_bar_fov_lbl->setLabel(wos.str());
+		QString str;
+    	QTextStream wos(&str);
+		wos << "FOV=" << qSetRealNumberPrecision(3) << core->getProjection()->getFov() << QString::fromWCharArray(L"\u00B0");
+		top_bar_fov_lbl->setLabel(str.toStdWString());
 		top_bar_fov_lbl->adjustSize();
 	}
 	top_bar_fov_lbl->setVisible(FlagShowFov);
 
 	if (FlagShowFps)
 	{
-		wstringstream wos;
-		wos << L"FPS=" << setprecision(4) << app->fps;
-		top_bar_fps_lbl->setLabel(wos.str());
+		QString str;
+    	QTextStream wos(&str);
+		wos << "FPS=" << qSetRealNumberPrecision(4) << app->getFps();
+		top_bar_fps_lbl->setLabel(str.toStdWString());
 		top_bar_fps_lbl->adjustSize();
 	}
 	top_bar_fps_lbl->setVisible(FlagShowFps);
@@ -531,7 +547,7 @@ void StelUI::bt_real_time_speed_cb(void)
 
 void StelUI::bt_time_now_cb(void)
 {
-	core->getNavigation()->setJDay(get_julian_from_sys());
+	core->getNavigation()->setJDay(StelUtils::getJDFromSystem());
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -566,19 +582,20 @@ void StelUI::cbEditScriptExecute(void)
 
 	bt_script->clearText();
 	bt_script->setEditing(false);
-
-	if (!app->commander->execute_command(command_string))
+	
+	StelCommandInterface* commander = (StelCommandInterface*)StelApp::getInstance().getModuleMgr().getModule("StelCommandInterface");
+	if (!commander->execute_command(command_string))
 		bt_flag_help_lbl->setLabel(_("Invalid Script command"));
 }
 
 ////////////////////////////////////////////////////////////////////////////////
 void StelUI::cb(void)
 {
-	ConstellationMgr* cmgr = (ConstellationMgr*)StelApp::getInstance().getModuleMgr().getModule("constellations");
-	NebulaMgr* nmgr = (NebulaMgr*)StelApp::getInstance().getModuleMgr().getModule("nebulas");
-	LandscapeMgr* lmgr = (LandscapeMgr*)StelApp::getInstance().getModuleMgr().getModule("landscape");
-	GridLinesMgr* grlmgr = (GridLinesMgr*)StelApp::getInstance().getModuleMgr().getModule("gridlines");
-	MovementMgr* mvmgr = (MovementMgr*)StelApp::getInstance().getModuleMgr().getModule("movements");
+	ConstellationMgr* cmgr = (ConstellationMgr*)StelApp::getInstance().getModuleMgr().getModule("ConstellationMgr");
+	NebulaMgr* nmgr = (NebulaMgr*)StelApp::getInstance().getModuleMgr().getModule("NebulaMgr");
+	LandscapeMgr* lmgr = (LandscapeMgr*)StelApp::getInstance().getModuleMgr().getModule("LandscapeMgr");
+	GridLinesMgr* grlmgr = (GridLinesMgr*)StelApp::getInstance().getModuleMgr().getModule("GridLinesMgr");
+	MovementMgr* mvmgr = (MovementMgr*)StelApp::getInstance().getModuleMgr().getModule("MovementMgr");
 	
 	cmgr->setFlagLines(bt_flag_constellation_draw->getState());
 	cmgr->setFlagNames(bt_flag_constellation_name->getState());
@@ -588,6 +605,7 @@ void StelUI::cb(void)
 	lmgr->setFlagLandscape(bt_flag_ground->getState());
 	lmgr->setFlagCardinalsPoints(bt_flag_cardinals->getState());
 	lmgr->setFlagAtmosphere(bt_flag_atmosphere->getState());
+	lmgr->setFlagFog(bt_flag_atmosphere->getState());
 	
 	nmgr->setFlagHints( bt_flag_nebula_name->getState() );
 	if (bt_flip_horz) core->getProjection()->setFlipHorz( bt_flip_horz->getState() );
@@ -669,7 +687,7 @@ void StelUI::cbr(void)
 	if (bt_flag_equatorial_mode->getIsMouseOver())
 		bt_flag_help_lbl->setLabel(_("Equatorial/Altazimuthal Mount [ENTER]"));
 	if (bt_flag_config->getIsMouseOver())
-		bt_flag_help_lbl->setLabel(_("Configuration window"));
+		bt_flag_help_lbl->setLabel(_("Configuration window [1]"));
 
 	if (bt_flag_night->getIsMouseOver())
 		bt_flag_help_lbl->setLabel(_("Night (red) mode"));
@@ -680,15 +698,15 @@ void StelUI::cbr(void)
 	bt_flag_help_lbl->setLabel(_("Quit [CMD + Q]"));
 #endif
 	if (bt_flag_search->getIsMouseOver())
-		bt_flag_help_lbl->setLabel(_("Search for object"));
+		bt_flag_help_lbl->setLabel(_("Search for object [CTRL + F]"));
 	if (bt_script->getIsMouseOver())
 		bt_flag_help_lbl->setLabel(_("Script commander"));
 	if (bt_flag_goto->getIsMouseOver())
 		bt_flag_help_lbl->setLabel(_("Goto selected object [SPACE]"));
 	if (bt_flip_horz && bt_flip_horz->getIsMouseOver())
-		bt_flag_help_lbl->setLabel(_("Flip horizontally"));
+		bt_flag_help_lbl->setLabel(_("Flip horizontally [CTRL + SHIFT + H]"));
 	if (bt_flip_vert && bt_flip_vert->getIsMouseOver())
-		bt_flag_help_lbl->setLabel(_("Flip vertically"));
+		bt_flag_help_lbl->setLabel(_("Flip vertically [CTRL + SHIFT + V]"));
 }
 
 void StelUI::tcbr(void)
@@ -700,15 +718,15 @@ void StelUI::tcbr(void)
 	if (bt_inc_time_speed->getIsMouseOver())
 		bt_flag_time_control_lbl->setLabel(_("Increase Time Speed [L]"));
 	if (bt_time_now->getIsMouseOver())
-		bt_flag_time_control_lbl->setLabel(_("Return to Current Time"));
+		bt_flag_time_control_lbl->setLabel(_("Return to Current Time [8]"));
 }
 
 // The window containing the info (licence)
 Component* StelUI::createLicenceWindow(void)
 {
 	licence_txtlbl = new TextLabel(
-		wstring(L"                 \u2022   Stellarium  October 2006  \u2022\n\n") +
-		L"\u2022   Copyright (c) 2000-2006 Fabien Chereau et al.\n\n" +
+		wstring(L"                 \u2022   Stellarium  January 2008  \u2022\n\n") +
+		L"\u2022   Copyright (c) 2000-2008 Fabien Chereau et al.\n\n" +
 		L"\u2022" + _("   Please check for newer versions and send bug reports\n\
     and comments to us at: http://www.stellarium.org\n\n") +
 		L"\u2022   This program is free software; you can redistribute it and/or\n\
@@ -777,6 +795,7 @@ CTRL + G : Goto selected solar system object\n\
 K   : Normal time rate          L   : Increase time rate\n\
 - and = :  Back and forward one day (press ALT for sidereal day)\n\
 [ and ] :  Back and forward 7 days (press ALT for sidereal days)\n\
+CTRL + - : Back one hour        CTRL + = : forward one hour\n\
 \n")) + 
 		wstring(_("During Script Playback:\n\
 CTRL + C : End Script\n\
@@ -799,7 +818,7 @@ CTRL + C : End Script\n\
 	help_txtlbl->setPos(10,10);
 	help_win = new StdBtWin(_("Help"));
 	//help_win->setOpaque(opaqueGUI);
-	help_win->reshape(215,45,580,645);
+	help_win->reshape(215,45,580,655);
 	help_win->addComponent(help_txtlbl);
 	help_win->setVisible(FlagHelp);
 	help_win->setOnHideBtCallback(callback<void>(this, &StelUI::help_win_hideBtCallback));
@@ -844,11 +863,12 @@ void StelUI::drawGui(void)
 }
 
 /*******************************************************************************/
-int StelUI::handle_move(int x, int y, StelMod mod)
+int StelUI::handleMouseMoves(int x, int y, StelMod mod)
 {
+	ScriptMgr* scripts = (ScriptMgr*)StelApp::getInstance().getModuleMgr().getModule("ScriptMgr");
 	// Do not allow use of mouse while script is playing
 	// otherwise script can get confused
-	if(app->scripts->is_playing()) return 0;
+	if(scripts->is_playing()) return 0;
 
 	// Show cursor
 	StelApp::getInstance().showCursor(true);
@@ -860,11 +880,12 @@ int StelUI::handle_move(int x, int y, StelMod mod)
 }
 
 /*******************************************************************************/
-int StelUI::handle_clic(Uint16 x, Uint16 y, Uint8 button, Uint8 state, StelMod mod)
+int StelUI::handleClick(Uint16 x, Uint16 y, Uint8 button, Uint8 state, StelMod mod)
 {
+	ScriptMgr* scripts = (ScriptMgr*)StelApp::getInstance().getModuleMgr().getModule("ScriptMgr");
 	// Do not allow use of mouse while script is playing
 	// otherwise script can get confused
-	if(app->scripts->is_playing()) return 0;
+	if(scripts->is_playing()) return 0;
 
 	// Make sure object pointer is turned on (script may have turned off)
 	StelApp::getInstance().getStelObjectMgr().setFlagSelectedObjectPointer(true);
@@ -875,7 +896,7 @@ int StelUI::handle_clic(Uint16 x, Uint16 y, Uint8 button, Uint8 state, StelMod m
 
 	if (desktop->onClic((int)x, (int)y, button, state, mod))
 	{
-		MovementMgr* mvmgr = (MovementMgr*)StelApp::getInstance().getModuleMgr().getModule("movements");
+		MovementMgr* mvmgr = (MovementMgr*)StelApp::getInstance().getModuleMgr().getModule("MovementMgr");
 		mvmgr->stopDragging();
 		return 1;
 	}
@@ -891,6 +912,9 @@ int StelUI::handle_keysGUI(StelKey key, StelMod mod, Uint16 unicode, Uint8 state
 int StelUI::handle_keys(StelKey key, StelMod mod, Uint16 unicode, Uint8 state)
 {
 	const StelObjectMgr& objmgr = StelApp::getInstance().getStelObjectMgr();
+	StelCommandInterface* commander = (StelCommandInterface*)StelApp::getInstance().getModuleMgr().getModule("StelCommandInterface");
+	ScriptMgr* scripts = (ScriptMgr*)StelApp::getInstance().getModuleMgr().getModule("ScriptMgr");
+	
 	if (state==Stel_KEYDOWN)
 	{
 //printf("handle_keys: '%c'(%d), %d, 0x%04x\n",key,(int)key,unicode,mod);
@@ -925,36 +949,36 @@ int StelUI::handle_keys(StelKey key, StelMod mod, Uint16 unicode, Uint8 state)
 		// if script is running, only script control keys are accessible
 		// to pause/resume/cancel the script
 		// (otherwise script could get very confused by user interaction)
-		if(app->scripts->is_playing())
+		if(scripts->is_playing())
 		{
 
 			// here reusing time control keys to control the script playback
 			if(key==StelKey_6)
 			{
 				// pause/unpause script
-				app->commander->execute_command( "script action pause");
+				commander->execute_command( "script action pause");
 				app->setTimeMultiplier(1);   // don't allow resumption of ffwd this way (confusing for audio)
 			}
 			else if(key==StelKey_k)
 			{
-				app->commander->execute_command( "script action resume");
+				commander->execute_command( "script action resume");
 				app->setTimeMultiplier(1);
 			}
 			else if(key==StelKey_7 || unicode==0x0003 || (key==StelKey_m && FlagEnableTuiMenu))
 			{  // ctrl-c
 				// TODO: should double check with user here...
-				app->commander->execute_command( "script action end");
+				commander->execute_command( "script action end");
 				if(key==StelKey_m) setFlagShowTuiMenu(true);
 			}
 			// TODO n is bad key if ui allowed
 			else if(key==StelKey_GREATER || key==StelKey_n)
 			{
-				app->commander->execute_command( "audio volume increment");
+				commander->execute_command( "audio volume increment");
 			}
 			// TODO d is bad key if ui allowed
 			else if(key==StelKey_LESS || key==StelKey_d)
 			{
-				app->commander->execute_command( "audio volume decrement");
+				commander->execute_command( "audio volume decrement");
 
 			}
 			else if(key==StelKey_j)
@@ -964,7 +988,7 @@ int StelUI::handle_keys(StelKey key, StelMod mod, Uint16 unicode, Uint8 state)
 					app->setTimeMultiplier(1);
 
 					// restart audio in correct place
-					app->commander->execute_command( "audio action sync");
+					commander->execute_command( "audio action sync");
 				}
 				else if(app->getTimeMultiplier() > 1 )
 				{
@@ -975,16 +999,16 @@ int StelUI::handle_keys(StelKey key, StelMod mod, Uint16 unicode, Uint8 state)
 			else if(key==StelKey_l)
 			{
 				// stop audio since won't play at higher speeds
-				app->commander->execute_command( "audio action pause");
+				commander->execute_command( "audio action pause");
 				app->setTimeMultiplier( app->getTimeMultiplier()*2 );
 				if(app->getTimeMultiplier()>8) app->setTimeMultiplier(8);
 			}
-			else if(!app->scripts->get_allow_ui())
+			else if(!scripts->get_allow_ui())
 			{
 				cout << "Playing a script.  Press CTRL-C (or 7) to stop." << endl;
 			}
 
-			if(!app->scripts->get_allow_ui()) return 0;  // only limited user interaction allowed with script
+			if(!scripts->get_allow_ui()) return 0;  // only limited user interaction allowed with script
 
 		}
 		else
@@ -992,30 +1016,30 @@ int StelUI::handle_keys(StelKey key, StelMod mod, Uint16 unicode, Uint8 state)
 			app->setTimeMultiplier(1);  // if no script in progress always real time
 
 			// normal time controls here (taken over for script control above if playing a script)
-			if(key==StelKey_k) app->commander->execute_command( "timerate rate 1");
-			if(key==StelKey_l) app->commander->execute_command( "timerate action increment");
-			if(key==StelKey_j) app->commander->execute_command( "timerate action decrement");
-			if(key==StelKey_6) app->commander->execute_command( "timerate action pause");
-			if(key==StelKey_7) app->commander->execute_command( "timerate rate 0");
-			if(key==StelKey_8) app->commander->execute_command( "date load preset");
+			if(key==StelKey_k) commander->execute_command( "timerate rate 1");
+			if(key==StelKey_l) commander->execute_command( "timerate action increment");
+			if(key==StelKey_j) commander->execute_command( "timerate action decrement");
+			if(key==StelKey_6) commander->execute_command( "timerate action pause");
+			if(key==StelKey_7) commander->execute_command( "timerate rate 0");
+			if(key==StelKey_8) commander->execute_command( "date load preset");
 
 		}
 
 		if (key == StelKey_r && (mod & COMPATIBLE_StelMod_CTRL))
 		{
-			if(app->scripts->is_recording())
+			if(scripts->is_recording())
 			{
-				app->commander->execute_command( "script action cancelrecord");
+				commander->execute_command( "script action cancelrecord");
 				show_message(_("Command recording stopped."), 3000);
 			}
 			else
 			{
-				app->commander->execute_command( "script action record");
+				commander->execute_command( "script action record");
 
-				if(app->scripts->is_recording())
+				if(scripts->is_recording())
 				{
 					show_message(wstring( _("Recording commands to script file:\n")
-					                      + StelUtils::stringToWstring(app->scripts->get_record_filename()) + L"\n\n"
+					                      + StelUtils::stringToWstring(scripts->get_record_filename()) + L"\n\n"
 					                      + _("Hit CTRL-R again to stop.\n")), 4000);
 				}
 				else
@@ -1025,7 +1049,7 @@ int StelUI::handle_keys(StelKey key, StelMod mod, Uint16 unicode, Uint8 state)
 			}
             return 0;
 		}
-		TelescopeMgr* telmgr = (TelescopeMgr*)StelApp::getInstance().getModuleMgr().getModule("telescopes");
+		TelescopeMgr* telmgr = (TelescopeMgr*)StelApp::getInstance().getModuleMgr().getModule("TelescopeMgr");
         switch (key) {
 		case StelKey_ESCAPE:
 	        // RFE 1310384, ESC closes dialogs
@@ -1079,20 +1103,20 @@ int StelUI::handle_keys(StelKey key, StelMod mod, Uint16 unicode, Uint8 state)
             } // else fall through
 		case StelKey_COMMA:
 		{
-			SolarSystem* ssmgr = (SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("ssystem");
-			GridLinesMgr* grlmgr = (GridLinesMgr*)StelApp::getInstance().getModuleMgr().getModule("gridlines");
+			SolarSystem* ssmgr = (SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("SolarSystem");
+			GridLinesMgr* grlmgr = (GridLinesMgr*)StelApp::getInstance().getModuleMgr().getModule("GridLinesMgr");
 			if(!grlmgr->getFlagEclipticLine())
 			{
-				app->commander->execute_command( "flag ecliptic_line on");
+				commander->execute_command( "flag ecliptic_line on");
 			}
 			else if( !ssmgr->getFlagTrails())
 			{
-				app->commander->execute_command( "flag object_trails on");
+				commander->execute_command( "flag object_trails on");
 			}
 			else
 			{
-				app->commander->execute_command( "flag object_trails off");
-				app->commander->execute_command( "flag ecliptic_line off");
+				commander->execute_command( "flag object_trails off");
+				commander->execute_command( "flag ecliptic_line off");
 			}
 			break;
 		}
@@ -1102,7 +1126,7 @@ int StelUI::handle_keys(StelKey key, StelMod mod, Uint16 unicode, Uint8 state)
 				break;
             } // else fall through
 		case StelKey_PERIOD:
-            app->commander->execute_command( "flag equator_line toggle");
+            commander->execute_command( "flag equator_line toggle");
             break;
 		case StelKey_6:
             if (mod & COMPATIBLE_StelMod_CTRL && objmgr.getWasSelected())
@@ -1126,16 +1150,16 @@ int StelUI::handle_keys(StelKey key, StelMod mod, Uint16 unicode, Uint8 state)
             if (mod & COMPATIBLE_StelMod_CTRL && objmgr.getWasSelected()) {
             	telmgr->telescopeGoto(9,objmgr.getSelectedObject()[0]->getObsJ2000Pos(core->getNavigation()));
             } else {
-            	MeteorMgr* metmgr = (MeteorMgr*)StelApp::getInstance().getModuleMgr().getModule("meteors");
+            	MeteorMgr* metmgr = (MeteorMgr*)StelApp::getInstance().getModuleMgr().getModule("MeteorMgr");
 				const int zhr = metmgr->getZHR();
 				if (zhr <= 10 ) {
-					app->commander->execute_command("meteors zhr 80");  // standard Perseids rate
+					commander->execute_command("meteors zhr 80");  // standard Perseids rate
 				} else if( zhr <= 80 ) {
-					app->commander->execute_command("meteors zhr 10000"); // exceptional Leonid rate
+					commander->execute_command("meteors zhr 10000"); // exceptional Leonid rate
 				} else if( zhr <= 10000 ) {
-					app->commander->execute_command("meteors zhr 144000");  // highest ever recorded ZHR (1966 Leonids)
+					commander->execute_command("meteors zhr 144000");  // highest ever recorded ZHR (1966 Leonids)
 				} else {
-					app->commander->execute_command("meteors zhr 10");  // set to default base rate (10 is normal, 0 would be none)
+					commander->execute_command("meteors zhr 10");  // set to default base rate (10 is normal, 0 would be none)
 				}
             }
             break;
@@ -1160,7 +1184,7 @@ int StelUI::handle_keys(StelKey key, StelMod mod, Uint16 unicode, Uint8 state)
 					core->getProjection()->setFlipVert(!core->getProjection()->getFlipVert());
 				}
             } else {
-				app->commander->execute_command( "flag constellation_names toggle");
+				commander->execute_command( "flag constellation_names toggle");
             }
             break;
 
@@ -1169,58 +1193,58 @@ int StelUI::handle_keys(StelKey key, StelMod mod, Uint16 unicode, Uint8 state)
 		    		FlagSearch = ! search_win->getVisible();;
 				search_win->setVisible(FlagSearch);
             } else {
-				app->commander->execute_command( "flag fog toggle");
+				commander->execute_command( "flag fog toggle");
             }
 			break;
 
 		case StelKey_r:
-            app->commander->execute_command( "flag constellation_art toggle");
+            commander->execute_command( "flag constellation_art toggle");
             break;
 		case StelKey_c:
-            app->commander->execute_command( "flag constellation_drawing toggle");
+            commander->execute_command( "flag constellation_drawing toggle");
             break;
 		case StelKey_b:
-            app->commander->execute_command( "flag constellation_boundaries toggle");
+            commander->execute_command( "flag constellation_boundaries toggle");
             break;
 		case StelKey_d:
-            app->commander->execute_command( "flag star_names toggle");
+            commander->execute_command( "flag star_names toggle");
             break;
 		case StelKey_p:
 		{
-			SolarSystem* ssmgr2 = (SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("ssystem");
+			SolarSystem* ssmgr2 = (SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("SolarSystem");
 			if(!ssmgr2->getFlagHints())
 			{
-				app->commander->execute_command("flag planet_names on");
+				commander->execute_command("flag planet_names on");
 			}
 			else if( !ssmgr2->getFlagOrbits())
 			{
-				app->commander->execute_command("flag planet_orbits on");
+				commander->execute_command("flag planet_orbits on");
 			}
 			else
 			{
-				app->commander->execute_command("flag planet_orbits off");
-				app->commander->execute_command("flag planet_names off");
+				commander->execute_command("flag planet_orbits off");
+				commander->execute_command("flag planet_names off");
 			}
 			break;
 		}
 		case StelKey_z:
 		{
-			GridLinesMgr* grlmgr = (GridLinesMgr*)StelApp::getInstance().getModuleMgr().getModule("gridlines");
+			GridLinesMgr* grlmgr = (GridLinesMgr*)StelApp::getInstance().getModuleMgr().getModule("GridLinesMgr");
 			if (grlmgr->getFlagMeridianLine()) {
-				app->commander->execute_command( "flag meridian_line 0");
-				app->commander->execute_command( "flag azimuthal_grid 1");
+				commander->execute_command( "flag meridian_line 0");
+				commander->execute_command( "flag azimuthal_grid 1");
 			} else {
-				if (grlmgr->getFlagAzimutalGrid()) app->commander->execute_command( "flag azimuthal_grid 0");
-				else app->commander->execute_command( "flag meridian_line 1");
+				if (grlmgr->getFlagAzimutalGrid()) commander->execute_command( "flag azimuthal_grid 0");
+				else commander->execute_command( "flag meridian_line 1");
 			}
 			break;
 		}
 		case StelKey_e:
             if (!(mod & COMPATIBLE_StelMod_CTRL))
-            	app->commander->execute_command( "flag equatorial_grid toggle");
+            	commander->execute_command( "flag equatorial_grid toggle");
             break;
 		case StelKey_n:
-            app->commander->execute_command( "flag nebula_names toggle");
+            commander->execute_command( "flag nebula_names toggle");
             break;
 		case StelKey_g:
 			if (mod & COMPATIBLE_StelMod_CTRL) {
@@ -1230,28 +1254,28 @@ int StelUI::handle_keys(StelKey key, StelMod mod, Uint16 unicode, Uint8 state)
                     if (pl) core->getObservatory()->setHomePlanet(pl);
                 }
             } else {
-                app->commander->execute_command( "flag landscape toggle");
+                commander->execute_command( "flag landscape toggle");
             }
             break;
 		case StelKey_q:
-            app->commander->execute_command( "flag cardinal_points toggle");
+            commander->execute_command( "flag cardinal_points toggle");
             break;
 		case StelKey_a:
-            app->commander->execute_command( "flag atmosphere toggle");
+            commander->execute_command( "flag atmosphere toggle");
             break;
 
 		case StelKey_t:
 		{
-			MovementMgr* mvmgr = (MovementMgr*)StelApp::getInstance().getModuleMgr().getModule("movements");
+			MovementMgr* mvmgr = (MovementMgr*)StelApp::getInstance().getModuleMgr().getModule("MovementMgr");
             mvmgr->setFlagLockEquPos(!mvmgr->getFlagLockEquPos());
             break;
 		}
 		case StelKey_s:
             if (!(mod & COMPATIBLE_StelMod_CTRL))
-				app->commander->execute_command( "flag stars toggle");
+				commander->execute_command( "flag stars toggle");
             break;
 		case StelKey_SPACE:
-            app->commander->execute_command("flag track_object on");
+            commander->execute_command("flag track_object on");
             break;
 		case StelKey_i:
             FlagInfos=!FlagInfos;
@@ -1259,54 +1283,58 @@ int StelUI::handle_keys(StelKey key, StelMod mod, Uint16 unicode, Uint8 state)
             break;
 		case StelKey_EQUALS:
 			if ((mod & StelMod_ALT) || getDayKeyMode() == "sidereal")
-				app->commander->execute_command( "date sidereal 1");
+				commander->execute_command( "date sidereal 1");
+			else if (mod & COMPATIBLE_StelMod_CTRL)
+				commander->execute_command( "date relative 0.04166666666666666667");
 			else
-				app->commander->execute_command( "date relative 1");
+				commander->execute_command( "date relative 1");
 			break;
 		case StelKey_MINUS:
 			if ((mod & StelMod_ALT) || getDayKeyMode() == "sidereal")
-				app->commander->execute_command( "date sidereal -1");
-			else 
-				app->commander->execute_command( "date relative -1");
+				commander->execute_command( "date sidereal -1");
+			else if (mod & COMPATIBLE_StelMod_CTRL)
+				commander->execute_command( "date relative -0.04166666666666666667");
+			else
+				commander->execute_command( "date relative -1");
             break;
 		case StelKey_m:
             if (FlagEnableTuiMenu) setFlagShowTuiMenu(true);  // not recorded
             break;
 		case StelKey_o:
-            app->commander->execute_command( "flag moon_scaled toggle");
+            commander->execute_command( "flag moon_scaled toggle");
             break;
 		case StelKey_LEFTBRACKET:
 			if ((mod & StelMod_ALT) || getDayKeyMode() == "sidereal")
-				app->commander->execute_command( "date sidereal -7");
+				commander->execute_command( "date sidereal -7");
 			else 
-				app->commander->execute_command( "date relative -7");
+				commander->execute_command( "date relative -7");
             break;
 		case StelKey_RIGHTBRACKET:
 			if ((mod & StelMod_ALT) || getDayKeyMode() == "sidereal")
-				app->commander->execute_command( "date sidereal 7");
+				commander->execute_command( "date sidereal 7");
 			else 
-				app->commander->execute_command( "date relative 7");
+				commander->execute_command( "date relative 7");
             break;
 		case StelKey_SLASH:
             if (mod & COMPATIBLE_StelMod_CTRL) {
-				app->commander->execute_command( "zoom auto out");
+				commander->execute_command( "zoom auto out");
             } else {
-            	MovementMgr* mvmgr = (MovementMgr*)StelApp::getInstance().getModuleMgr().getModule("movements");
+            	MovementMgr* mvmgr = (MovementMgr*)StelApp::getInstance().getModuleMgr().getModule("MovementMgr");
 				// here we help script recorders by selecting the right type of zoom option
 				// based on current settings of manual or full auto zoom
-				if(mvmgr->getFlagManualAutoZoom()) app->commander->execute_command( "zoom auto in manual 1");
-				else app->commander->execute_command( "zoom auto in");
+				if(mvmgr->getFlagManualAutoZoom()) commander->execute_command( "zoom auto in manual 1");
+				else commander->execute_command( "zoom auto in");
             }
             break;
 		case StelKey_BACKSLASH:
-            app->commander->execute_command( "zoom auto out");
+            commander->execute_command( "zoom auto out");
             break;
 		case StelKey_x:
-            app->commander->execute_command( "flag show_tui_datetime toggle");
+            commander->execute_command( "flag show_tui_datetime toggle");
 
 			// keep these in sync.  Maybe this should just be one flag.
-            if(FlagShowTuiDateTime) app->commander->execute_command( "flag show_tui_short_obj_info on");
-            else app->commander->execute_command( "flag show_tui_short_obj_info off");
+            if(FlagShowTuiDateTime) commander->execute_command( "flag show_tui_short_obj_info on");
+            else commander->execute_command( "flag show_tui_short_obj_info off");
             break;
 		case StelKey_RETURN:
             core->getNavigation()->toggleMountMode();
@@ -1342,10 +1370,10 @@ void StelUI::gui_update_widgets(int delta_time)
 	// update message win
 	message_win->update(delta_time);
 	
-	ConstellationMgr* cmgr = (ConstellationMgr*)StelApp::getInstance().getModuleMgr().getModule("constellations");
-	NebulaMgr* nmgr = (NebulaMgr*)StelApp::getInstance().getModuleMgr().getModule("nebulas");
-	LandscapeMgr* lmgr = (LandscapeMgr*)StelApp::getInstance().getModuleMgr().getModule("landscape");
-	GridLinesMgr* grlmgr = (GridLinesMgr*)StelApp::getInstance().getModuleMgr().getModule("gridlines");
+	ConstellationMgr* cmgr = (ConstellationMgr*)StelApp::getInstance().getModuleMgr().getModule("ConstellationMgr");
+	NebulaMgr* nmgr = (NebulaMgr*)StelApp::getInstance().getModuleMgr().getModule("NebulaMgr");
+	LandscapeMgr* lmgr = (LandscapeMgr*)StelApp::getInstance().getModuleMgr().getModule("LandscapeMgr");
+	GridLinesMgr* grlmgr = (GridLinesMgr*)StelApp::getInstance().getModuleMgr().getModule("GridLinesMgr");
 
 	if (!initialised) 
         return;
@@ -1388,7 +1416,7 @@ void StelUI::gui_update_widgets(int delta_time)
 	static double lastJD = 0;
 	if (fabs(lastJD-core->getNavigation()->getJDay())>JD_SECOND/4)
 	{
-		bt_time_now->setState(fabs(core->getNavigation()->getJDay()-get_julian_from_sys())<JD_SECOND);
+		bt_time_now->setState(fabs(core->getNavigation()->getJDay()-StelUtils::getJDFromSystem())<JD_SECOND);
 		lastJD = core->getNavigation()->getJDay();
 	}
 	if (config_win->getVisible()) updateConfigForm();
@@ -1412,12 +1440,9 @@ void StelUI::setTitleObservatoryName(const wstring& name)
 {
 	if (top_bar_appName_lbl) {
 		if (name.empty())
-			top_bar_appName_lbl->setLabel(
-				StelUtils::stringToWstring(StelApp::getApplicationName()));
+			top_bar_appName_lbl->setLabel(StelApp::getApplicationName().toStdWString());
 		else
-			top_bar_appName_lbl->setLabel(
-				StelUtils::stringToWstring(StelApp::getApplicationName())
-					+ L" (" + name + L")");
+			top_bar_appName_lbl->setLabel(StelApp::getApplicationName().toStdWString() + L" (" + name + L")");
 		top_bar_appName_lbl->setPos(StelApp::getInstance().getScreenW()/2-top_bar_appName_lbl->getSizex()/2,1);
 	}
 }
@@ -1434,12 +1459,12 @@ wstring StelUI::getTitleWithAltitude(void)
         L" @ " + StelUtils::doubleToWstring(core->getObservatory()->get_altitude()) + L"m";
 }
 
-void StelUI::setColorScheme(const InitParser& conf, const string& section)
+void StelUI::setColorScheme(const InitParser& conf, const QString& section)
 {
 	if (!desktop) return;
 	
-	s_color GuiBaseColor		= StelUtils::str_to_vec3f(conf.get_str(section, "gui_base_color", "0.3,0.4,0.7"));
-	s_color GuiTextColor		= StelUtils::str_to_vec3f(conf.get_str(section, "gui_text_color", "0.7,0.8,0.9"));
+	s_color GuiBaseColor		= StelUtils::str_to_vec3f(conf.get_str(section.toStdString(), "gui_base_color", "0.3,0.4,0.7"));
+	s_color GuiTextColor		= StelUtils::str_to_vec3f(conf.get_str(section.toStdString(), "gui_text_color", "0.7,0.8,0.9"));
 	
 	desktop->setColorScheme(GuiBaseColor, GuiTextColor);
 }
