@@ -41,6 +41,8 @@
 #include "Navigator.hpp"
 #include "StelFileMgr.hpp"
 #include "Planet.hpp"
+#include <QFile>
+#include <QDebug>
 
 using namespace s_gui;
 
@@ -48,9 +50,9 @@ Component* StelUI::createConfigWindow(SFont& courierFont)
 {
 	StelApp::getInstance().getTextureManager().setDefaultParams();
 	
-	StarMgr* smgr = (StarMgr*)StelApp::getInstance().getModuleMgr().getModule("stars");
-	NebulaMgr* nmgr = (NebulaMgr*)StelApp::getInstance().getModuleMgr().getModule("nebulas");
-	LandscapeMgr* lmgr = (LandscapeMgr*)StelApp::getInstance().getModuleMgr().getModule("landscape");
+	StarMgr* smgr = (StarMgr*)StelApp::getInstance().getModuleMgr().getModule("StarMgr");
+	NebulaMgr* nmgr = (NebulaMgr*)StelApp::getInstance().getModuleMgr().getModule("NebulaMgr");
+	LandscapeMgr* lmgr = (LandscapeMgr*)StelApp::getInstance().getModuleMgr().getModule("LandscapeMgr");
 	
 	config_win = new StdBtWin(_("Configuration"));
 	//config_win->setOpaque(opaqueGUI);
@@ -341,10 +343,12 @@ Component* StelUI::createConfigWindow(SFont& courierFont)
 
 	Label * lblalt = new Label(_("Altitude : "));
 	lblalt->setPos(20, y+81);
-	alt_incdec	= new IntIncDec(&courierFont, tex_up, tex_down, 0, 2000, 0, 10);
+	alt_incdec	= new IntIncDec(&courierFont, tex_up, tex_down, 0, 30000, 0, 10);
 	alt_incdec->setSizex(135);
 	alt_incdec->setOnPressCallback(callback<void>(this, &StelUI::setObserverPositionFromIncDec));
 	alt_incdec->setPos(130,y+80);
+	Label * lblaltunit = new Label(_("m"));
+	lblaltunit->setPos(180, y+81);
 
 	LabeledButton* location_save_bt = new LabeledButton(_("Save location"));
 	location_save_bt->setOnPressCallback(callback<void>(this, &StelUI::saveObserverPosition));
@@ -358,6 +362,7 @@ Component* StelUI::createConfigWindow(SFont& courierFont)
 	tab_location->addComponent(lbllong);
 	tab_location->addComponent(lbllat);
 	tab_location->addComponent(lblalt);
+	tab_location->addComponent(lblaltunit);
 	tab_location->addComponent(long_incdec);
 	tab_location->addComponent(lat_incdec);
 	tab_location->addComponent(alt_incdec);
@@ -397,7 +402,16 @@ Component* StelUI::createConfigWindow(SFont& courierFont)
 	tab_video->addComponent(viewport_distorter_cbx);
 	viewport_distorter_cbx->setPos(x,y); y+=35;
 
+	Label * lblvideo1a = new Label(wstring(L"\u2022 ")+_("Saving settings will save current full screen status"));
+	lblvideo1a->setPos(x+10, y);
+	tab_video->addComponent(lblvideo1a);
+
+	char vs[1000];
 	x=220; y=10;
+	
+	// Should fix bug 1751366
+	screen_size_sl = NULL;
+#ifndef USE_QT4
 	Label * lblvideo2 = new Label(wstring(L"\u2022 ")+_("Screen Resolution :"));
 	lblvideo2->setPos(x+10, y);
 	tab_video->addComponent(lblvideo2); y+=24;
@@ -412,19 +426,18 @@ Component* StelUI::createConfigWindow(SFont& courierFont)
 	screen_size_sl = new ListBox(6);
 	screen_size_sl->setPos(x+20,y);
 	screen_size_sl->setSizex(200);
-	screen_size_sl->addItemList(StelUtils::stringToWstring(app->getVideoModeList()));
-	char vs[1000];
+	screen_size_sl->addItemList(app->getVideoModeList().toStdWString());
 	sprintf(vs, "%dx%d", core->getProjection()->getViewportWidth(), core->getProjection()->getViewportHeight());
 	screen_size_sl->setCurrent(StelUtils::stringToWstring(vs));
 	tab_video->addComponent(screen_size_sl);
 
 	Label * lblvideo5 = new Label(_("For unlisted screen resolution, edit the file :"));
-	Label * lblvideo6 = new Label(StelUtils::stringToWstring(app->getConfigFilePath()));
+	Label * lblvideo6 = new Label(app->getConfigFilePath().toStdWString());
 	lblvideo5->setPos(30, tab_video->getSizey()-125);
 	lblvideo6->setPos(30, tab_video->getSizey()-110);
 	tab_video->addComponent(lblvideo5);
 	tab_video->addComponent(lblvideo6);
-
+#endif
 	LabeledButton* video_save_bt = new LabeledButton(_("Save as default"));
 	video_save_bt->setOnPressCallback(callback<void>(this, &StelUI::setVideoOption));
 	tab_video->addComponent(video_save_bt);
@@ -443,24 +456,24 @@ Component* StelUI::createConfigWindow(SFont& courierFont)
 
 	landscape_sl = new StringList();
 	landscape_sl->setPos(x,y);
-	landscape_sl->addItemList(lmgr->getLandscapeNames());
+	landscape_sl->addItemList(lmgr->getAllLandscapeNames().toStdString());
 	landscape_sl->adjustSize();
-	sprintf(vs, "%s", StelUtils::wstringToString(lmgr->getLandscapeName()).c_str());
+	sprintf(vs, "%s", lmgr->getLandscapeName().toUtf8().constData());
 	landscape_sl->setValue(vs);
 	landscape_sl->setOnPressCallback(callback<void>(this, &StelUI::setLandscape));
 	tab_landscapes->addComponent(landscape_sl);
 
-	landscape_authorlb = new Label(_("Author: ") +lmgr->getLandscapeAuthorName());
+	landscape_authorlb = new Label(_("Author: ") +lmgr->getLandscapeAuthorName().toStdWString());
 	landscape_authorlb->setPos(x+landscape_sl->getSizex()+20, y); 
 	landscape_authorlb->adjustSize();
 	tab_landscapes->addComponent(landscape_authorlb);
 	
-	landscapePlanetLb = new Label(_("Planet: ") + lmgr->getLandscapePlanetName());
+	landscapePlanetLb = new Label(_("Planet: ") + lmgr->getLandscapePlanetName().toStdWString());
 	landscapePlanetLb->setPos(x+landscape_sl->getSizex()+20, y+25); 
 	landscapePlanetLb->adjustSize();
 	tab_landscapes->addComponent(landscapePlanetLb);
 
-	landscapeLocationLb = new Label(_("Location: ") + lmgr->getLandscapeLocationDescription());
+	landscapeLocationLb = new Label(_("Location: ") + lmgr->getLandscapeLocationDescription().toStdWString());
 	landscapeLocationLb->setPos(x+landscape_sl->getSizex()+20, y+50); 
 	landscapeLocationLb->adjustSize();
 	tab_landscapes->addComponent(landscapeLocationLb);
@@ -470,7 +483,7 @@ Component* StelUI::createConfigWindow(SFont& courierFont)
 	locationFromLandscapeCheck->setPos(x+landscape_sl->getSizex()+20, y+80); 
 	tab_landscapes->addComponent(locationFromLandscapeCheck);
 	
-	landscape_descriptionlb = new TextLabel(lmgr->getLandscapeDescription());
+	landscape_descriptionlb = new TextLabel(lmgr->getLandscapeDescription().toStdWString());
 	landscape_descriptionlb->setPos(x+landscape_sl->getSizex()+20, y+110); 
 	landscape_descriptionlb->adjustSize();
 	tab_landscapes->addComponent(landscape_descriptionlb);	
@@ -495,9 +508,9 @@ Component* StelUI::createConfigWindow(SFont& courierFont)
 	language_lb = new ListBox(6);
 	language_lb->setPos(x+10,y);
 	language_lb->setSizex(200);
-	language_lb->addItemList(Translator::getAvailableLanguagesNamesNative(app->getFileMgr().getLocaleDir()));
+	language_lb->addItemList(Translator::getAvailableLanguagesNamesNative(app->getFileMgr().getLocaleDir()).toStdWString());
 	language_lb->setOnChangeCallback(callback<void>(this, &StelUI::setAppLanguage));
-	language_lb->setCurrent(StelUtils::stringToWstring(app->getLocaleMgr().getAppLanguage()));
+	language_lb->setCurrent(app->getLocaleMgr().getAppLanguage().toStdWString());
 	tab_language->addComponent(language_lb);
 	
 	x=260; y=10;
@@ -511,9 +524,9 @@ Component* StelUI::createConfigWindow(SFont& courierFont)
 	languageSky_lb = new ListBox(6);
 	languageSky_lb->setPos(x+10,y);
 	languageSky_lb->setSizex(200);
-	languageSky_lb->addItemList(Translator::getAvailableLanguagesNamesNative(app->getFileMgr().getLocaleDir()));
+	languageSky_lb->addItemList(Translator::getAvailableLanguagesNamesNative(app->getFileMgr().getLocaleDir()).toStdWString());
 	languageSky_lb->setOnChangeCallback(callback<void>(this, &StelUI::setSkyLanguage));
-	languageSky_lb->setCurrent(StelUtils::stringToWstring(app->getLocaleMgr().getSkyLanguage()));
+	languageSky_lb->setCurrent(app->getLocaleMgr().getSkyLanguage().toStdWString());
 	tab_language->addComponent(languageSky_lb);
 
 	x=150;
@@ -584,12 +597,12 @@ void StelUI::dialogCallback(void)
 
 void StelUI::setSkyLanguage(void)
 {
-	app->getLocaleMgr().setSkyLanguage(Translator::nativeLanguageNameCodeToIso639_1(languageSky_lb->getCurrent()));
+	app->getLocaleMgr().setSkyLanguage(Translator::nativeNameToIso639_1Code(QString::fromStdWString(languageSky_lb->getCurrent())));
 }
 
 void StelUI::setAppLanguage(void)
 {
-	app->getLocaleMgr().setAppLanguage(Translator::nativeLanguageNameCodeToIso639_1(language_lb->getCurrent()));
+	app->getLocaleMgr().setAppLanguage(Translator::nativeNameToIso639_1Code(QString::fromStdWString(language_lb->getCurrent())));
 }
 
 void StelUI::setSkyCulture(void)
@@ -602,12 +615,12 @@ void StelUI::load_cities(const string& planetEnglishName)
 	// Clear the old cities
 	earth_map->clearCities();
 	
-	string fileName;
+	QString fileName;
 	try
 	{
-		fileName = StelApp::getInstance().getFileMgr().findFile("data/cities_" + planetEnglishName + ".fab");
+		fileName = StelApp::getInstance().getFileMgr().findFile(QString("data/cities_") + planetEnglishName.c_str() + ".fab");
 	}
-	catch(exception& e)
+	catch (exception& e)
 	{
 		cerr << "INFO StelUI::load_cities " << e.what() << endl;
 		return;
@@ -623,10 +636,10 @@ void StelUI::load_cities(const string& planetEnglishName)
 	int total = 0;
 
 	cout << "Loading Cities data for planet " << planetEnglishName << "...";
-	FILE *fic = fopen(fileName.c_str(), "r");
+	FILE *fic = fopen(QFile::encodeName(fileName).constData(), "r");
 	if (!fic)
 	{
-		cerr << "Can't open " << fileName << endl;
+		qWarning() << "Can't open " << fileName;
 		return;
 	}
 
@@ -739,7 +752,7 @@ void StelUI::autoCompleteSearchedObject(void)
 
 void StelUI::gotoSearchedObject(void)
 {
-	MovementMgr* mvmgr = (MovementMgr*)StelApp::getInstance().getModuleMgr().getModule("movements");
+	MovementMgr* mvmgr = (MovementMgr*)StelApp::getInstance().getModuleMgr().getModule("MovementMgr");
 	
 	if (StelApp::getInstance().getStelObjectMgr().findAndSelectI18n(star_edit->getText()))
 	{
@@ -762,59 +775,63 @@ void StelUI::gotoSearchedObject(void)
 
 void StelUI::updateConfigVariables(void)
 {
-	NebulaMgr* nmgr = (NebulaMgr*)StelApp::getInstance().getModuleMgr().getModule("nebulas");
-	MeteorMgr* metmgr = (MeteorMgr*)StelApp::getInstance().getModuleMgr().getModule("meteors");
-
-	app->commander->execute_command("flag stars ", stars_cbx->getState());
-	app->commander->execute_command("flag star_names ", star_names_cbx->getState());
-	app->commander->execute_command("set max_mag_star_name ", max_mag_star_name->getValue());
-	app->commander->execute_command("flag star_twinkle ", star_twinkle_cbx->getState());
-	app->commander->execute_command("set star_twinkle_amount ", star_twinkle_amount->getValue());
-	app->commander->execute_command("flag constellation_drawing ", constellation_cbx->getState());
-	app->commander->execute_command("flag constellation_names ", constellation_name_cbx->getState());
-	app->commander->execute_command("flag constellation_boundaries ", constellation_boundaries_cbx->getState());
-	app->commander->execute_command("flag constellation_pick ", sel_constellation_cbx->getState());
-	app->commander->execute_command("flag nebula_names ", nebulas_names_cbx->getState());
-	app->commander->execute_command("set max_mag_nebula_name ", max_mag_nebula_name->getValue());
+	NebulaMgr* nmgr = (NebulaMgr*)StelApp::getInstance().getModuleMgr().getModule("NebulaMgr");
+	MeteorMgr* metmgr = (MeteorMgr*)StelApp::getInstance().getModuleMgr().getModule("MeteorMgr");
+	StelCommandInterface* commander = (StelCommandInterface*)StelApp::getInstance().getModuleMgr().getModule("StelCommandInterface");
+	
+	commander->execute_command("flag stars ", stars_cbx->getState());
+	commander->execute_command("flag star_names ", star_names_cbx->getState());
+	commander->execute_command("set max_mag_star_name ", max_mag_star_name->getValue());
+	commander->execute_command("flag star_twinkle ", star_twinkle_cbx->getState());
+	commander->execute_command("set star_twinkle_amount ", star_twinkle_amount->getValue());
+	commander->execute_command("flag constellation_drawing ", constellation_cbx->getState());
+	commander->execute_command("flag constellation_names ", constellation_name_cbx->getState());
+	commander->execute_command("flag constellation_boundaries ", constellation_boundaries_cbx->getState());
+	commander->execute_command("flag constellation_pick ", sel_constellation_cbx->getState());
+	commander->execute_command("flag nebula_names ", nebulas_names_cbx->getState());
+	commander->execute_command("set max_mag_nebula_name ", max_mag_nebula_name->getValue());
 	nmgr->setFlagDisplayNoTexture(nebulas_no_texture_cbx->getState());
-	app->commander->execute_command("flag planet_names ", planets_hints_cbx->getState());
-	app->commander->execute_command("flag moon_scaled ", moon_x4_cbx->getState());
-	app->commander->execute_command("flag equatorial_grid ", equator_grid_cbx->getState());
-	app->commander->execute_command("flag azimuthal_grid ", azimuth_grid_cbx->getState());
-	app->commander->execute_command("flag equator_line ", equator_cbx->getState());
-	app->commander->execute_command("flag ecliptic_line ", ecliptic_cbx->getState());
-	app->commander->execute_command("flag landscape ", ground_cbx->getState());
-	app->commander->execute_command("flag cardinal_points ", cardinal_cbx->getState());
-	app->commander->execute_command("flag atmosphere ", atmosphere_cbx->getState());
-	app->commander->execute_command("flag fog ", fog_cbx->getState());
-	app->commander->execute_command("flag landscape_sets_location ", locationFromLandscapeCheck->getState());
+	commander->execute_command("flag planet_names ", planets_hints_cbx->getState());
+	commander->execute_command("flag moon_scaled ", moon_x4_cbx->getState());
+	commander->execute_command("flag equatorial_grid ", equator_grid_cbx->getState());
+	commander->execute_command("flag azimuthal_grid ", azimuth_grid_cbx->getState());
+	commander->execute_command("flag equator_line ", equator_cbx->getState());
+	commander->execute_command("flag ecliptic_line ", ecliptic_cbx->getState());
+	commander->execute_command("flag landscape ", ground_cbx->getState());
+	commander->execute_command("flag cardinal_points ", cardinal_cbx->getState());
+	commander->execute_command("flag atmosphere ", atmosphere_cbx->getState());
+	commander->execute_command("flag fog ", fog_cbx->getState());
+	commander->execute_command("flag landscape_sets_location ", locationFromLandscapeCheck->getState());
 	if (meteor_rate_10->getState() && metmgr->getZHR()!=10)
-		app->commander->execute_command("meteors zhr 10");
+		commander->execute_command("meteors zhr 10");
 	else if (meteor_rate_80->getState() && metmgr->getZHR()!=80)
-		app->commander->execute_command("meteors zhr 80");
+		commander->execute_command("meteors zhr 80");
 	else if (meteor_rate_10000->getState() && metmgr->getZHR()!=10000)
-		app->commander->execute_command("meteors zhr 10000");
+		commander->execute_command("meteors zhr 10000");
 	else if (meteor_rate_144000->getState() && metmgr->getZHR()!=144000)
-		app->commander->execute_command("meteors zhr 144000");
+		commander->execute_command("meteors zhr 144000");
 }
 
 void StelUI::updateConfigVariables2(void)
 {
-	app->commander->execute_command("flag planets ", planets_cbx->getState());
+	StelCommandInterface* commander = (StelCommandInterface*)StelApp::getInstance().getModuleMgr().getModule("StelCommandInterface");
+	commander->execute_command("flag planets ", planets_cbx->getState());
 }
 
 void StelUI::setCurrentTimeFromConfig(void)
 {
-	//	core->navigation->set_JDay(time_current->getJDay() - core->observatory->get_GMT_shift()*JD_HOUR);
-	app->commander->execute_command(string("date local " + time_current->getDateString()));
+	//StelCommandInterface* commander = (StelCommandInterface*)StelApp::getInstance().getModuleMgr().getModule("StelCommandInterface");
+	core->getNavigation()->setJDay(time_current->getJDay() - app->getLocaleMgr().get_GMT_shift(time_current->getJDay())*JD_HOUR);
+	//commander->execute_command(string("date local " + time_current->getDateString()));
 }
 
 void StelUI::setObserverPositionFromMap(void)
 {
+	StelCommandInterface* commander = (StelCommandInterface*)StelApp::getInstance().getModuleMgr().getModule("StelCommandInterface");
 	std::ostringstream oss;
 	oss << "moveto lat " << earth_map->getPointerLatitude() << " lon " << earth_map->getPointerLongitude()
 		<< " alt " << earth_map->getPointerAltitude();
-	app->commander->execute_command(oss.str());
+	commander->execute_command(oss.str());
 }
 
 void StelUI::setCityFromMap(void)
@@ -826,16 +843,20 @@ void StelUI::setCityFromMap(void)
 
 void StelUI::setObserverPositionFromIncDec(void)
 {
+	StelCommandInterface* commander = (StelCommandInterface*)StelApp::getInstance().getModuleMgr().getModule("StelCommandInterface");
 	std::ostringstream oss;
 	oss.setf(ios::fixed);
 	oss.precision(10);
 	oss << "moveto lat " << lat_incdec->getValue() << " lon " << long_incdec->getValue()
 		<< " alt " << alt_incdec->getValue();
-	app->commander->execute_command(oss.str());
+	commander->execute_command(oss.str());
 }
 
 void StelUI::doSaveObserverPosition(const string& name)
 {
+	StelCommandInterface* commander = (StelCommandInterface*)StelApp::getInstance().getModuleMgr().getModule("StelCommandInterface");
+	StelUI* ui = (StelUI*)StelApp::getInstance().getModuleMgr().getModule("StelUI");
+	
 	string location = name;
     for (string::size_type i=0;i<location.length();++i)
 	{
@@ -845,10 +866,10 @@ void StelUI::doSaveObserverPosition(const string& name)
 	std::ostringstream oss;
 	oss << "moveto lat " << lat_incdec->getValue() << " lon " << long_incdec->getValue()
 		<< " name " << location;
-	app->commander->execute_command(oss.str());
+	commander->execute_command(oss.str());
 
-	core->getObservatory()->save(app->getConfigFilePath(), "init_location");
-	app->ui->setTitleObservatoryName(app->ui->getTitleWithAltitude());
+	core->getObservatory()->save(app->getConfigFilePath().toUtf8().data(), "init_location");
+	ui->setTitleObservatoryName(ui->getTitleWithAltitude());
 }
 
 void StelUI::saveObserverPosition(void)
@@ -864,10 +885,10 @@ void StelUI::saveObserverPosition(void)
 
 void StelUI::saveLandscapeOptions(void)
 {
-	cout << "Saving landscape name in file " << app->getConfigFilePath() << endl;
+	cout << "Saving landscape name in file " << app->getConfigFilePath().toUtf8().data() << endl;
 	InitParser conf;
 	conf.load(app->getConfigFilePath());
-	LandscapeMgr* lmgr = (LandscapeMgr*)app->getModuleMgr().getModule("landscape");
+	LandscapeMgr* lmgr = (LandscapeMgr*)app->getModuleMgr().getModule("LandscapeMgr");
 	conf.set_str("init_location:landscape_name", lmgr->getLandscapeId());
 	conf.set_boolean("landscape:flag_landscape_sets_location", lmgr->getFlagLandscapeSetsLocation());
 	conf.save(app->getConfigFilePath());
@@ -875,7 +896,7 @@ void StelUI::saveLandscapeOptions(void)
 
 void StelUI::setLandscapeUpdatesLocation(void)
 {
-	LandscapeMgr* lmgr = (LandscapeMgr*)app->getModuleMgr().getModule("landscape");
+	LandscapeMgr* lmgr = (LandscapeMgr*)app->getModuleMgr().getModule("LandscapeMgr");
 	lmgr->setFlagLandscapeSetsLocation(locationFromLandscapeCheck->getState());
 	InitParser conf;
 	conf.load(app->getConfigFilePath());
@@ -892,7 +913,7 @@ void StelUI::setLandscapeUpdatesLocation(void)
 
 void StelUI::saveLanguageOptions(void)
 {
-	cout << "Saving language in file " << app->getConfigFilePath() << endl;
+	cout << "Saving language in file " << app->getConfigFilePath().toUtf8().data() << endl;
 	InitParser conf;
 	conf.load(app->getConfigFilePath());
 	conf.set_str("localization:sky_locale", app->getLocaleMgr().getSkyLanguage());
@@ -903,18 +924,18 @@ void StelUI::saveLanguageOptions(void)
 
 void StelUI::saveRenderOptions(void)
 {
-	cout << "Saving rendering options in file " << app->getConfigFilePath() << endl;
+	cout << "Saving rendering options in file " << app->getConfigFilePath().toUtf8().data() << endl;
 
 	InitParser conf;
 	conf.load(app->getConfigFilePath());
 
-	StarMgr* smgr = (StarMgr*)StelApp::getInstance().getModuleMgr().getModule("stars");
-	ConstellationMgr* cmgr = (ConstellationMgr*)StelApp::getInstance().getModuleMgr().getModule("constellations");
-	NebulaMgr* nmgr = (NebulaMgr*)StelApp::getInstance().getModuleMgr().getModule("nebulas");
-	SolarSystem* ssmgr = (SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("ssystem");
-	LandscapeMgr* lmgr = (LandscapeMgr*)StelApp::getInstance().getModuleMgr().getModule("landscape");
-	GridLinesMgr* grlmgr = (GridLinesMgr*)StelApp::getInstance().getModuleMgr().getModule("gridlines");
-	MeteorMgr* metmgr = (MeteorMgr*)StelApp::getInstance().getModuleMgr().getModule("meteors");
+	StarMgr* smgr = (StarMgr*)StelApp::getInstance().getModuleMgr().getModule("StarMgr");
+	ConstellationMgr* cmgr = (ConstellationMgr*)StelApp::getInstance().getModuleMgr().getModule("ConstellationMgr");
+	NebulaMgr* nmgr = (NebulaMgr*)StelApp::getInstance().getModuleMgr().getModule("NebulaMgr");
+	SolarSystem* ssmgr = (SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("SolarSystem");
+	LandscapeMgr* lmgr = (LandscapeMgr*)StelApp::getInstance().getModuleMgr().getModule("LandscapeMgr");
+	GridLinesMgr* grlmgr = (GridLinesMgr*)StelApp::getInstance().getModuleMgr().getModule("GridLinesMgr");
+	MeteorMgr* metmgr = (MeteorMgr*)StelApp::getInstance().getModuleMgr().getModule("MeteorMgr");
 	
 	conf.set_boolean("astro:flag_stars", smgr->getFlagStars());
 	conf.set_boolean("astro:flag_star_name", smgr->getFlagNames());
@@ -951,21 +972,34 @@ void StelUI::saveRenderOptions(void)
 
 void StelUI::setVideoOption(void)
 {
-	string s = StelUtils::wstringToString(screen_size_sl->getCurrent());
-	int i = s.find("x");
-	int w = atoi(s.substr(0,i).c_str());
-	int h = atoi(s.substr(i+1,s.size()).c_str());
+	int w, h;
+	if (screen_size_sl==NULL)
+	{
+		// In QT build the screen_size_sl does not exist.
+		w = StelApp::getInstance().getScreenW();
+		h = StelApp::getInstance().getScreenH();
+	}
+	else
+	{
+		// SDL build - take res from SDL mode-string, else
+		// we can get a full screen with a non-fullsized
+		// view port inside it (if we just use the 
+		string s = StelUtils::wstringToString(screen_size_sl->getCurrent());
+		int i = s.find("x");
+		w = atoi(s.substr(0,i).c_str());
+		h = atoi(s.substr(i+1,s.size()).c_str());
+	}
 
         // cheap hack to prevent bug #1483662 - MNG, 20060508
 	cout << "Saving video settings: projection=" << core->getProjection()->getCurrentProjection()
-	     << ", distorter=" << app->getViewPortDistorterType();
+			<< ", distorter=" << qPrintable(app->getViewPortDistorterType());
 	if ( w && h ) cout << ", res=" << w << "x" << h;
-	cout << " in file " << app->getConfigFilePath() << endl;
+	cout << " in file " << qPrintable(app->getConfigFilePath()) << endl;
 
 	InitParser conf;
 	conf.load(app->getConfigFilePath());
 
-	conf.set_str("projection:type", core->getProjection()->getCurrentProjection());
+	conf.set_str("projection:type", core->getProjection()->getCurrentProjection().c_str());
 	conf.set_str("video:distorter", app->getViewPortDistorterType());
 
 
@@ -984,12 +1018,12 @@ void StelUI::setVideoOption(void)
 
 void StelUI::setLandscape(void)
 {
-	LandscapeMgr* lmgr = (LandscapeMgr*)StelApp::getInstance().getModuleMgr().getModule("landscape");
-	lmgr->setLandscape(lmgr->nameToKey(landscape_sl->getValue()));
-	landscape_authorlb->setLabel(_("Author: ") + lmgr->getLandscapeAuthorName());
-	landscape_descriptionlb->setLabel(_("Info: ") + lmgr->getLandscapeDescription());	
-	landscapePlanetLb->setLabel(_("Planet: ") + lmgr->getLandscapePlanetName());
-	landscapeLocationLb->setLabel(_("Location: ") + lmgr->getLandscapeLocationDescription());
+	LandscapeMgr* lmgr = (LandscapeMgr*)StelApp::getInstance().getModuleMgr().getModule("LandscapeMgr");
+	lmgr->setLandscapeByName(landscape_sl->getValue().c_str());
+	landscape_authorlb->setLabel(_("Author: ") + lmgr->getLandscapeAuthorName().toStdWString());
+	landscape_descriptionlb->setLabel(_("Info: ") + lmgr->getLandscapeDescription().toStdWString());	
+	landscapePlanetLb->setLabel(_("Planet: ") + lmgr->getLandscapePlanetName().toStdWString());
+	landscapeLocationLb->setLabel(_("Location: ") + lmgr->getLandscapeLocationDescription().toStdWString());
 }
 
 void StelUI::updateVideoVariables(void)
@@ -1012,13 +1046,13 @@ void StelUI::updateVideoVariables(void)
 void StelUI::updateConfigForm(void)
 {
 	// Stars
-	StarMgr* smgr = (StarMgr*)StelApp::getInstance().getModuleMgr().getModule("stars");
-	ConstellationMgr* cmgr = (ConstellationMgr*)StelApp::getInstance().getModuleMgr().getModule("constellations");
-	NebulaMgr* nmgr = (NebulaMgr*)StelApp::getInstance().getModuleMgr().getModule("nebulas");
-	SolarSystem* ssmgr = (SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("ssystem");
-	LandscapeMgr* lmgr = (LandscapeMgr*)StelApp::getInstance().getModuleMgr().getModule("landscape");
-	GridLinesMgr* grlmgr = (GridLinesMgr*)StelApp::getInstance().getModuleMgr().getModule("gridlines");
-	MeteorMgr* metmgr = (MeteorMgr*)StelApp::getInstance().getModuleMgr().getModule("meteors");
+	StarMgr* smgr = (StarMgr*)StelApp::getInstance().getModuleMgr().getModule("StarMgr");
+	ConstellationMgr* cmgr = (ConstellationMgr*)StelApp::getInstance().getModuleMgr().getModule("ConstellationMgr");
+	NebulaMgr* nmgr = (NebulaMgr*)StelApp::getInstance().getModuleMgr().getModule("NebulaMgr");
+	SolarSystem* ssmgr = (SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("SolarSystem");
+	LandscapeMgr* lmgr = (LandscapeMgr*)StelApp::getInstance().getModuleMgr().getModule("LandscapeMgr");
+	GridLinesMgr* grlmgr = (GridLinesMgr*)StelApp::getInstance().getModuleMgr().getModule("GridLinesMgr");
+	MeteorMgr* metmgr = (MeteorMgr*)StelApp::getInstance().getModuleMgr().getModule("MeteorMgr");
 	
 	stars_cbx->setState(smgr->getFlagStars());
 	star_names_cbx->setState(smgr->getFlagNames());
@@ -1134,12 +1168,17 @@ void StelUI::search_win_hideBtCallback(void)
 
 void StelUI::updatePlanetMap(const string& englishName)
 {
-	SolarSystem* ssystem = (SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("ssystem");
+	SolarSystem* ssystem = (SolarSystem*)StelApp::getInstance().getModuleMgr().getModule("SolarSystem");
 	Planet* planetObject = (Planet*)(ssystem->searchByEnglishName(englishName));
 	if (!planetObject)
 		return;
 	
-	STextureSP newTex = planetObject->getMapTexture();
+	STextureSP newTex;
+	if (planetObject->getEnglishName()=="Earth")
+		newTex = StelApp::getInstance().getTextureManager().createTexture("earthmap.png");
+	else
+		newTex = planetObject->getMapTexture();
+	
 	if (newTex)
 		earth_map->setMapTexture(newTex);
 	else
