@@ -44,6 +44,8 @@
 #include "Observer.hpp"
 #include "StelFileMgr.hpp"
 #include "InitParser.hpp"
+#include <QTextStream>
+#include <QFile>
 
 // Draw simple gravity text ui.
 void StelUI::draw_gravity_ui(void)
@@ -61,20 +63,27 @@ void StelUI::draw_gravity_ui(void)
 	if (FlagShowTuiDateTime)
 	{
 		double jd = core->getNavigation()->getJDay();
-		wostringstream os;
+		
+		QString str;
+		QTextStream os(&str);
 
-		os << app->getLocaleMgr().get_printable_date_local(jd) << L" " << app->getLocaleMgr().get_printable_time_local(jd);
+		os << QString::fromStdWString(app->getLocaleMgr().get_printable_date_local(jd) + L" " + app->getLocaleMgr().get_printable_time_local(jd));
 
 		// label location if not on earth
 		if(core->getObservatory()->getHomePlanetEnglishName() != "Earth") {
-			os << L" " << _(core->getObservatory()->getHomePlanetEnglishName());
+			os << " ";
+			os << q_(core->getObservatory()->getHomePlanetEnglishName().c_str());
 		}
 
-		if (FlagShowFov) os << L" fov " << setprecision(3) << core->getProjection()->getFov();
-		if (FlagShowFps) os << L"  FPS " << app->fps;
+		if (FlagShowFov)
+		{
+			os.setRealNumberPrecision(3);
+			os << " fov " << core->getProjection()->getFov();
+		}
+		if (FlagShowFps) os << "  FPS " << app->getFps();
 
 		glColor3f(0.5,1,0.5);
-		core->getProjection()->drawText(tuiFont, x - shift + 38, y - 38, os.str(), 0, 0, 0, false);
+		core->getProjection()->drawText(tuiFont, x - shift + 38, y - 38, str.toStdWString(), 0, 0, 0, false);
 	}
 
 	if (app->getStelObjectMgr().getWasSelected() && FlagShowTuiShortObjInfo)
@@ -90,7 +99,7 @@ void StelUI::draw_gravity_ui(void)
 // since lose states - try localizeTui() instead
 void StelUI::init_tui(void)
 {
-	LandscapeMgr* lmgr = (LandscapeMgr*)app->getModuleMgr().getModule("landscape");
+	LandscapeMgr* lmgr = (LandscapeMgr*)app->getModuleMgr().getModule("LandscapeMgr");
 	
 	// Menu root branch
 	ScriptDirectoryRead = 0;
@@ -129,7 +138,7 @@ void StelUI::init_tui(void)
 	// Home planet only changed if hit enter to accept because
 	// switching planet instantaneously as select is hard on a planetarium audience
 	tui_location_planet = new s_tui::MultiSet2_item<wstring>(wstring(L"1.4 ") );
-	SolarSystem* ssmgr = (SolarSystem*)app->getModuleMgr().getModule("ssystem");
+	SolarSystem* ssmgr = (SolarSystem*)app->getModuleMgr().getModule("SolarSystem");
 	tui_location_planet->addItemList(ssmgr->getPlanetHashString());
 	//	tui_location_planet->set_OnChangeCallback(callback<void>(this, &StelUI::tui_cb_location_change_planet));
 	tui_location_planet->set_OnTriggerCallback(callback<void>(this, &StelUI::tui_cb_location_change_planet));
@@ -144,7 +153,7 @@ void StelUI::init_tui(void)
 	tui_time_skytime->set_OnChangeCallback(callback<void>(this, &StelUI::tui_cb_sky_time));
 	try
 	{
-		tui_time_settmz = new s_tui::Time_zone_item(app->getFileMgr().findFile("data/zone.tab"), wstring(L"2.2 "));
+		tui_time_settmz = new s_tui::Time_zone_item(QFile::encodeName(app->getFileMgr().findFile("data/zone.tab")).constData(), wstring(L"2.2 "));
 	}
 	catch(exception &e)
 	{
@@ -188,7 +197,7 @@ void StelUI::init_tui(void)
 	tui_menu_general->addComponent(tui_general_sky_culture);
 
 	tui_general_sky_locale = new s_tui::MultiSet_item<wstring>(wstring(L"3.2 ") );
-	tui_general_sky_locale->addItemList(Translator::getAvailableLanguagesNamesNative(app->getFileMgr().getLocaleDir()));
+	tui_general_sky_locale->addItemList(Translator::getAvailableLanguagesNamesNative(app->getFileMgr().getLocaleDir()).toStdWString());
 
 	tui_general_sky_locale->set_OnChangeCallback(callback<void>(this, &StelUI::tui_cb_tui_general_change_sky_locale));
 	tui_menu_general->addComponent(tui_general_sky_locale);
@@ -203,8 +212,8 @@ void StelUI::init_tui(void)
 	tui_star_labelmaxmag->set_OnChangeCallback(callback<void>(this, &StelUI::tui_cb_stars));
 	tui_stars_twinkle = new s_tui::Decimal_item(0., 1., 0.3, wstring(L"4.4 "), 0.1);
 	tui_stars_twinkle->set_OnChangeCallback(callback<void>(this, &StelUI::tui_cb_stars));
-	tui_star_limitingmag = new s_tui::Decimal_item(0., 7., 6.5, wstring(L"4.5 "), 0.1);
-	tui_star_limitingmag->set_OnChangeCallback(callback<void>(this, &StelUI::tui_cb_stars));
+//	tui_star_limitingmag = new s_tui::Decimal_item(0., 7., 6.5, wstring(L"4.5 "), 0.1);
+//	tui_star_limitingmag->set_OnChangeCallback(callback<void>(this, &StelUI::tui_cb_stars));
 
 	tui_menu_stars->addComponent(tui_stars_show);
 	tui_menu_stars->addComponent(tui_star_magscale);
@@ -281,7 +290,7 @@ void StelUI::init_tui(void)
 	tui_menu_effects->addComponent(tui_effect_light_pollution);
 
 	tui_effect_landscape = new s_tui::MultiSet_item<wstring>(wstring(L"5.1 ") );
-	tui_effect_landscape->addItemList(StelUtils::stringToWstring(lmgr->getLandscapeNames()));
+	tui_effect_landscape->addItemList(lmgr->getAllLandscapeNames().toStdWString());
 
 	tui_effect_landscape->set_OnChangeCallback(callback<void>(this, &StelUI::tui_cb_tui_effect_change_landscape));
 	tui_menu_effects->addComponent(tui_effect_landscape);
@@ -322,7 +331,7 @@ void StelUI::init_tui(void)
 	// 6. Scripts
 	tui_scripts_local = new s_tui::MultiSet_item<wstring>(wstring(L"6.1 ") );
 	//	tui_scripts_local->addItemList(wstring(TUI_SCRIPT_MSG) + wstring(L"\n") 
-	//			       + StelUtils::stringToWstring(app->scripts->get_script_list(core->getDataDir() + "scripts/"))); 
+	//			       + StelUtils::stringToWstring(scripts->get_script_list(core->getDataDir() + "scripts/"))); 
 	tui_scripts_local->set_OnChangeCallback(callback<void>(this, &StelUI::tui_cb_scripts_local));
 	tui_menu_scripts->addComponent(tui_scripts_local);
 
@@ -347,7 +356,7 @@ void StelUI::init_tui(void)
 	tui_menu_administration->addComponent(tui_admin_updateme);
 
 	tui_admin_setlocale = new s_tui::MultiSet_item<wstring>(L"7.5 ");
-	tui_admin_setlocale->addItemList(Translator::getAvailableLanguagesNamesNative(app->getFileMgr().getLocaleDir()));
+	tui_admin_setlocale->addItemList(Translator::getAvailableLanguagesNamesNative(app->getFileMgr().getLocaleDir()).toStdWString());
 	tui_admin_setlocale->set_OnChangeCallback(callback<void>(this, &StelUI::tui_cb_admin_set_locale));
 	tui_menu_administration->addComponent(tui_admin_setlocale);
 
@@ -359,8 +368,9 @@ void StelUI::init_tui(void)
 // Update fonts, labels and lists for a new app locale
 void StelUI::localizeTui(void)
 {
-
-	cout << "Localizing TUI for locale: " << app->getLocaleMgr().getAppLanguage() << endl;
+	ScriptMgr* scripts = (ScriptMgr*)StelApp::getInstance().getModuleMgr().getModule("ScriptMgr");
+	
+	cout << "Localizing TUI for locale: " << qPrintable(app->getLocaleMgr().getAppLanguage()) << endl;
 
 	if(!tui_root) return;  // not initialized yet
 
@@ -378,7 +388,7 @@ void StelUI::localizeTui(void)
 	tui_location_longitude->setLabel(wstring(L"1.2 ") + _("Longitude: "));
 	tui_location_altitude->setLabel(wstring(L"1.3 ") + _("Altitude (m): "));
 	tui_location_planet->setLabel(wstring(L"1.4 ") + _("Solar System Body: "));
-	SolarSystem* ssmgr = (SolarSystem*)app->getModuleMgr().getModule("ssystem");
+	SolarSystem* ssmgr = (SolarSystem*)app->getModuleMgr().getModule("SolarSystem");
 	tui_location_planet->replaceItemList(ssmgr->getPlanetHashString(),0);
 
 	// 2. Time
@@ -408,7 +418,7 @@ void StelUI::localizeTui(void)
 	tui_star_magscale->setLabel(wstring(L"4.2 ") + _("Star Value Multiplier: "));
 	tui_star_labelmaxmag->setLabel(wstring(L"4.3 ") + _("Maximum Magnitude to Label: "));
 	tui_stars_twinkle->setLabel(wstring(L"4.4 ") + _("Twinkling: "));
-	tui_star_limitingmag->setLabel(wstring(L"4.5 ") + _("Limiting Magnitude: "));
+	//tui_star_limitingmag->setLabel(wstring(L"4.5 ") + _("Limiting Magnitude: "));
 
 	// 5. Colors
 	tui_colors_const_line_color->setLabel(wstring(L"5.1 ") + _("Constellation Lines") + L": ");
@@ -443,7 +453,7 @@ void StelUI::localizeTui(void)
 	// 7. Scripts
 	tui_scripts_local->setLabel(wstring(L"7.1 ") + _("Local Script: "));
 	tui_scripts_local->replaceItemList(_(TUI_SCRIPT_MSG) + wstring(L"\n") 
-			+ StelUtils::stringToWstring(app->scripts->get_script_list("scripts")), 0); 
+			+ StelUtils::stringToWstring(scripts->get_script_list("scripts")), 0); 
 	tui_scripts_removeable->setLabel(wstring(L"7.2 ") + _("CD/DVD Script: "));
 	tui_scripts_removeable->replaceItemList(_(TUI_SCRIPT_MSG), 0);
 
@@ -505,10 +515,10 @@ int StelUI::handle_keys_tui(Uint16 key, Uint8 state)
 			{
 				try
 				{
-					string theParent = app->getFileMgr().findFile("scripts/" + SelectedScript);
+					QString theParent = app->getFileMgr().findFile(QString("scripts/") + SelectedScript.c_str());
 					theParent = app->getFileMgr().dirName(theParent);
 					cmd = "script action play filename \"" + SelectedScript 
-						+ "\" path \"" + theParent + "/\"";
+						+ "\" path \"" + QFile::encodeName(theParent).constData() + "/\"";
 				}
 				catch(exception& e)
 				{
@@ -517,8 +527,9 @@ int StelUI::handle_keys_tui(Uint16 key, Uint8 state)
 			}
 			
 			// now execute the command
+			StelCommandInterface* commander = (StelCommandInterface*)StelApp::getInstance().getModuleMgr().getModule("StelCommandInterface");
 			if ( cmd != "" )
-				app->commander->execute_command(cmd);
+				commander->execute_command(cmd);
 			else
 				cerr << "ERROR while executing script" << endl;
 		}
@@ -547,14 +558,14 @@ void StelUI::tui_update_widgets(void)
 
 	if (!FlagShowTuiMenu) return;
 	
-	StarMgr* smgr = (StarMgr*)app->getModuleMgr().getModule("stars");
-	ConstellationMgr* cmgr = (ConstellationMgr*)app->getModuleMgr().getModule("constellations");
-	NebulaMgr* nmgr = (NebulaMgr*)app->getModuleMgr().getModule("nebulas");
-	SolarSystem* ssmgr = (SolarSystem*)app->getModuleMgr().getModule("ssystem");
-	MilkyWay* mw = (MilkyWay*)app->getModuleMgr().getModule("milkyway");
-	LandscapeMgr* lmgr = (LandscapeMgr*)app->getModuleMgr().getModule("landscape");
-	GridLinesMgr* grlmgr = (GridLinesMgr*)app->getModuleMgr().getModule("gridlines");
-	MovementMgr* mvmgr = (MovementMgr*)app->getModuleMgr().getModule("movements");
+	StarMgr* smgr = (StarMgr*)app->getModuleMgr().getModule("StarMgr");
+	ConstellationMgr* cmgr = (ConstellationMgr*)app->getModuleMgr().getModule("ConstellationMgr");
+	NebulaMgr* nmgr = (NebulaMgr*)app->getModuleMgr().getModule("NebulaMgr");
+	SolarSystem* ssmgr = (SolarSystem*)app->getModuleMgr().getModule("SolarSystem");
+	MilkyWay* mw = (MilkyWay*)app->getModuleMgr().getModule("MilkyWay");
+	LandscapeMgr* lmgr = (LandscapeMgr*)app->getModuleMgr().getModule("LandscapeMgr");
+	GridLinesMgr* grlmgr = (GridLinesMgr*)app->getModuleMgr().getModule("GridLinesMgr");
+	MovementMgr* mvmgr = (MovementMgr*)app->getModuleMgr().getModule("MovementMgr");
 	
 	// 1. Location
 	tui_location_latitude->setValue(core->getObservatory()->get_latitude());
@@ -572,8 +583,8 @@ void StelUI::tui_update_widgets(void)
 	tui_time_dateformat->setCurrent(StelUtils::stringToWstring(app->getLocaleMgr().get_date_format_str()));
 
 	// 3. general
-	tui_general_sky_culture->setValue(StelUtils::stringToWstring(app->getSkyCultureMgr().getSkyCultureDir()));
-	tui_general_sky_locale->setValue(StelUtils::stringToWstring(app->getLocaleMgr().getSkyLanguage()));
+	tui_general_sky_culture->setValue(app->getSkyCultureMgr().getSkyCultureDir().toStdWString());
+	tui_general_sky_locale->setValue(app->getLocaleMgr().getSkyLanguage().toStdWString());
 
 	// 4. Stars
 	tui_stars_show->setValue(smgr->getFlagStars());
@@ -603,9 +614,9 @@ void StelUI::tui_update_widgets(void)
 
 	// 6. effects
 	tui_effect_light_pollution->setValue(lmgr->getAtmosphereLightPollutionLuminance());
-	tui_effect_landscape->setValue(lmgr->getLandscapeName());
+	tui_effect_landscape->setValue(lmgr->getLandscapeName().toStdWString());
 	tui_effect_pointobj->setValue(smgr->getFlagPointStar());
-	tui_effect_zoom_duration->setValue(mvmgr->getAutomoveDuration());
+	tui_effect_zoom_duration->setValue(mvmgr->getAutoMoveDuration());
 	tui_effect_manual_zoom->setValue(mvmgr->getFlagManualAutoZoom());
 	tui_effect_object_scale->setValue(smgr->getScale());
 	tui_effect_milkyway_intensity->setValue(mw->getIntensity());
@@ -628,7 +639,7 @@ void StelUI::tui_update_widgets(void)
 	}
 
 	// 8. admin
-	tui_admin_setlocale->setValue( StelUtils::stringToWstring(app->getLocaleMgr().getAppLanguage()) );
+	tui_admin_setlocale->setValue(app->getLocaleMgr().getAppLanguage().toStdWString());
 
 }
 
@@ -673,7 +684,7 @@ void StelUI::tui_cb_admin_save_default(void)
 
 	try
 	{
-		system( (app->getFileMgr().findFile("data/script_save_config ") ).c_str() );
+		system( QFile::encodeName(app->getFileMgr().findFile("data/script_save_config ")).constData());
 	}
 	catch(exception& e)
 	{
@@ -686,7 +697,7 @@ void StelUI::tui_cb_admin_updateme(void)
 {
 	try
 	{
-		system( ( app->getFileMgr().findFile("data/script_internet_update" )).c_str() );
+		system( QFile::encodeName(app->getFileMgr().findFile("data/script_internet_update ")).constData());
 	}
 	catch(exception& e)
 	{
@@ -700,7 +711,7 @@ void StelUI::tui_cb_admin_shutdown(void)
 {
 	try
 	{
-		system( ( app->getFileMgr().findFile("data/script_shutdown" )).c_str() );
+		system( QFile::encodeName(app->getFileMgr().findFile("data/script_shutdown ")).constData());
 	}
 	catch(exception& e)
 	{
@@ -712,29 +723,32 @@ void StelUI::tui_cb_admin_shutdown(void)
 // Set a new landscape skin
 void StelUI::tui_cb_tui_effect_change_landscape(void)
 {
-	app->commander->execute_command(string("set landscape_name \"" +  StelUtils::wstringToString(tui_effect_landscape->getCurrent()) + "\""));
+	StelCommandInterface* commander = (StelCommandInterface*)StelApp::getInstance().getModuleMgr().getModule("StelCommandInterface");
+	commander->execute_command(string("set landscape_name \"" +  StelUtils::wstringToString(tui_effect_landscape->getCurrent()) + "\""));
 }
 
 
 // Set a new sky culture
 void StelUI::tui_cb_tui_general_change_sky_culture(void) {
-
+	StelCommandInterface* commander = (StelCommandInterface*)StelApp::getInstance().getModuleMgr().getModule("StelCommandInterface");
 	//	core->setSkyCulture(tui_general_sky_culture->getCurrent());
-	app->commander->execute_command( string("set sky_culture ") + StelUtils::wstringToString(tui_general_sky_culture->getCurrent()));
+	commander->execute_command( string("set sky_culture ") + StelUtils::wstringToString(tui_general_sky_culture->getCurrent()));
 }
 
 // Set a new sky locale
 void StelUI::tui_cb_tui_general_change_sky_locale(void) {
+	StelCommandInterface* commander = (StelCommandInterface*)StelApp::getInstance().getModuleMgr().getModule("StelCommandInterface");
 	// wcout << "set sky locale to " << tui_general_sky_locale->getCurrent() << endl;
-	app->commander->execute_command( string("set sky_locale " + StelUtils::wstringToString(tui_general_sky_locale->getCurrent())));
+	commander->execute_command( string("set sky_locale " + StelUtils::wstringToString(tui_general_sky_locale->getCurrent())));
 }
 
 
 // callback for changing scripts from removeable media
 void StelUI::tui_cb_scripts_removeable() {
   if(!ScriptDirectoryRead) {
+  		ScriptMgr* scripts = (ScriptMgr*)StelApp::getInstance().getModuleMgr().getModule("ScriptMgr");
 	  // read scripts from mounted disk
-	  string script_list = app->scripts->get_script_list(app->scripts->get_removable_media_path());
+	  string script_list = scripts->get_script_list(scripts->get_removable_media_path());
 	  tui_scripts_removeable->replaceItemList(_(TUI_SCRIPT_MSG) + wstring(L"\n") + StelUtils::stringToWstring(script_list),0);
 	  ScriptDirectoryRead = 1;
   } 
@@ -742,8 +756,9 @@ void StelUI::tui_cb_scripts_removeable() {
   if(tui_scripts_removeable->getCurrent()==_(TUI_SCRIPT_MSG)) {
 	  SelectedScript = "";
   } else {
+  		ScriptMgr* scripts = (ScriptMgr*)StelApp::getInstance().getModuleMgr().getModule("ScriptMgr");
 	  SelectedScript = StelUtils::wstringToString(tui_scripts_removeable->getCurrent());
-	  SelectedScriptDirectory = app->scripts->get_removable_media_path();
+	  SelectedScriptDirectory = scripts->get_removable_media_path().toStdString();
 	  // to avoid confusing user, clear out local script selection as well
 	  tui_scripts_local->setCurrent(_(TUI_SCRIPT_MSG));
   } 
@@ -771,85 +786,88 @@ void StelUI::tui_cb_scripts_local() {
 // change UI locale
 void StelUI::tui_cb_admin_set_locale() {
 
-	app->getLocaleMgr().setAppLanguage(StelUtils::wstringToString(tui_admin_setlocale->getCurrent()));
+	app->getLocaleMgr().setAppLanguage(QString::fromStdWString(tui_admin_setlocale->getCurrent()));
 }
 
 
 void StelUI::tui_cb_effects_milkyway_intensity() {
-
+	StelCommandInterface* commander = (StelCommandInterface*)StelApp::getInstance().getModuleMgr().getModule("StelCommandInterface");
 	std::ostringstream oss;
 	oss << "set milky_way_intensity " << tui_effect_milkyway_intensity->getValue();
-	app->commander->execute_command(oss.str());
+	commander->execute_command(oss.str());
 }
 
 void StelUI::tui_cb_setlocation() {
-	
+	StelCommandInterface* commander = (StelCommandInterface*)StelApp::getInstance().getModuleMgr().getModule("StelCommandInterface");
 	std::ostringstream oss;
 	oss << "moveto lat " << tui_location_latitude->getValue() 
 		<< " lon " <<  tui_location_longitude->getValue()
 		<< " alt " << tui_location_altitude->getValue();
-	app->commander->execute_command(oss.str());
+	commander->execute_command(oss.str());
 
 }
 
 
 void StelUI::tui_cb_stars()
 {
+	StelCommandInterface* commander = (StelCommandInterface*)StelApp::getInstance().getModuleMgr().getModule("StelCommandInterface");
+	
 	// 4. Stars
 	std::ostringstream oss;
 
 	oss << "flag stars " << tui_stars_show->getValue();
-	app->commander->execute_command(oss.str());
+	commander->execute_command(oss.str());
 
 	oss.str("");
 	oss << "set max_mag_star_name " << tui_star_labelmaxmag->getValue();
-	app->commander->execute_command(oss.str());
+	commander->execute_command(oss.str());
 
 	oss.str("");
 	oss << "set star_twinkle_amount " << tui_stars_twinkle->getValue();
-	app->commander->execute_command(oss.str());
+	commander->execute_command(oss.str());
 
 	oss.str("");
 	oss << "set star_mag_scale " << tui_star_magscale->getValue();
-	app->commander->execute_command(oss.str());
+	commander->execute_command(oss.str());
 /* TODO
 	oss.str("");
 	oss << "set star_limiting_mag " << tui_star_limitingmag->getValue();
-	app->commander->execute_command(oss.str());
+	commander->execute_command(oss.str());
 */
 
 }
 
 void StelUI::tui_cb_effects()
 {
-
+	StelCommandInterface* commander = (StelCommandInterface*)StelApp::getInstance().getModuleMgr().getModule("StelCommandInterface");
+	
 	// 5. effects
 	std::ostringstream oss;
 
 	oss << "flag point_star " << tui_effect_pointobj->getValue();
-	app->commander->execute_command(oss.str());
+	commander->execute_command(oss.str());
 
 	oss.str("");
 	oss << "set auto_move_duration " << tui_effect_zoom_duration->getValue();
-	app->commander->execute_command(oss.str());
+	commander->execute_command(oss.str());
 
 	oss.str("");
 	oss << "flag manual_zoom " << tui_effect_manual_zoom->getValue();
-	app->commander->execute_command(oss.str());
+	commander->execute_command(oss.str());
 
 	oss.str("");
 	oss << "set star_scale " << tui_effect_object_scale->getValue();
-	app->commander->execute_command(oss.str());
+	commander->execute_command(oss.str());
 
 	MouseCursorTimeout = tui_effect_cursor_timeout->getValue();  // never recorded
 
 	oss.str("");
 	oss << "set light_pollution_luminance " << tui_effect_light_pollution->getValue();
-	app->commander->execute_command(oss.str());
+	commander->execute_command(oss.str());
 
 	oss.str("");
 	oss << "flag landscape_sets_location " << tui_effect_landscape_sets_location->getValue();
-	app->commander->execute_command(oss.str());
+	commander->execute_command(oss.str());
 
 }
 
@@ -857,28 +875,30 @@ void StelUI::tui_cb_effects()
 // set sky time
 void StelUI::tui_cb_sky_time()
 {
+	StelCommandInterface* commander = (StelCommandInterface*)StelApp::getInstance().getModuleMgr().getModule("StelCommandInterface");
 	std::ostringstream oss;
 	oss << "date local " << StelUtils::wstringToString(tui_time_skytime->getDateString());
-	app->commander->execute_command(oss.str());
+	commander->execute_command(oss.str());
 }
 
 
 // set nebula label limit
 void StelUI::tui_cb_effects_nebulae_label_magnitude()
 {
+	StelCommandInterface* commander = (StelCommandInterface*)StelApp::getInstance().getModuleMgr().getModule("StelCommandInterface");
 	std::ostringstream oss;
 	oss << "set max_mag_nebula_name " << tui_effect_nebulae_label_magnitude->getValue();
-	app->commander->execute_command(oss.str());
+	commander->execute_command(oss.str());
 }
 
 
 void StelUI::tui_cb_change_color()
 {
-	ConstellationMgr* cmgr = (ConstellationMgr*)app->getModuleMgr().getModule("constellations");
-	NebulaMgr* nmgr = (NebulaMgr*)app->getModuleMgr().getModule("nebulas");
-	SolarSystem* ssmgr = (SolarSystem*)app->getModuleMgr().getModule("ssystem");
-	LandscapeMgr* lmgr = (LandscapeMgr*)app->getModuleMgr().getModule("landscape");
-	GridLinesMgr* grlmgr = (GridLinesMgr*)app->getModuleMgr().getModule("gridlines");
+	ConstellationMgr* cmgr = (ConstellationMgr*)app->getModuleMgr().getModule("ConstellationMgr");
+	NebulaMgr* nmgr = (NebulaMgr*)app->getModuleMgr().getModule("NebulaMgr");
+	SolarSystem* ssmgr = (SolarSystem*)app->getModuleMgr().getModule("SolarSystem");
+	LandscapeMgr* lmgr = (LandscapeMgr*)app->getModuleMgr().getModule("LandscapeMgr");
+	GridLinesMgr* grlmgr = (GridLinesMgr*)app->getModuleMgr().getModule("GridLinesMgr");
 	
 	cmgr->setLinesColor( tui_colors_const_line_color->getVector() );
 	cmgr->setNamesColor( tui_colors_const_label_color->getVector() );
@@ -905,7 +925,8 @@ void StelUI::tui_cb_location_change_planet()
 {
 	//	core->setHomePlanet( StelUtils::wstringToString( tui_location_planet->getCurrent() ) );
 	//	wcout << "set home planet " << tui_location_planet->getCurrent() << endl;
-	app->commander->execute_command(string("set home_planet \"") + 
+	StelCommandInterface* commander = (StelCommandInterface*)StelApp::getInstance().getModuleMgr().getModule("StelCommandInterface");	
+	commander->execute_command(string("set home_planet \"") + 
 									StelUtils::wstringToString( tui_location_planet->getCurrent() ) +
 									"\"");
 }
@@ -931,8 +952,9 @@ void StelUI::tuiUpdateIndependentWidgets(void) {
 	tui_location_planet->setValue(StelUtils::stringToWstring(core->getObservatory()->getHomePlanetEnglishName()));
 
 	// Reread local script directory (in case new files)
+	ScriptMgr* scripts = (ScriptMgr*)StelApp::getInstance().getModuleMgr().getModule("ScriptMgr");
 	tui_scripts_local->replaceItemList(_(TUI_SCRIPT_MSG) + wstring(L"\n") 
-			+ StelUtils::stringToWstring(app->scripts->get_script_list("scripts")), 0); 
+			+ StelUtils::stringToWstring(scripts->get_script_list("scripts")), 0); 
 
 	// also clear out script lists as media may have changed
 	ScriptDirectoryRead = 0;
@@ -941,32 +963,32 @@ void StelUI::tuiUpdateIndependentWidgets(void) {
 
 
 // Saves all current settings
-void StelUI::saveCurrentConfig(const string& confFile)
+void StelUI::saveCurrentConfig(const QString& confFile)
 {
 	// No longer resaves everything, just settings user can change through UI
 
 	StelSkyCultureMgr* skyCultureMgr = &app->getSkyCultureMgr();
 	StelLocaleMgr* localeMgr = &app->getLocaleMgr();
 	StelModuleMgr* moduleMgr = &app->getModuleMgr();
-	GridLinesMgr* grlmgr = (GridLinesMgr*)app->getModuleMgr().getModule("gridlines");
-	MovementMgr* mvmgr = (MovementMgr*)app->getModuleMgr().getModule("movements");
+	GridLinesMgr* grlmgr = (GridLinesMgr*)app->getModuleMgr().getModule("GridLinesMgr");
+	MovementMgr* mvmgr = (MovementMgr*)app->getModuleMgr().getModule("MovementMgr");
 	
-	cout << "Saving configuration file " << confFile << " ..." << endl;
+	cout << "Saving configuration file " << confFile.toUtf8().data() << " ..." << endl;
 	InitParser conf;
 	conf.load(confFile);
 
 	// Main section
-	conf.set_str	("main:version", string(PACKAGE_VERSION));
+	conf.set_str	("main:version", PACKAGE_VERSION);
 
 	// localization section
 	conf.set_str    ("localization:sky_culture", skyCultureMgr->getSkyCultureDir());
 	conf.set_str    ("localization:sky_locale", localeMgr->getSkyLanguage());
 	conf.set_str    ("localization:app_locale", localeMgr->getAppLanguage());
-	conf.set_str	("localization:time_display_format", localeMgr->get_time_format_str());
-	conf.set_str	("localization:date_display_format", localeMgr->get_date_format_str());
+	conf.set_str	("localization:time_display_format", localeMgr->get_time_format_str().c_str());
+	conf.set_str	("localization:date_display_format", localeMgr->get_date_format_str().c_str());
 	if (localeMgr->get_tz_format() == StelLocaleMgr::S_TZ_CUSTOM)
 	{
-		conf.set_str("localization:time_zone", localeMgr->get_custom_tz_name());
+		conf.set_str("localization:time_zone", localeMgr->get_custom_tz_name().c_str());
 	}
 	if (localeMgr->get_tz_format() == StelLocaleMgr::S_TZ_SYSTEM_DEFAULT)
 	{
@@ -978,7 +1000,7 @@ void StelUI::saveCurrentConfig(const string& confFile)
 	}
 
 	// viewing section
-	ConstellationMgr* cmgr = (ConstellationMgr*)moduleMgr->getModule("constellations");
+	ConstellationMgr* cmgr = (ConstellationMgr*)moduleMgr->getModule("ConstellationMgr");
 	conf.set_boolean("viewing:flag_constellation_drawing", cmgr->getFlagLines());
 	conf.set_boolean("viewing:flag_constellation_name", cmgr->getFlagNames());
 	conf.set_boolean("viewing:flag_constellation_art", cmgr->getFlagArt());
@@ -986,12 +1008,12 @@ void StelUI::saveCurrentConfig(const string& confFile)
 	conf.set_boolean("viewing:flag_constellation_pick", cmgr->getFlagIsolateSelected());
 	conf.set_double ("viewing:constellation_art_intensity", cmgr->getArtIntensity());
 	conf.set_double ("viewing:constellation_art_fade_duration", cmgr->getArtFadeDuration());
-	conf.set_str    ("color:const_lines_color", StelUtils::vec3f_to_str(cmgr->getLinesColor()));
-	conf.set_str    ("color:const_names_color", StelUtils::vec3f_to_str(cmgr->getNamesColor()));
-	conf.set_str    ("color:const_boundary_color", StelUtils::vec3f_to_str(cmgr->getBoundariesColor()));
+	conf.set_str    ("color:const_lines_color", StelUtils::vec3f_to_str(cmgr->getLinesColor()).c_str());
+	conf.set_str    ("color:const_names_color", StelUtils::vec3f_to_str(cmgr->getNamesColor()).c_str());
+	conf.set_str    ("color:const_boundary_color", StelUtils::vec3f_to_str(cmgr->getBoundariesColor()).c_str());
 		
-	SolarSystem* ssmgr = (SolarSystem*)moduleMgr->getModule("ssystem");
-	LandscapeMgr* lmgr = (LandscapeMgr*)moduleMgr->getModule("landscape");
+	SolarSystem* ssmgr = (SolarSystem*)moduleMgr->getModule("SolarSystem");
+	LandscapeMgr* lmgr = (LandscapeMgr*)moduleMgr->getModule("LandscapeMgr");
 	conf.set_double("viewing:moon_scale", ssmgr->getMoonScale());
 	conf.set_boolean("viewing:flag_equatorial_grid", grlmgr->getFlagEquatorGrid());
 	conf.set_boolean("viewing:flag_azimutal_grid", grlmgr->getFlagAzimutalGrid());
@@ -1009,7 +1031,7 @@ void StelUI::saveCurrentConfig(const string& confFile)
 	//	conf.set_double ("viewing:atmosphere_fade_duration", core->getAtmosphereFadeDuration());
 
 	// Star section
-	StarMgr* smgr = (StarMgr*)moduleMgr->getModule("stars");
+	StarMgr* smgr = (StarMgr*)moduleMgr->getModule("StarMgr");
 	conf.set_double ("stars:star_scale", smgr->getScale());
 	conf.set_double ("stars:star_mag_scale", smgr->getMagScale());
 	conf.set_boolean("stars:flag_point_star", smgr->getFlagPointStar());
@@ -1020,22 +1042,22 @@ void StelUI::saveCurrentConfig(const string& confFile)
 	conf.set_boolean("astro:flag_star_name", smgr->getFlagNames());
 
 	// Color section
-	NebulaMgr* nmgr = (NebulaMgr*)moduleMgr->getModule("nebulas");
-	conf.set_str    ("color:azimuthal_color", StelUtils::vec3f_to_str(grlmgr->getColorAzimutalGrid()));
-	conf.set_str    ("color:equatorial_color", StelUtils::vec3f_to_str(grlmgr->getColorEquatorGrid()));
-	conf.set_str    ("color:equator_color", StelUtils::vec3f_to_str(grlmgr->getColorEquatorLine()));
-	conf.set_str    ("color:ecliptic_color", StelUtils::vec3f_to_str(grlmgr->getColorEclipticLine()));
-	conf.set_str    ("color:meridian_color", StelUtils::vec3f_to_str(grlmgr->getColorMeridianLine()));
-	conf.set_str	("color:nebula_label_color", StelUtils::vec3f_to_str(nmgr->getNamesColor()));
-	conf.set_str	("color:nebula_circle_color", StelUtils::vec3f_to_str(nmgr->getCirclesColor()));
-	conf.set_str    ("color:cardinal_color", StelUtils::vec3f_to_str(lmgr->getColorCardinalPoints()));
-	conf.set_str    ("color:planet_names_color", StelUtils::vec3f_to_str(ssmgr->getNamesColor()));
-	conf.set_str    ("color:planet_orbits_color", StelUtils::vec3f_to_str(ssmgr->getOrbitsColor()));
-	conf.set_str    ("color:object_trails_color", StelUtils::vec3f_to_str(ssmgr->getTrailsColor()));
+	NebulaMgr* nmgr = (NebulaMgr*)moduleMgr->getModule("NebulaMgr");
+	conf.set_str    ("color:azimuthal_color", StelUtils::vec3f_to_str(grlmgr->getColorAzimutalGrid()).c_str());
+	conf.set_str    ("color:equatorial_color", StelUtils::vec3f_to_str(grlmgr->getColorEquatorGrid()).c_str());
+	conf.set_str    ("color:equator_color", StelUtils::vec3f_to_str(grlmgr->getColorEquatorLine()).c_str());
+	conf.set_str    ("color:ecliptic_color", StelUtils::vec3f_to_str(grlmgr->getColorEclipticLine()).c_str());
+	conf.set_str    ("color:meridian_color", StelUtils::vec3f_to_str(grlmgr->getColorMeridianLine()).c_str());
+	conf.set_str	("color:nebula_label_color", StelUtils::vec3f_to_str(nmgr->getNamesColor()).c_str());
+	conf.set_str	("color:nebula_circle_color", StelUtils::vec3f_to_str(nmgr->getCirclesColor()).c_str());
+	conf.set_str    ("color:cardinal_color", StelUtils::vec3f_to_str(lmgr->getColorCardinalPoints()).c_str());
+	conf.set_str    ("color:planet_names_color", StelUtils::vec3f_to_str(ssmgr->getNamesColor()).c_str());
+	conf.set_str    ("color:planet_orbits_color", StelUtils::vec3f_to_str(ssmgr->getOrbitsColor()).c_str());
+	conf.set_str    ("color:object_trails_color", StelUtils::vec3f_to_str(ssmgr->getTrailsColor()).c_str());
 
 	// gui section
 	conf.set_double("gui:mouse_cursor_timeout",getMouseCursorTimeout());
-	conf.set_str	("gui:day_key_mode", getDayKeyMode());
+	conf.set_str	("gui:day_key_mode", getDayKeyMode().c_str());
 
 	// Text ui section
 	conf.set_boolean("tui:flag_show_gravity_ui", getFlagShowGravityUi());
@@ -1047,7 +1069,7 @@ void StelUI::saveCurrentConfig(const string& confFile)
 	conf.set_double ("navigation:auto_move_duration", mvmgr->getAutoMoveDuration());
 	conf.set_double ("navigation:zoom_speed", mvmgr->getZoomSpeed());
 	conf.set_double ("navigation:preset_sky_time", core->getNavigation()->getPresetSkyTime());
-	conf.set_str	("navigation:startup_time_mode", core->getNavigation()->getStartupTimeMode());
+	conf.set_str	("navigation:startup_time_mode", core->getNavigation()->getStartupTimeMode().c_str());
 
 	// Astro section
 	conf.set_boolean("astro:flag_object_trails", ssmgr->getFlagTrails());
@@ -1059,12 +1081,11 @@ void StelUI::saveCurrentConfig(const string& confFile)
 	conf.set_boolean("astro:flag_planets_hints", ssmgr->getFlagHints());
 	conf.set_boolean("astro:flag_planets_orbits", ssmgr->getFlagOrbits());
 
-	MilkyWay* mw = (MilkyWay*)moduleMgr->getModule("milkyway");
+	MilkyWay* mw = (MilkyWay*)moduleMgr->getModule("MilkyWay");
 	conf.set_boolean("astro:flag_milky_way", mw->getFlagShow());
 	conf.set_double("astro:milky_way_intensity", mw->getIntensity());
 
-	// Get landscape and other observatory info
-	// TODO: shouldn't observator already know what section to save in?
+	// Save observatory info
 	core->getObservatory()->setConf(conf, "init_location");
 
 	conf.save(confFile);
