@@ -17,7 +17,6 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-
 #include <config.h>
 
 #include <math.h> // fmod
@@ -33,110 +32,45 @@
 #include <algorithm>
 #include <stdexcept>
 
-
-#include "dirent.h"
-
-#if defined( CYGWIN )
+#ifdef CYGWIN
  #include <malloc.h>
 #endif
 
-#ifdef HAVE_LIBCURL
- #include <curl/curl.h>
-#endif
-
 #include "StelUtils.hpp"
-#include "Translator.hpp"
 #include "vecmath.h"
 #include "GLee.h"
 
+#include "fixx11h.h"
+#include <QString>
+#include <QTextStream>
+#include <QFile>
+#include <QDebug>
+
 namespace StelUtils {
 
-//! Dummy wrapper used to remove a boring warning when using strftime directly
-size_t my_strftime(char *s, size_t max, const char *fmt, const struct tm *tm)
-{
-	return strftime(s, max, fmt, tm);
-}
-
-
-//! Convert from char* UTF-8 to wchar_t UCS4 - stolen from SDL_ttf library
-wchar_t *UTF8_to_UNICODE(wchar_t *unicode, const char *utf8, int len)
-{
-	int i, j;
-	unsigned short ch;  // 16 bits
-
-	for ( i=0, j=0; i < len; ++i, ++j )
-	{
-		ch = ((const unsigned char *)utf8)[i];
-		if ( ch >= 0xF0 )
-		{
-			ch  =  (unsigned short)(utf8[i]&0x07) << 18;
-			ch |=  (unsigned short)(utf8[++i]&0x3F) << 12;
-			ch |=  (unsigned short)(utf8[++i]&0x3F) << 6;
-			ch |=  (unsigned short)(utf8[++i]&0x3F);
-		}
-		else
-			if ( ch >= 0xE0 )
-			{
-				ch  =  (unsigned short)(utf8[i]&0x3F) << 12;
-				ch |=  (unsigned short)(utf8[++i]&0x3F) << 6;
-				ch |=  (unsigned short)(utf8[++i]&0x3F);
-			}
-			else
-				if ( ch >= 0xC0 )
-				{
-					ch  =  (unsigned short)(utf8[i]&0x3F) << 6;
-					ch |=  (unsigned short)(utf8[++i]&0x3F);
-				}
-
-		unicode[j] = ch;
-	}
-	unicode[j] = 0;
-
-	return unicode;
-}
-
-//! Convert from UTF-8 to wchar_t
-//! Warning this is likely to be not very portable
 std::wstring stringToWstring(const string& s)
 {
-	wchar_t* outbuf = new wchar_t[s.length()+1];
-	UTF8_to_UNICODE(outbuf, s.c_str(), s.length());
-	wstring ws(outbuf);
-	delete[] outbuf;
-	return ws;
+	return QString::fromUtf8(s.c_str()).toStdWString();
 }
 
 string wstringToString(const wstring& ws)
 {
-	// Get UTF-8 string length
-	size_t len = wcstombs(NULL, ws.c_str(), 0)+1;
-	// Create wide string
-	char* s = new char[len];
-	wcstombs(s, ws.c_str(), len);
-	string ss(s);
-	delete [] s;
-	return ss;
+	return QString::fromStdWString(ws).toUtf8().constData();
 }
 
 wstring doubleToWstring(double d)
 {
-	std::wostringstream woss;
-	woss << d;
-	return woss.str();
+	return QString::number(d).toStdWString();
 }
 
 wstring intToWstring(int i)
 {
-	std::wostringstream woss;
-	woss << i;
-	return woss.str();
+	return QString::number(i).toStdWString();
 }
 
 string intToString(int i)
 {
-	std::ostringstream oss;
-	oss << i;
-	return oss.str();
+	return QString::number(i).toStdString();
 }
 
 double hmsToRad(unsigned int h, unsigned int m, double s )
@@ -189,7 +123,7 @@ void radToDms(double angle, bool& sign, unsigned int& d, unsigned int& m, double
  Convert an angle in radian to a hms formatted string
  If the minute and second part are null are too small, don't print them
 *************************************************************************/
-string radToHmsStrAdapt(double angle)
+QString radToHmsStrAdapt(double angle)
 {
 	unsigned int h,m;
 	double s;
@@ -208,23 +142,13 @@ string radToHmsStrAdapt(double angle)
 	{
 		os << m << 'm';
 	}
-	return os.str();
+	return QString::fromStdString(os.str());
 }
 
-/*************************************************************************
- Convert an angle in radian to a hms formatted wstring
- If the minute and second part are null are too small, don't print them
-*************************************************************************/
-wstring radToHmsWstrAdapt(double angle)
-{
-	return StelUtils::stringToWstring(radToHmsStrAdapt(angle));
-}
-
-
 /*************************************************************************
  Convert an angle in radian to a hms formatted string
 *************************************************************************/
-string radToHmsStr(double angle, bool decimal)
+QString radToHmsStr(double angle, bool decimal)
 {
 	unsigned int h,m;
 	double s;
@@ -236,33 +160,32 @@ string radToHmsStr(double angle, bool decimal)
 		os << std::setprecision(0) << std::setw(2);
 	
 	os << h << 'h' << m << 'm' << std::fixed << std::setfill('0') << s << 's';
-	return os.str();
+	return QString::fromStdString(os.str());
 }
 
 /*************************************************************************
- Convert an angle in radian to a hms formatted wstring
-*************************************************************************/
-wstring radToHmsWstr(double angle, bool decimal)
-{
-	return StelUtils::stringToWstring(radToHmsStr(angle, decimal));
-}
-
-/*************************************************************************
- Convert an angle in radian to a dms formatted string
+ Convert an angle in radian to a dms formatted wstring
  If the minute and second part are null are too small, don't print them
 *************************************************************************/
-string radToDmsStrAdapt(double angle)
+QString radToDmsStrAdapt(double angle, bool useD)
 {
+	QString degsign('d');
+	if (!useD)
+	{
+		const wchar_t degsignw = L'\u00B0';
+		degsign = QString::fromWCharArray(&degsignw, 1);
+	}
 	bool sign;
 	unsigned int d,m;
 	double s;
 	StelUtils::radToDms(angle+0.005*M_PI/180/(60*60)*(angle<0?-1.:1.), sign, d, m, s);
-	ostringstream os;
+	QString str;
+	QTextStream os(&str);
 	
-	os << (sign?'+':'-') << d << 'd';
+	os << (sign?'+':'-') << d << degsign;
 	if (std::fabs(s*100-(int)s*100)>=1)
 	{
-		os << m << '\'' << std::fixed << std::setprecision(2) << std::setw(5) << std::setfill('0') << s << '\"';
+		os << m << '\'' << fixed << qSetRealNumberPrecision(2) << qSetFieldWidth(5) << qSetPadChar('0') << s << qSetFieldWidth(0) << '\"';
 	}
 	else if ((int)s!=0)
 	{
@@ -272,112 +195,46 @@ string radToDmsStrAdapt(double angle)
 	{
 		os << m << '\'';
 	}
-	return os.str();
+	return str;
 }
 
-/*************************************************************************
- Convert an angle in radian to a dms formatted wstring
- If the minute and second part are null are too small, don't print them
-*************************************************************************/
-wstring radToDmsWstrAdapt(double angle, bool useD)
-{
-	wchar_t degsign = L'\u00B0';
-	if (useD) degsign = L'd';
-	bool sign;
-	unsigned int d,m;
-	double s;
-	StelUtils::radToDms(angle+0.005*M_PI/180/(60*60)*(angle<0?-1.:1.), sign, d, m, s);
-	wostringstream os;
-	
-	os << (sign?L'+':L'-') << d << degsign;
-	if (std::fabs(s*100-(int)s*100)>=1)
-	{
-		os << m << L'\'' << std::fixed << std::setprecision(2) << std::setw(5) << std::setfill(L'0') << s << L'\"';
-	}
-	else if ((int)s!=0)
-	{
-		os << m << L'\'' << (int)s << L'\"';
-	}
-	else if (m!=0)
-	{
-		os << m << L'\'';
-	}
-	return os.str();
-}
-
-/*************************************************************************
- Convert an angle in radian to a dms formatted string
-*************************************************************************/
-string radToDmsStr(double angle, bool decimal)
-{
-	bool sign;
-	unsigned int d,m;
-	double s;
-	StelUtils::radToDms(angle+0.005*M_PI/180/(60*60)*(angle<0?-1.:1.), sign, d, m, s);
-	ostringstream os;
-	
-	os << (sign?'+':'-') << d << 'd';
-		
-	os << m << '\'' << std::fixed << std::setfill('0');
-	
-	if (decimal)
-		os << std::setprecision(1) << std::setw(4);
-	else
-		os << std::setprecision(0) << std::setw(2);
-		
-	os << s << '\"';
-	return os.str();
-}
 
 /*************************************************************************
  Convert an angle in radian to a dms formatted wstring
 *************************************************************************/
-wstring radToDmsWstr(double angle, bool decimal, bool useD)
+QString radToDmsStr(double angle, bool decimal, bool useD)
 {
-	wchar_t degsign = L'\u00B0';
-	if (useD) degsign = L'd';
+	QString degsign('d');
+	if (!useD)
+	{
+		const wchar_t degsignw = L'\u00B0';
+		degsign = QString::fromWCharArray(&degsignw, 1);
+	}
 	bool sign;
 	unsigned int d,m;
 	double s;
 	StelUtils::radToDms(angle+0.005*M_PI/180/(60*60)*(angle<0?-1.:1.), sign, d, m, s);
-	wostringstream os;
-	
-	os << (sign?L'+':L'-') << d << degsign;
-	
-	if (decimal)
-		os << std::setprecision(1) << std::setw(4);
-	else
-		os << std::setprecision(0) << std::setw(2);
-		
-	os << m << L'\'' << std::fixed << std::setfill(L'0') << s << L'\"';
-	return os.str();
-}
+	QString str;
+	QTextStream os(&str);
+	os << (sign?'+':'-') << d << degsign;
 
-/*************************************************************************
- Convert an angle in radian to a dms formatted string
-*************************************************************************/
-string radToDmsWstr(double angle)
-{
-	bool sign;
-	unsigned int d,m;
-	double s;
-	StelUtils::radToDms(angle+0.005*M_PI/180/(60*60)*(angle<0?-1.:1.), sign, d, m, s);
-	ostringstream os;
-	
-	os << (sign?'+':'-') << d << 'd';
-	if (std::fabs(s*100-(int)s*100)>=1)
+	int width = 2;
+	if (decimal)
 	{
-		os << m << '\'' << std::fixed << std::setprecision(2) << std::setw(5) << std::setfill('0') << s << '\"';
+		os << qSetRealNumberPrecision(1);
+		width = 4;
 	}
-	else if ((int)s!=0)
+	else
 	{
-		os << m << '\'' << (int)s << '\"';
+		os << qSetRealNumberPrecision(0);
+		width = 2;
 	}
-	else if (m!=0)
-	{
-		os << m << '\'';
-	}
-	return os.str();
+		
+	os << qSetFieldWidth(width) << m << qSetFieldWidth(0) << '\'' 
+		<< fixed << qSetFieldWidth(width) << qSetPadChar('0') << s 
+		<< qSetFieldWidth(0) << '\"';
+
+	return str;
 }
 
 // Obtains a Vec3f from a string with the form x,y,z
@@ -398,7 +255,13 @@ string vec3f_to_str(const Vec3f& v)
 
 double stringToDouble(const string& str)
 {
-	if(str.empty()) return 0;
+#ifdef NAN
+	if(str.empty())
+		return NAN;
+#else
+	if(str.empty())
+		return 0.;
+#endif
 	double dbl;
 	std::istringstream dstr( str );
 
@@ -603,16 +466,6 @@ double get_dec_angle(const string& str)
 	return (pos);
 }
 
-// Delete the file
-bool deleteFile(const std::string& fileName)
-{
-	if (std::remove(fileName.c_str())==-1)
-	{
-		return false;
-	}
-	return true;
-}
-
 bool checkAbsolutePath(const string& fileName)
 {
 	// Absolute path if starts by '/' or by 'Drive:/' (MS)
@@ -638,56 +491,47 @@ int getBiggerPowerOfTwo(int value)
 		p<<=1;
 	return p;
 }
-
-//! Download the file from the given URL to the given name using libcurl
-bool downloadFile(const std::string& url, const std::string& fullPath, 
-	const std::string& referer, const string& cookiesFile)
-{
-#ifndef HAVE_LIBCURL
-	cerr << "Stellarium was compiled without libCurl support. Can't access remote URLs." << endl;
-	return false;
-#else
-	// Download the file using libCurl
-	CURL* handle = curl_easy_init();
-	curl_easy_setopt(handle, CURLOPT_URL, url.c_str());
-	curl_easy_setopt(handle, CURLOPT_REFERER, referer.c_str());
-	curl_easy_setopt(handle, CURLOPT_FOLLOWLOCATION, 1);
-	curl_easy_setopt(handle, CURLOPT_SSL_VERIFYPEER, 0);
-	if (!cookiesFile.empty())
-	{
-		// Activate cookies
-		curl_easy_setopt(handle, CURLOPT_COOKIEFILE, cookiesFile.c_str());
-		cerr << "Using cookies file: " << cookiesFile << endl;
-	}
-	FILE* fic = fopen(fullPath.c_str(), "wb");
-	if (!fic)
-	{
-		cerr << "Can't create file: " << fullPath << endl;
-		return false;
-	}
-	curl_easy_setopt(handle, CURLOPT_WRITEDATA, fic);
-	//curl_easy_setopt(handle, CURLOPT_VERBOSE, 1);
-	if (curl_easy_perform(handle)!=0)
-	{
-		cerr << "There was an error while getting file: " << url << endl;
-		fclose(fic);
-		curl_easy_cleanup(handle);
-		return false;
-	}
-	fclose(fic);
-	curl_easy_cleanup(handle);
-	return true;
-#endif
-}
 	
-	// Return the inverse sinus hyperbolic of z
+// Return the inverse sinus hyperbolic of z
 double asinh(double z)
 {
 	return std::log(z+std::sqrt(z*z+1));
 }
-} // end of the StelUi namespace
 
-bool argsHaveOption(vector<string>& args, string shortOpt, string longOpt, bool modify=true)
+/*************************************************************************
+ Convert a QT QDateTime class to julian day
+*************************************************************************/
+double qDateTimeToJd(const QDateTime& dateTime)
+{
+	return (double)(dateTime.date().toJulianDay())+(double)1./(24*60*60*1000)*QTime().msecsTo(dateTime.time())-0.5;
+}
+
+/*************************************************************************
+ Convert a julian day to a QT QDateTime class. 
+ Warning if JD < 0 the date is invalid (any date before 2 January 4713 B.C.)
+*************************************************************************/
+QDateTime jdToQDateTime(double jd)
+{
+	jd+=0.5;
+	const int ms = (int)( (jd-(int)jd) *24.*60.*60.*1000. +0.5);
+	QDateTime dateTime(QDate::fromJulianDay((int)jd));
+	return dateTime.addMSecs(ms).toUTC();
+}
+
+/*************************************************************************
+ Calculate julian day from system time.
+*************************************************************************/
+double getJDFromSystem(void)
+{
+	return StelUtils::qDateTimeToJd(QDateTime::currentDateTime().toUTC());
+}
+
+double qTimeToJDFraction(const QTime& time)
+{
+	return (double)1./(24*60*60*1000)*QTime().msecsTo(time)-0.5;
+}
+
+bool argsHaveOption(vector<string>& args, string shortOpt, string longOpt, bool modify)
 {
 	bool result=false;
 	vector<string>::iterator lastOpt = find(args.begin(), args.end(), "--");
@@ -711,235 +555,91 @@ bool argsHaveOption(vector<string>& args, string shortOpt, string longOpt, bool
 	return result;
 }
 
+} // end of the StelUtils namespace
+////////////////////////////////////////////////////////////////////////////////////////////
+
 // convert string int ISO 8601-like format [+/-]YYYY-MM-DDThh:mm:ss (no timzone offset)
 // to julian day
 int string_to_jday(string date, double &jd)
 {
-	char tmp;
-	int year, month, day, hour, minute, second;
-	year = month = day = hour = minute = second = 0;
+	cerr << date << endl;
+	// Handle also strings with : instead of - in date part
+// 	for(int i=0; i<2; i++)
+// 	{
+// 		string::size_type p = date.find(":", 0);
+// 		if (p != string::npos)
+// 			date.replace(p, 1, "-");
+// 	}
 
-	std::istringstream dstr( date );
-
-	// TODO better error checking
-	dstr >> year >> tmp >> month >> tmp >> day >> tmp >> hour >> tmp >> minute >> tmp >> second;
-
-	// bounds checking (per s_tui time object)
-	if( year > 100000 || year < -100000 ||
-	        month < 1 || month > 12 ||
-	        day < 1 || day > 31 ||
-	        hour < 0 || hour > 23 ||
-	        minute < 0 || minute > 59 ||
-	        second < 0 || second > 59) return 0;
-
-
-	// code taken from s_tui.cpp
-	if (month <= 2)
-	{
-		year--;
-		month += 12;
-	}
-
-	// Correct for the lost days in Oct 1582 when the Gregorian calendar
-	// replaced the Julian calendar.
-	int B = -2;
-	if (year > 1582 || (year == 1582 && (month > 10 || (month == 10 && day >= 15))))
-	{
-		B = year / 400 - year / 100;
-	}
-
-	jd = ((floor(365.25 * year) +
-	       floor(30.6001 * (month + 1)) + B + 1720996.5 +
-	       day + hour / 24.0 + minute / 1440.0 + second / 86400.0));
+// 	// handle lack of 0 padding
+// 	if (date.find("-",5) == 6)
+// 		date.replace(5, 0, "0");
+// 
+// 	if (date.find("T",7) == 9)
+// 		date.replace(8, 0, "0");
+// 
+// 	if (date.find(":",11) == 12)
+// 		date.replace(11, 0, "0");
+// 
+// 	if (date.find(":",14) == 15)
+// 		date.replace(14, 0, "0");
+// 
+// 	if (date.length() == 18)
+// 		date.replace(17, 0, "0");
 
+	jd = StelUtils::qDateTimeToJd(QDateTime::fromString(date.c_str(), Qt::ISODate));
 	return 1;
 }
 
-/* Calculate the julian day from a calendar day.
- * Valid for positive and negative years but not for negative JD.
- * Formula 7.1 on pg 61 */
- // Code originally from libnova which appeared to be totally wrong... New code from celestia
-double get_julian_day (const ln_date * cdate)
-{
-	ln_date date;
-	int y, m, B;
-
-	date = *cdate;
-
-	y = date.years;
-	m = date.months;
-	if (date.months <= 2)
-	{
-		y = date.years - 1;
-		m = date.months + 12;
-	}
-
-    // Correct for the lost days in Oct 1582 when the Gregorian calendar
-    // replaced the Julian calendar.
-	B = -2;
-	if (date.years > 1582 || (date.years == 1582 && (date.months > 10 || (date.months == 10 && date.days >= 15))))
-	{
-		B = y / 400 - y / 100;
-	}
-
-	return (floor(365.25 * y) +
-			floor(30.6001 * (m + 1)) + B + 1720996.5 +
-			date.days + date.hours / 24.0 + date.minutes / 1440.0 + date.seconds / 86400.0);
-}
 
 // Calculate tm struct from julian day
 void get_tm_from_julian(double JD, struct tm * tm_time)
 {
-	ln_date date;
-	get_date(JD, &date);
-	tm_time->tm_sec = (int)date.seconds;
-	tm_time->tm_min = date.minutes;
-	tm_time->tm_hour = date.hours;
-	tm_time->tm_mday = date.days;
-	tm_time->tm_mon = date.months - 1;
-	tm_time->tm_year = date.years - 1900;
+	QDateTime dateTime = StelUtils::jdToQDateTime(JD);
+	tm_time->tm_sec = dateTime.time().second();
+	tm_time->tm_min = dateTime.time().minute();
+	tm_time->tm_hour = dateTime.time().hour();
+	tm_time->tm_wday = (int)fmod(JD + 1.0,7);
+	tm_time->tm_mday = dateTime.date().day();
+	tm_time->tm_mon = dateTime.date().month() - 1;
+	tm_time->tm_year = dateTime.date().year() - 1900;
 	tm_time->tm_isdst = -1;
 }
 
-/* Calculate the date from the Julian day
- * params : JD Julian day, date Pointer to new calendar date. */
- // Code originally from libnova which appeared to be totally wrong... New code from celestia
-void get_date(double jd, ln_date * date)
+//! Dummy wrapper used to remove a boring warning when using strftime directly
+size_t my_strftime(char *s, size_t max, const char *fmt, const struct tm *tm)
 {
-	int a, d, e, f;
-	double c, b;
-	double dday, dhour, dminute;
-
-	a = (int) (jd + 0.5);
-
-	if (a < 2299161)
-	{
-		c = a + 1524;
-	}
-	else
-	{
-		b = (int) ((a - 1867216.25) / 36524.25);
-		c = a + b - (int) (b / 4) + 1525;
-	}
-
-	d = (int) ((c - 122.1) / 365.25);
-	e = (int) (365.25 * d);
-	f = (int) ((c - e) / 30.6001);
-
-	dday = c - e - (int) (30.6001 * f) + ((jd + 0.5) - (int) (jd + 0.5));
-
-    /* This following used to be 14.0, but gcc was computing it incorrectly, so
-	it was changed to 14 */
-	date->months = f - 1 - 12 * (int) (f / 14);
-	date->years = d - 4715 - (int) ((7.0 + date->months) / 10.0);
-	date->days = (int) dday;
-
-	dhour = (dday - date->days) * 24;
-	date->hours = (int) dhour;
-
-	dminute = (dhour - date->hours) * 60;
-	date->minutes = (int) dminute;
-
-	date->seconds = (dminute - date->minutes) * 60;
+	return strftime(s, max, fmt, tm);
 }
 
-
-/* Calculate gmt date from system date.
- * param : date Pointer to store date. */
-void get_ln_date_from_sys(ln_date * date)
-{
-	time_t rawtime;
-	struct tm * ptm;
-
-	/* get current time */
-	time ( &rawtime );
-
-	/* convert to gmt time representation */
-	ptm = gmtime ( &rawtime );
-
-	/* fill in date struct */
-	date->seconds = ptm->tm_sec;
-	date->minutes = ptm->tm_min;
-	date->hours = ptm->tm_hour;
-	date->days = ptm->tm_mday;
-	date->months = ptm->tm_mon + 1;
-	date->years = ptm->tm_year + 1900;
-}
-
-/* Calculate julian day from system time. */
-double get_julian_from_sys(void)
-{
-	ln_date date;
-	/* get sys date */
-	get_ln_date_from_sys(&date);
-	return get_julian_day(&date);
-}
-
-// Calculate time_t from julian day
-time_t get_time_t_from_julian(double JD)
-{
-	struct tm loctime;
-	ln_date date;
-
-	get_date(JD, &date);
-
-	loctime.tm_sec = (int)date.seconds;
-	loctime.tm_min = date.minutes;
-	loctime.tm_hour = date.hours;
-	loctime.tm_mday =date.days;
-	loctime.tm_mon = date.months -1;
-	loctime.tm_year = date.years - 1900;
-	loctime.tm_isdst = -1;
-
-	return mktime(&loctime);
-}
-
-
 // Return the number of hours to add to gmt time to get the local time in day JD
 // taking the parameters from system. This takes into account the daylight saving
 // time if there is. (positive for Est of GMT)
 // TODO : %z in strftime only works on GNU compiler
 // Fixed 31-05-2004 Now use the extern variables set by tzset()
-float get_GMT_shift_from_system(double JD, bool _local)
+float get_GMT_shift_from_system(double JD)
 {
-	/* Doesn't seem like MACOSX is a special case... ??? rob
-#if defined( MACOSX ) || defined(WIN32)
-	struct tm *timeinfo;
-	time_t rawtime; time(&rawtime);
-	timeinfo = localtime(&rawtime);
-	return (float)timeinfo->tm_gmtoff/3600 + (timeinfo->tm_isdst!=0); 
-#else */
-
 #if !defined(WIN32)
-
 	struct tm * timeinfo;
-
-	if(!_local)
-	{
-		// JD is UTC
-		struct tm rawtime;
-		get_tm_from_julian(JD, &rawtime);
-		
+	struct tm rawtime;
+	get_tm_from_julian(JD, &rawtime);
 #ifdef HAVE_TIMEGM
-		time_t ltime = timegm(&rawtime);
-#elif HAVE_MKTIME
-		time_t ltime = mktime(&rawtime);
-#else
-		// This does not work
-		time_t ltime = my_timegm(&rawtime);
+	time_t ltime = timegm(&rawtime);
 #endif
-		
-		timeinfo = localtime(&ltime);
-	} else {
-		time_t rtime;
-		rtime = get_time_t_from_julian(JD);
-		timeinfo = localtime(&rtime);
-	}
+#ifndef HAVE_TIMEGM
+#ifdef HAVE_MKTIME
+	time_t ltime = mktime(&rawtime);
+#else
+	// This does not work
+	time_t ltime = my_timegm(&rawtime);
+#endif	
+#endif
+	timeinfo = localtime(&ltime);
 
 	static char heure[20];
 	heure[0] = '\0';
 
-	StelUtils::my_strftime(heure, 19, "%z", timeinfo);
+	my_strftime(heure, 19, "%z", timeinfo);
 	
 	heure[5] = '\0';
 	float min = 1.f/60.f * atoi(&heure[3]);
@@ -954,6 +654,12 @@ float get_GMT_shift_from_system(double JD, bool _local)
 #endif
 }
 
+// Calculate time_t from julian day
+time_t get_time_t_from_julian(double JD)
+{
+	return StelUtils::jdToQDateTime(JD).toTime_t();
+}
+
 // Return the time zone name taken from system locale
 wstring get_time_zone_name_from_system(double JD)
 {
@@ -969,17 +675,6 @@ wstring get_time_zone_name_from_system(double JD)
 	timeinfo = localtime(&rawtime);
 	static char timez[255];
 	timez[0] = 0;
-	StelUtils::my_strftime(timez, 254, "%Z", timeinfo);
+	my_strftime(timez, 254, "%Z", timeinfo);
 	return StelUtils::stringToWstring(timez);
 }
-
-// Return the time in ISO 8601 format that is : %Y-%m-%d %H:%M:%S
-string get_ISO8601_time_UTC(double JD)
-{
-	struct tm time_utc;
-	get_tm_from_julian(JD, &time_utc);
-
-	static char isotime[255];
-	StelUtils::my_strftime(isotime, 254, "%Y-%m-%d %H:%M:%S", &time_utc);
-	return isotime;
-}
