@@ -138,7 +138,7 @@ public:
 	// Return longitude in rad
 	inline T longitude() const;
 	
-	// Distance in radian between two normalized vectors
+	// Distance in radian between two
 	inline T angle(const Vector3<T>&) const;
 
     inline T length() const;
@@ -157,7 +157,8 @@ public:
     inline Vector4();
     inline Vector4(const Vector4<T>&);
 	inline Vector4(const Vector3<T>&);
-    inline Vector4(T, T, T, T);
+	inline Vector4(T, T, T);
+	inline Vector4(T, T, T, T);
 
 	inline Vector4& operator=(const Vector4<T>&);
 	inline Vector4& operator=(const Vector3<T>&);
@@ -372,7 +373,7 @@ template<class T> T Vector2<T>::dot(const Vector2<T>& b) const
 
 template<class T> T Vector2<T>::length() const
 {
-    return (T) sqrt(v[0] * v[0] + v[1] * v[1]);
+    return (T) std::sqrt(v[0] * v[0] + v[1] * v[1]);
 }
 
 template<class T> T Vector2<T>::lengthSquared() const
@@ -382,7 +383,7 @@ template<class T> T Vector2<T>::lengthSquared() const
 
 template<class T> void Vector2<T>::normalize()
 {
-    T s = (T) 1 / sqrt(v[0] * v[0] + v[1] * v[1]);
+    T s = (T) 1 / std::sqrt(v[0] * v[0] + v[1] * v[1]);
     v[0] *= s;
     v[1] *= s;
 }
@@ -535,7 +536,7 @@ template<class T> Vector3<T> Vector3<T>::operator^(const Vector3<T>& b) const
 // Angle in radian between two normalized vectors
 template<class T> T Vector3<T>::angle(const Vector3<T>& b) const
 {
-	return std::acos(dot(b));
+	return std::acos(dot(b)/sqrt(lengthSquared()*b.lengthSquared()));
 }
 
 template<class T> T Vector3<T>::length() const
@@ -550,7 +551,7 @@ template<class T> T Vector3<T>::lengthSquared() const
 
 template<class T> void Vector3<T>::normalize()
 {
-    T s = (T) (1. / sqrt(v[0] * v[0] + v[1] * v[1] + v[2] * v[2]));
+    T s = (T) (1. / std::sqrt(v[0] * v[0] + v[1] * v[1] + v[2] * v[2]));
     v[0] *= s;
     v[1] *= s;
     v[2] *= s;
@@ -614,6 +615,11 @@ template<class T> Vector4<T>::Vector4(const Vector3<T>& a)
 	v[0]=a.v[0]; v[1]=a.v[1]; v[2]=a.v[2]; v[3]=1;
 }
 
+template<class T> Vector4<T>::Vector4(T x, T y, T z)
+{
+	v[0]=x; v[1]=y; v[2]=z; v[3]=1;
+}
+
 template<class T> Vector4<T>::Vector4(T x, T y, T z, T a = 1)
 {
 	v[0]=x; v[1]=y; v[2]=z; v[3]=a;
